# Changelog

## 0.788.0 (2026-03-28)

Full Changelog: [v0.787.0...v0.788.0](https://github.com/aiinbx/aiinbx-py/compare/v0.787.0...v0.788.0)

### Features

* **api:** api update ([a1086cb](https://github.com/aiinbx/aiinbx-py/commit/a1086cbdf0ec7920f7d195732d499e1029da0dc7))

## 0.787.0 (2026-03-28)

Full Changelog: [v0.786.0...v0.787.0](https://github.com/aiinbx/aiinbx-py/compare/v0.786.0...v0.787.0)

### Features

* **api:** api update ([c3cbecc](https://github.com/aiinbx/aiinbx-py/commit/c3cbecc48f304b778a2a00c9e0fff6df9470fd77))

## 0.786.0 (2026-03-28)

Full Changelog: [v0.785.0...v0.786.0](https://github.com/aiinbx/aiinbx-py/compare/v0.785.0...v0.786.0)

### Features

* **api:** api update ([0f789aa](https://github.com/aiinbx/aiinbx-py/commit/0f789aaee98126c1ac8f800ef9a3997811f36ed1))

## 0.785.0 (2026-03-28)

Full Changelog: [v0.784.0...v0.785.0](https://github.com/aiinbx/aiinbx-py/compare/v0.784.0...v0.785.0)

### Features

* **api:** api update ([8344973](https://github.com/aiinbx/aiinbx-py/commit/8344973e709ae97f84ec26fdfa0449bc3eec80bc))

## 0.784.0 (2026-03-28)

Full Changelog: [v0.783.0...v0.784.0](https://github.com/aiinbx/aiinbx-py/compare/v0.783.0...v0.784.0)

### Features

* **api:** api update ([e30acec](https://github.com/aiinbx/aiinbx-py/commit/e30aceca82a2f5cb9a6496f7fa8f30f24f949a37))

## 0.783.0 (2026-03-28)

Full Changelog: [v0.782.0...v0.783.0](https://github.com/aiinbx/aiinbx-py/compare/v0.782.0...v0.783.0)

### Features

* **api:** api update ([91004ee](https://github.com/aiinbx/aiinbx-py/commit/91004eecb0fd831458aada8cd8b72d77c2165e44))

## 0.782.0 (2026-03-27)

Full Changelog: [v0.781.0...v0.782.0](https://github.com/aiinbx/aiinbx-py/compare/v0.781.0...v0.782.0)

### Features

* **api:** api update ([7e0ae51](https://github.com/aiinbx/aiinbx-py/commit/7e0ae51aafbd8d5eb2f2d2570a94db99e7c9f767))

## 0.781.0 (2026-03-27)

Full Changelog: [v0.780.0...v0.781.0](https://github.com/aiinbx/aiinbx-py/compare/v0.780.0...v0.781.0)

### Features

* **api:** api update ([40a22c9](https://github.com/aiinbx/aiinbx-py/commit/40a22c9c40784b2d9ae456dc40744f852452ac74))

## 0.780.0 (2026-03-27)

Full Changelog: [v0.779.0...v0.780.0](https://github.com/aiinbx/aiinbx-py/compare/v0.779.0...v0.780.0)

### Features

* **api:** api update ([b226ae1](https://github.com/aiinbx/aiinbx-py/commit/b226ae1871c046fc1b07177dd58d33f176a002e7))

## 0.779.0 (2026-03-27)

Full Changelog: [v0.778.0...v0.779.0](https://github.com/aiinbx/aiinbx-py/compare/v0.778.0...v0.779.0)

### Features

* **api:** api update ([3bbe027](https://github.com/aiinbx/aiinbx-py/commit/3bbe02744c6f8a61a1d9d9a19a8f48121cc8f7ff))

## 0.778.0 (2026-03-27)

Full Changelog: [v0.777.0...v0.778.0](https://github.com/aiinbx/aiinbx-py/compare/v0.777.0...v0.778.0)

### Features

* **api:** api update ([3d24a75](https://github.com/aiinbx/aiinbx-py/commit/3d24a75fb7ecebf5013fa528d6b8b71b60394fd5))

## 0.777.0 (2026-03-27)

Full Changelog: [v0.776.0...v0.777.0](https://github.com/aiinbx/aiinbx-py/compare/v0.776.0...v0.777.0)

### Features

* **api:** api update ([6b7848b](https://github.com/aiinbx/aiinbx-py/commit/6b7848b1bb4c9c815147f3aa4c2909a8a5ee0fa7))

## 0.776.0 (2026-03-27)

Full Changelog: [v0.775.0...v0.776.0](https://github.com/aiinbx/aiinbx-py/compare/v0.775.0...v0.776.0)

### Features

* **api:** api update ([b4f441d](https://github.com/aiinbx/aiinbx-py/commit/b4f441df77f118ef1d09321bc6f16866daf7dfc9))

## 0.775.0 (2026-03-27)

Full Changelog: [v0.774.0...v0.775.0](https://github.com/aiinbx/aiinbx-py/compare/v0.774.0...v0.775.0)

### Features

* **api:** api update ([380b8fb](https://github.com/aiinbx/aiinbx-py/commit/380b8fbf8dfe930578d0f25fb5ba35b4d62e5337))

## 0.774.0 (2026-03-27)

Full Changelog: [v0.773.0...v0.774.0](https://github.com/aiinbx/aiinbx-py/compare/v0.773.0...v0.774.0)

### Features

* **internal:** implement indices array format for query and form serialization ([5e89eec](https://github.com/aiinbx/aiinbx-py/commit/5e89eec4d0f591c1a6a39f464fe071dc870653b2))

## 0.773.0 (2026-03-27)

Full Changelog: [v0.772.0...v0.773.0](https://github.com/aiinbx/aiinbx-py/compare/v0.772.0...v0.773.0)

### Features

* **api:** api update ([47c6ef0](https://github.com/aiinbx/aiinbx-py/commit/47c6ef00f3a884372fdfaff4a1e2cd66036fba58))

## 0.772.0 (2026-03-27)

Full Changelog: [v0.771.0...v0.772.0](https://github.com/aiinbx/aiinbx-py/compare/v0.771.0...v0.772.0)

### Features

* **api:** api update ([ca0262c](https://github.com/aiinbx/aiinbx-py/commit/ca0262c3da33b519c9df3a13222a623ade6b55bf))

## 0.771.0 (2026-03-26)

Full Changelog: [v0.770.0...v0.771.0](https://github.com/aiinbx/aiinbx-py/compare/v0.770.0...v0.771.0)

### Features

* **api:** api update ([49d7c40](https://github.com/aiinbx/aiinbx-py/commit/49d7c40be6a47568f67664b319778e4a686a6eda))

## 0.770.0 (2026-03-26)

Full Changelog: [v0.769.0...v0.770.0](https://github.com/aiinbx/aiinbx-py/compare/v0.769.0...v0.770.0)

### Features

* **api:** api update ([b72841c](https://github.com/aiinbx/aiinbx-py/commit/b72841cfda6bdebcfac3939fb12e92490caa796c))

## 0.769.0 (2026-03-26)

Full Changelog: [v0.768.0...v0.769.0](https://github.com/aiinbx/aiinbx-py/compare/v0.768.0...v0.769.0)

### Features

* **api:** api update ([ffea92b](https://github.com/aiinbx/aiinbx-py/commit/ffea92be66e16ace9689eae9c6cbf8da67c75c11))

## 0.768.0 (2026-03-26)

Full Changelog: [v0.767.0...v0.768.0](https://github.com/aiinbx/aiinbx-py/compare/v0.767.0...v0.768.0)

### Features

* **api:** api update ([c406c7e](https://github.com/aiinbx/aiinbx-py/commit/c406c7e7af05633de0c882f06a64b77c8b431d8a))

## 0.767.0 (2026-03-26)

Full Changelog: [v0.766.0...v0.767.0](https://github.com/aiinbx/aiinbx-py/compare/v0.766.0...v0.767.0)

### Features

* **api:** api update ([9fbcba4](https://github.com/aiinbx/aiinbx-py/commit/9fbcba43ca3360e948feae68bfe76c3e4b29fd35))

## 0.766.0 (2026-03-26)

Full Changelog: [v0.765.0...v0.766.0](https://github.com/aiinbx/aiinbx-py/compare/v0.765.0...v0.766.0)

### Features

* **api:** api update ([55c3174](https://github.com/aiinbx/aiinbx-py/commit/55c3174205f913874d5e3d0a51e4c1adc5741990))

## 0.765.0 (2026-03-26)

Full Changelog: [v0.764.0...v0.765.0](https://github.com/aiinbx/aiinbx-py/compare/v0.764.0...v0.765.0)

### Features

* **api:** api update ([6afef9a](https://github.com/aiinbx/aiinbx-py/commit/6afef9a0d4071d376fc19df3bd5471011da684aa))

## 0.764.0 (2026-03-26)

Full Changelog: [v0.763.0...v0.764.0](https://github.com/aiinbx/aiinbx-py/compare/v0.763.0...v0.764.0)

### Features

* **api:** api update ([91ae8be](https://github.com/aiinbx/aiinbx-py/commit/91ae8bea1edea24a4c78726863d567bee3020c3c))

## 0.763.0 (2026-03-26)

Full Changelog: [v0.762.0...v0.763.0](https://github.com/aiinbx/aiinbx-py/compare/v0.762.0...v0.763.0)

### Features

* **api:** api update ([d0e370b](https://github.com/aiinbx/aiinbx-py/commit/d0e370beab0b3e17f6927aff492466ea80365a46))

## 0.762.0 (2026-03-26)

Full Changelog: [v0.761.0...v0.762.0](https://github.com/aiinbx/aiinbx-py/compare/v0.761.0...v0.762.0)

### Features

* **api:** api update ([faeb5a0](https://github.com/aiinbx/aiinbx-py/commit/faeb5a08ab9e300d8817fa6a4ad5a9dd6e1951ea))

## 0.761.0 (2026-03-25)

Full Changelog: [v0.760.0...v0.761.0](https://github.com/aiinbx/aiinbx-py/compare/v0.760.0...v0.761.0)

### Features

* **api:** api update ([114ab27](https://github.com/aiinbx/aiinbx-py/commit/114ab27ae45e8844bcc2b0c76a1e2ccd13d26436))

## 0.760.0 (2026-03-25)

Full Changelog: [v0.759.0...v0.760.0](https://github.com/aiinbx/aiinbx-py/compare/v0.759.0...v0.760.0)

### Features

* **api:** api update ([d9f1de4](https://github.com/aiinbx/aiinbx-py/commit/d9f1de49b674f10fb7b3116cd6c7d86974fb31fb))

## 0.759.0 (2026-03-25)

Full Changelog: [v0.758.0...v0.759.0](https://github.com/aiinbx/aiinbx-py/compare/v0.758.0...v0.759.0)

### Features

* **api:** api update ([b343a12](https://github.com/aiinbx/aiinbx-py/commit/b343a12faf560f767b384ccc786132d06e544a4d))

## 0.758.0 (2026-03-25)

Full Changelog: [v0.757.0...v0.758.0](https://github.com/aiinbx/aiinbx-py/compare/v0.757.0...v0.758.0)

### Features

* **api:** api update ([9027c48](https://github.com/aiinbx/aiinbx-py/commit/9027c4830cfbe70ea163e6163117597a03eac598))


### Chores

* **ci:** skip lint on metadata-only changes ([cbaecc2](https://github.com/aiinbx/aiinbx-py/commit/cbaecc26df97bf30e4eec2a5b6ecd45843a3952a))

## 0.757.0 (2026-03-24)

Full Changelog: [v0.756.0...v0.757.0](https://github.com/aiinbx/aiinbx-py/compare/v0.756.0...v0.757.0)

### Features

* **api:** api update ([6c52d4c](https://github.com/aiinbx/aiinbx-py/commit/6c52d4c574fb4062951abfb867e707b56d64d7ce))

## 0.756.0 (2026-03-24)

Full Changelog: [v0.755.0...v0.756.0](https://github.com/aiinbx/aiinbx-py/compare/v0.755.0...v0.756.0)

### Features

* **api:** api update ([0b9e468](https://github.com/aiinbx/aiinbx-py/commit/0b9e4688c1e1754c3580f37d2d6403275e396574))

## 0.755.0 (2026-03-24)

Full Changelog: [v0.754.0...v0.755.0](https://github.com/aiinbx/aiinbx-py/compare/v0.754.0...v0.755.0)

### Features

* **api:** api update ([5a87a2a](https://github.com/aiinbx/aiinbx-py/commit/5a87a2a01586d1eabb457ef3f3c64ef81ea4ebca))

## 0.754.0 (2026-03-24)

Full Changelog: [v0.753.0...v0.754.0](https://github.com/aiinbx/aiinbx-py/compare/v0.753.0...v0.754.0)

### Features

* **api:** api update ([d712074](https://github.com/aiinbx/aiinbx-py/commit/d7120749204f21e3b19923929514f7f6b0785b0a))

## 0.753.0 (2026-03-24)

Full Changelog: [v0.752.0...v0.753.0](https://github.com/aiinbx/aiinbx-py/compare/v0.752.0...v0.753.0)

### Features

* **api:** api update ([fc8e39a](https://github.com/aiinbx/aiinbx-py/commit/fc8e39a429d812bbaf96cc1b087b56e05bb425d9))

## 0.752.0 (2026-03-24)

Full Changelog: [v0.751.0...v0.752.0](https://github.com/aiinbx/aiinbx-py/compare/v0.751.0...v0.752.0)

### Features

* **api:** api update ([185340b](https://github.com/aiinbx/aiinbx-py/commit/185340b34bc140b8d4c9166a1b1da39e2d9faeef))

## 0.751.0 (2026-03-24)

Full Changelog: [v0.750.0...v0.751.0](https://github.com/aiinbx/aiinbx-py/compare/v0.750.0...v0.751.0)

### Features

* **api:** api update ([69e34e4](https://github.com/aiinbx/aiinbx-py/commit/69e34e42f53b29d89bc71cb9551131bbba8e9657))

## 0.750.0 (2026-03-24)

Full Changelog: [v0.749.0...v0.750.0](https://github.com/aiinbx/aiinbx-py/compare/v0.749.0...v0.750.0)

### Features

* **api:** api update ([1fb0a50](https://github.com/aiinbx/aiinbx-py/commit/1fb0a5057d102cc14a5a9de137cacd3fef74cc31))


### Chores

* **internal:** update gitignore ([1f1dc3c](https://github.com/aiinbx/aiinbx-py/commit/1f1dc3cd8834cfd1e3de762e0dab14fc1a95e1ef))

## 0.749.0 (2026-03-24)

Full Changelog: [v0.748.0...v0.749.0](https://github.com/aiinbx/aiinbx-py/compare/v0.748.0...v0.749.0)

### Features

* **api:** api update ([64e6433](https://github.com/aiinbx/aiinbx-py/commit/64e64330aea95c23724766bbb58d50cf91172632))

## 0.748.0 (2026-03-24)

Full Changelog: [v0.747.0...v0.748.0](https://github.com/aiinbx/aiinbx-py/compare/v0.747.0...v0.748.0)

### Features

* **api:** api update ([35926ef](https://github.com/aiinbx/aiinbx-py/commit/35926efceed1f9d06f90a1fad44665523cb00d5a))

## 0.747.0 (2026-03-23)

Full Changelog: [v0.746.0...v0.747.0](https://github.com/aiinbx/aiinbx-py/compare/v0.746.0...v0.747.0)

### Features

* **api:** api update ([2320bea](https://github.com/aiinbx/aiinbx-py/commit/2320beaaf25b20fe713903e0bf580a83d0dd2d42))

## 0.746.0 (2026-03-23)

Full Changelog: [v0.745.0...v0.746.0](https://github.com/aiinbx/aiinbx-py/compare/v0.745.0...v0.746.0)

### Features

* **api:** api update ([e34ff28](https://github.com/aiinbx/aiinbx-py/commit/e34ff286b7930104642be2da06c4f4bdbf625e63))

## 0.745.0 (2026-03-23)

Full Changelog: [v0.744.0...v0.745.0](https://github.com/aiinbx/aiinbx-py/compare/v0.744.0...v0.745.0)

### Features

* **api:** api update ([b929686](https://github.com/aiinbx/aiinbx-py/commit/b9296862f56af6b506c5bd3d4959dea19c7daf3e))

## 0.744.0 (2026-03-23)

Full Changelog: [v0.743.0...v0.744.0](https://github.com/aiinbx/aiinbx-py/compare/v0.743.0...v0.744.0)

### Features

* **api:** api update ([ac50f2c](https://github.com/aiinbx/aiinbx-py/commit/ac50f2c2e5cdcddae04508a60e03f6759a07ff70))

## 0.743.0 (2026-03-23)

Full Changelog: [v0.742.0...v0.743.0](https://github.com/aiinbx/aiinbx-py/compare/v0.742.0...v0.743.0)

### Features

* **api:** api update ([4495e90](https://github.com/aiinbx/aiinbx-py/commit/4495e9019a5b4310e30f12552f270be13799aaf2))

## 0.742.0 (2026-03-23)

Full Changelog: [v0.741.0...v0.742.0](https://github.com/aiinbx/aiinbx-py/compare/v0.741.0...v0.742.0)

### Features

* **api:** api update ([0feae62](https://github.com/aiinbx/aiinbx-py/commit/0feae625078e67f348c932aabeceeb898c1566a4))

## 0.741.0 (2026-03-23)

Full Changelog: [v0.740.0...v0.741.0](https://github.com/aiinbx/aiinbx-py/compare/v0.740.0...v0.741.0)

### Features

* **api:** api update ([6f03813](https://github.com/aiinbx/aiinbx-py/commit/6f038132797748052082cbb89cdb10913dd74c30))

## 0.740.0 (2026-03-23)

Full Changelog: [v0.739.0...v0.740.0](https://github.com/aiinbx/aiinbx-py/compare/v0.739.0...v0.740.0)

### Features

* **api:** api update ([ca79fa4](https://github.com/aiinbx/aiinbx-py/commit/ca79fa43ecd01a00bd3599d40a1e6520731e9f9f))
* **api:** api update ([46c1f15](https://github.com/aiinbx/aiinbx-py/commit/46c1f156c8a9beae8ee33ab2239c4b7213e9547d))
* **api:** api update ([8de067a](https://github.com/aiinbx/aiinbx-py/commit/8de067ae7df90e4b7211be846d8ad03c611d8934))
* **api:** api update ([a86a138](https://github.com/aiinbx/aiinbx-py/commit/a86a138294e31d351c7aaf225cc6fc50e98afa8b))
* **api:** api update ([70d162a](https://github.com/aiinbx/aiinbx-py/commit/70d162a016004aeffbfc28b0ae718f2c0adfd61b))
* **api:** api update ([ed973a1](https://github.com/aiinbx/aiinbx-py/commit/ed973a11863444f640bfd5a9aa133b177693eede))
* **api:** api update ([e566288](https://github.com/aiinbx/aiinbx-py/commit/e56628868e69981028193354ff41db5a1d1927b2))
* **api:** api update ([b71bbe2](https://github.com/aiinbx/aiinbx-py/commit/b71bbe2ae9c7ad2185e77fadfbd312caa577c29f))
* **api:** api update ([66fc87d](https://github.com/aiinbx/aiinbx-py/commit/66fc87d9e5c4aea949f5d29208f531bb7480bfc7))

## 0.739.0 (2026-03-22)

Full Changelog: [v0.738.0...v0.739.0](https://github.com/aiinbx/aiinbx-py/compare/v0.738.0...v0.739.0)

### Features

* **api:** api update ([a90c85e](https://github.com/aiinbx/aiinbx-py/commit/a90c85ea21cfbab93dd6f26b589af8e30a37d376))

## 0.738.0 (2026-03-22)

Full Changelog: [v0.737.0...v0.738.0](https://github.com/aiinbx/aiinbx-py/compare/v0.737.0...v0.738.0)

### Features

* **api:** api update ([3433a54](https://github.com/aiinbx/aiinbx-py/commit/3433a54c0ec5274c6404596c75c67362ce2d8ff3))

## 0.737.0 (2026-03-22)

Full Changelog: [v0.736.0...v0.737.0](https://github.com/aiinbx/aiinbx-py/compare/v0.736.0...v0.737.0)

### Features

* **api:** api update ([ed37fd4](https://github.com/aiinbx/aiinbx-py/commit/ed37fd4c83b983ca19c8cebb8273704b1d4e9fbd))

## 0.736.0 (2026-03-22)

Full Changelog: [v0.735.0...v0.736.0](https://github.com/aiinbx/aiinbx-py/compare/v0.735.0...v0.736.0)

### Features

* **api:** api update ([c84e329](https://github.com/aiinbx/aiinbx-py/commit/c84e3291ca707896938db5fd137931cb34aa7e87))
* **api:** api update ([08aad8d](https://github.com/aiinbx/aiinbx-py/commit/08aad8ddc20c8fe0089f5825eb6944c84fdc2df0))
* **api:** api update ([90f45a3](https://github.com/aiinbx/aiinbx-py/commit/90f45a35084a1003e96acab07423fbd23e2bcb70))
* **api:** api update ([1811ef8](https://github.com/aiinbx/aiinbx-py/commit/1811ef8c6c5eed5eeb38488c7ebf8b0a82a0bec0))
* **api:** api update ([75e2661](https://github.com/aiinbx/aiinbx-py/commit/75e2661a3ccc8f61dd587e82fe24224694a0926f))
* **api:** api update ([ea09b9d](https://github.com/aiinbx/aiinbx-py/commit/ea09b9dfb3f4c340ca3851913a30457219a13c21))
* **api:** api update ([1702d1b](https://github.com/aiinbx/aiinbx-py/commit/1702d1b870a9ba8ce266c2e7a498d014bd5fdbd3))
* **api:** api update ([c497afc](https://github.com/aiinbx/aiinbx-py/commit/c497afcafab7ade37df7625af028d3cae27f1e62))
* **api:** api update ([ddf70d6](https://github.com/aiinbx/aiinbx-py/commit/ddf70d69059fc070f47818ee0d269bb845698fa6))
* **api:** api update ([ecef688](https://github.com/aiinbx/aiinbx-py/commit/ecef6883f6b49e43198122892a219d902f91c0ff))
* **api:** api update ([13208f2](https://github.com/aiinbx/aiinbx-py/commit/13208f213d8a78b9f1bb8bcfc38b5c78d6e01953))
* **api:** api update ([09d71b3](https://github.com/aiinbx/aiinbx-py/commit/09d71b399b3e05e3971927a0ded42ad38dd846eb))

## 0.735.0 (2026-03-21)

Full Changelog: [v0.734.0...v0.735.0](https://github.com/aiinbx/aiinbx-py/compare/v0.734.0...v0.735.0)

### Features

* **api:** api update ([52f0239](https://github.com/aiinbx/aiinbx-py/commit/52f0239fd15af3613106607db35673c1ad1ef426))

## 0.734.0 (2026-03-21)

Full Changelog: [v0.733.0...v0.734.0](https://github.com/aiinbx/aiinbx-py/compare/v0.733.0...v0.734.0)

### Features

* **api:** api update ([262885c](https://github.com/aiinbx/aiinbx-py/commit/262885c1f05667080f666e153e07e604dcb8352c))

## 0.733.0 (2026-03-21)

Full Changelog: [v0.732.0...v0.733.0](https://github.com/aiinbx/aiinbx-py/compare/v0.732.0...v0.733.0)

### Features

* **api:** api update ([3feb451](https://github.com/aiinbx/aiinbx-py/commit/3feb4518f6338204f1473316f5fbc4da2c806a10))

## 0.732.0 (2026-03-21)

Full Changelog: [v0.731.0...v0.732.0](https://github.com/aiinbx/aiinbx-py/compare/v0.731.0...v0.732.0)

### Features

* **api:** api update ([441d719](https://github.com/aiinbx/aiinbx-py/commit/441d7191900acdb45ca6bd3551086e2414e08738))

## 0.731.0 (2026-03-21)

Full Changelog: [v0.730.0...v0.731.0](https://github.com/aiinbx/aiinbx-py/compare/v0.730.0...v0.731.0)

### Features

* **api:** api update ([f1c1d28](https://github.com/aiinbx/aiinbx-py/commit/f1c1d28228f2dfaef293c1955f7ff5bfacac50a5))

## 0.730.0 (2026-03-21)

Full Changelog: [v0.729.0...v0.730.0](https://github.com/aiinbx/aiinbx-py/compare/v0.729.0...v0.730.0)

### Features

* **api:** api update ([6dbc97b](https://github.com/aiinbx/aiinbx-py/commit/6dbc97b870ae0102882b10e649a77828d0aa09bf))

## 0.729.0 (2026-03-21)

Full Changelog: [v0.728.0...v0.729.0](https://github.com/aiinbx/aiinbx-py/compare/v0.728.0...v0.729.0)

### Features

* **api:** api update ([d269bb3](https://github.com/aiinbx/aiinbx-py/commit/d269bb3df9ad1425b69b835576ea2ccb96c73653))

## 0.728.0 (2026-03-20)

Full Changelog: [v0.727.0...v0.728.0](https://github.com/aiinbx/aiinbx-py/compare/v0.727.0...v0.728.0)

### Features

* **api:** api update ([329116d](https://github.com/aiinbx/aiinbx-py/commit/329116d7a2657a53cf175abb3daa53934708e056))
* **api:** api update ([87fbcad](https://github.com/aiinbx/aiinbx-py/commit/87fbcadf760e3fa156846893653df9d7fb467468))

## 0.727.0 (2026-03-20)

Full Changelog: [v0.726.0...v0.727.0](https://github.com/aiinbx/aiinbx-py/compare/v0.726.0...v0.727.0)

### Features

* **api:** api update ([b7317ff](https://github.com/aiinbx/aiinbx-py/commit/b7317fff56e3f591944f9ee491c27aa006b42b27))

## 0.726.0 (2026-03-20)

Full Changelog: [v0.725.0...v0.726.0](https://github.com/aiinbx/aiinbx-py/compare/v0.725.0...v0.726.0)

### Features

* **api:** api update ([3693910](https://github.com/aiinbx/aiinbx-py/commit/3693910f2e0d0e7c7b8207a5ffc81796ef5bb9a2))

## 0.725.0 (2026-03-20)

Full Changelog: [v0.724.0...v0.725.0](https://github.com/aiinbx/aiinbx-py/compare/v0.724.0...v0.725.0)

### Features

* **api:** api update ([610e39e](https://github.com/aiinbx/aiinbx-py/commit/610e39ee10ee68e0ec1341461a3df0821c0cf4dd))

## 0.724.0 (2026-03-20)

Full Changelog: [v0.723.0...v0.724.0](https://github.com/aiinbx/aiinbx-py/compare/v0.723.0...v0.724.0)

### Features

* **api:** api update ([5719b5c](https://github.com/aiinbx/aiinbx-py/commit/5719b5c307551c2bdd878b1027dbcc427d039ea6))

## 0.723.0 (2026-03-20)

Full Changelog: [v0.722.0...v0.723.0](https://github.com/aiinbx/aiinbx-py/compare/v0.722.0...v0.723.0)

### Features

* **api:** api update ([d8188f1](https://github.com/aiinbx/aiinbx-py/commit/d8188f12c01abff36225aa0b41b1678933b5a924))

## 0.722.0 (2026-03-20)

Full Changelog: [v0.721.0...v0.722.0](https://github.com/aiinbx/aiinbx-py/compare/v0.721.0...v0.722.0)

### Features

* **api:** api update ([59b1c89](https://github.com/aiinbx/aiinbx-py/commit/59b1c895affe39b57bf58585810a1115c8fb2ab7))

## 0.721.0 (2026-03-20)

Full Changelog: [v0.720.0...v0.721.0](https://github.com/aiinbx/aiinbx-py/compare/v0.720.0...v0.721.0)

### Features

* **api:** api update ([5d4a455](https://github.com/aiinbx/aiinbx-py/commit/5d4a455565b9faef944523e8a43e969f4a3f7345))

## 0.720.0 (2026-03-20)

Full Changelog: [v0.719.1...v0.720.0](https://github.com/aiinbx/aiinbx-py/compare/v0.719.1...v0.720.0)

### Features

* **api:** api update ([d7e1ef0](https://github.com/aiinbx/aiinbx-py/commit/d7e1ef040839f26b43298e8ac6b5a911ac5c449e))

## 0.719.1 (2026-03-20)

Full Changelog: [v0.719.0...v0.719.1](https://github.com/aiinbx/aiinbx-py/compare/v0.719.0...v0.719.1)

### Bug Fixes

* sanitize endpoint path params ([aa5e27c](https://github.com/aiinbx/aiinbx-py/commit/aa5e27c9ba867fdfbb9fa5a5c66bc18777579caf))

## 0.719.0 (2026-03-20)

Full Changelog: [v0.718.0...v0.719.0](https://github.com/aiinbx/aiinbx-py/compare/v0.718.0...v0.719.0)

### Features

* **api:** api update ([58edc2c](https://github.com/aiinbx/aiinbx-py/commit/58edc2c49d3c51720500e6eee3a60765ff575f22))

## 0.718.0 (2026-03-20)

Full Changelog: [v0.717.0...v0.718.0](https://github.com/aiinbx/aiinbx-py/compare/v0.717.0...v0.718.0)

### Features

* **api:** api update ([b5525f5](https://github.com/aiinbx/aiinbx-py/commit/b5525f5ad4eecbd391ba71ee4bf7b9a3b74b2418))

## 0.717.0 (2026-03-19)

Full Changelog: [v0.716.0...v0.717.0](https://github.com/aiinbx/aiinbx-py/compare/v0.716.0...v0.717.0)

### Features

* **api:** api update ([a81b9f9](https://github.com/aiinbx/aiinbx-py/commit/a81b9f9a1f01c801497e71efd08b3ecb01272e79))

## 0.716.0 (2026-03-19)

Full Changelog: [v0.715.0...v0.716.0](https://github.com/aiinbx/aiinbx-py/compare/v0.715.0...v0.716.0)

### Features

* **api:** api update ([56a173c](https://github.com/aiinbx/aiinbx-py/commit/56a173cc846217fff565562c7562a7f8e39c431f))

## 0.715.0 (2026-03-19)

Full Changelog: [v0.714.0...v0.715.0](https://github.com/aiinbx/aiinbx-py/compare/v0.714.0...v0.715.0)

### Features

* **api:** api update ([5e77962](https://github.com/aiinbx/aiinbx-py/commit/5e779629b3af2314ac0ef0820caa9423c2ab3f02))

## 0.714.0 (2026-03-19)

Full Changelog: [v0.713.0...v0.714.0](https://github.com/aiinbx/aiinbx-py/compare/v0.713.0...v0.714.0)

### Features

* **api:** api update ([1ca3f3e](https://github.com/aiinbx/aiinbx-py/commit/1ca3f3e6a802744de6c732b0f3d8360a8e3a7e8c))

## 0.713.0 (2026-03-19)

Full Changelog: [v0.712.0...v0.713.0](https://github.com/aiinbx/aiinbx-py/compare/v0.712.0...v0.713.0)

### Features

* **api:** api update ([3a5e92e](https://github.com/aiinbx/aiinbx-py/commit/3a5e92ed1d4feea51da4b0f8474d5886322af713))

## 0.712.0 (2026-03-19)

Full Changelog: [v0.711.0...v0.712.0](https://github.com/aiinbx/aiinbx-py/compare/v0.711.0...v0.712.0)

### Features

* **api:** api update ([0a9fcf1](https://github.com/aiinbx/aiinbx-py/commit/0a9fcf184d93f411793e1ce51ce9a9d5e6e4be05))

## 0.711.0 (2026-03-19)

Full Changelog: [v0.710.0...v0.711.0](https://github.com/aiinbx/aiinbx-py/compare/v0.710.0...v0.711.0)

### Features

* **api:** api update ([c63b0a9](https://github.com/aiinbx/aiinbx-py/commit/c63b0a98c3cc0ccf68fb9737726568960746e3bb))

## 0.710.0 (2026-03-19)

Full Changelog: [v0.709.0...v0.710.0](https://github.com/aiinbx/aiinbx-py/compare/v0.709.0...v0.710.0)

### Features

* **api:** api update ([faa5d47](https://github.com/aiinbx/aiinbx-py/commit/faa5d4793dd76f57a9037551ff2ea20d9cf06206))

## 0.709.0 (2026-03-19)

Full Changelog: [v0.708.0...v0.709.0](https://github.com/aiinbx/aiinbx-py/compare/v0.708.0...v0.709.0)

### Features

* **api:** api update ([f003293](https://github.com/aiinbx/aiinbx-py/commit/f0032933180ea25c9c9896b555519bf58ed0707d))

## 0.708.0 (2026-03-19)

Full Changelog: [v0.707.0...v0.708.0](https://github.com/aiinbx/aiinbx-py/compare/v0.707.0...v0.708.0)

### Features

* **api:** api update ([40ba586](https://github.com/aiinbx/aiinbx-py/commit/40ba586179fe681a78a2c42c1f3e1fa86980eaff))

## 0.707.0 (2026-03-19)

Full Changelog: [v0.706.0...v0.707.0](https://github.com/aiinbx/aiinbx-py/compare/v0.706.0...v0.707.0)

### Features

* **api:** api update ([e77ec38](https://github.com/aiinbx/aiinbx-py/commit/e77ec386e5e3b3e2387f19cc38914baa1c167840))

## 0.706.0 (2026-03-18)

Full Changelog: [v0.705.0...v0.706.0](https://github.com/aiinbx/aiinbx-py/compare/v0.705.0...v0.706.0)

### Features

* **api:** api update ([d94a59c](https://github.com/aiinbx/aiinbx-py/commit/d94a59c67ca2a7575f17eaa922f76164f6fb160f))

## 0.705.0 (2026-03-18)

Full Changelog: [v0.704.0...v0.705.0](https://github.com/aiinbx/aiinbx-py/compare/v0.704.0...v0.705.0)

### Features

* **api:** api update ([78703e6](https://github.com/aiinbx/aiinbx-py/commit/78703e641f8f1450278388075dc38be749a0ce88))

## 0.704.0 (2026-03-18)

Full Changelog: [v0.703.0...v0.704.0](https://github.com/aiinbx/aiinbx-py/compare/v0.703.0...v0.704.0)

### Features

* **api:** api update ([b6c87de](https://github.com/aiinbx/aiinbx-py/commit/b6c87def386bcc05c6d2d9089d494c9a3cb8bb04))

## 0.703.0 (2026-03-18)

Full Changelog: [v0.702.0...v0.703.0](https://github.com/aiinbx/aiinbx-py/compare/v0.702.0...v0.703.0)

### Features

* **api:** api update ([00f83e6](https://github.com/aiinbx/aiinbx-py/commit/00f83e65526780ab2616395df78301e324948ef1))

## 0.702.0 (2026-03-18)

Full Changelog: [v0.701.0...v0.702.0](https://github.com/aiinbx/aiinbx-py/compare/v0.701.0...v0.702.0)

### Features

* **api:** api update ([75a4294](https://github.com/aiinbx/aiinbx-py/commit/75a42942ae9e05d95df154bcde54f9613bf4e162))

## 0.701.0 (2026-03-18)

Full Changelog: [v0.700.0...v0.701.0](https://github.com/aiinbx/aiinbx-py/compare/v0.700.0...v0.701.0)

### Features

* **api:** api update ([bf23223](https://github.com/aiinbx/aiinbx-py/commit/bf232232ba7c886b73a895b7da8aace33ee691e7))

## 0.700.0 (2026-03-18)

Full Changelog: [v0.699.0...v0.700.0](https://github.com/aiinbx/aiinbx-py/compare/v0.699.0...v0.700.0)

### Features

* **api:** api update ([1d5e466](https://github.com/aiinbx/aiinbx-py/commit/1d5e466c65156cac23122f89a3a6206a8688dc57))

## 0.699.0 (2026-03-18)

Full Changelog: [v0.698.0...v0.699.0](https://github.com/aiinbx/aiinbx-py/compare/v0.698.0...v0.699.0)

### Features

* **api:** api update ([8161640](https://github.com/aiinbx/aiinbx-py/commit/81616406da6e0d9fd9adda6a307e5da776f9b5f6))

## 0.698.0 (2026-03-18)

Full Changelog: [v0.697.0...v0.698.0](https://github.com/aiinbx/aiinbx-py/compare/v0.697.0...v0.698.0)

### Features

* **api:** api update ([b0f8c8d](https://github.com/aiinbx/aiinbx-py/commit/b0f8c8d9f251eb4b0f0a3601986e05e78ca2bd6c))

## 0.697.0 (2026-03-18)

Full Changelog: [v0.696.0...v0.697.0](https://github.com/aiinbx/aiinbx-py/compare/v0.696.0...v0.697.0)

### Features

* **api:** api update ([5ebe25e](https://github.com/aiinbx/aiinbx-py/commit/5ebe25e3e9d5f4c22ca5064aaa1dc0c5dece98ba))

## 0.696.0 (2026-03-17)

Full Changelog: [v0.695.0...v0.696.0](https://github.com/aiinbx/aiinbx-py/compare/v0.695.0...v0.696.0)

### Features

* **api:** api update ([f8ce297](https://github.com/aiinbx/aiinbx-py/commit/f8ce297efd8e5a434b59052981dcecd1937f3add))

## 0.695.0 (2026-03-17)

Full Changelog: [v0.694.0...v0.695.0](https://github.com/aiinbx/aiinbx-py/compare/v0.694.0...v0.695.0)

### Features

* **api:** api update ([6c44308](https://github.com/aiinbx/aiinbx-py/commit/6c4430811d74a19b5b211621ac30e8d85f239dc1))
* **api:** api update ([2afcb3c](https://github.com/aiinbx/aiinbx-py/commit/2afcb3c3cbe308a8e6186b4c7ffa846906bc44d6))

## 0.694.0 (2026-03-17)

Full Changelog: [v0.693.0...v0.694.0](https://github.com/aiinbx/aiinbx-py/compare/v0.693.0...v0.694.0)

### Features

* **api:** api update ([088d1a8](https://github.com/aiinbx/aiinbx-py/commit/088d1a8b90082b49c51af469530afd9650ca997d))

## 0.693.0 (2026-03-17)

Full Changelog: [v0.692.0...v0.693.0](https://github.com/aiinbx/aiinbx-py/compare/v0.692.0...v0.693.0)

### Features

* **api:** api update ([ce38a29](https://github.com/aiinbx/aiinbx-py/commit/ce38a293e9edf4af9ed9a30dbb8383ea11d7e8ae))

## 0.692.0 (2026-03-17)

Full Changelog: [v0.691.0...v0.692.0](https://github.com/aiinbx/aiinbx-py/compare/v0.691.0...v0.692.0)

### Features

* **api:** api update ([0c29715](https://github.com/aiinbx/aiinbx-py/commit/0c29715f1eb41a7fdb9f9e879ac6d2312405ecdd))

## 0.691.0 (2026-03-17)

Full Changelog: [v0.690.2...v0.691.0](https://github.com/aiinbx/aiinbx-py/compare/v0.690.2...v0.691.0)

### Features

* **api:** api update ([a93a6ea](https://github.com/aiinbx/aiinbx-py/commit/a93a6eab858bb99e2c2bbd88f5316f01dba2bd15))


### Chores

* **internal:** tweak CI branches ([dc1b213](https://github.com/aiinbx/aiinbx-py/commit/dc1b213a4f3a9c9a0356d1d5e13b5eda13cc4055))

## 0.690.2 (2026-03-17)

Full Changelog: [v0.690.1...v0.690.2](https://github.com/aiinbx/aiinbx-py/compare/v0.690.1...v0.690.2)

### Bug Fixes

* **deps:** bump minimum typing-extensions version ([523f766](https://github.com/aiinbx/aiinbx-py/commit/523f7664584d57d9624e79308896752302821869))

## 0.690.1 (2026-03-17)

Full Changelog: [v0.690.0...v0.690.1](https://github.com/aiinbx/aiinbx-py/compare/v0.690.0...v0.690.1)

### Bug Fixes

* **pydantic:** do not pass `by_alias` unless set ([fc8e00c](https://github.com/aiinbx/aiinbx-py/commit/fc8e00c8dd3a8777ccc1f2ff8dbce4202fc7488a))

## 0.690.0 (2026-03-17)

Full Changelog: [v0.689.0...v0.690.0](https://github.com/aiinbx/aiinbx-py/compare/v0.689.0...v0.690.0)

### Features

* **api:** api update ([249b0b0](https://github.com/aiinbx/aiinbx-py/commit/249b0b0379cd717d25a505e1791de5c9ea2fcf27))

## 0.689.0 (2026-03-16)

Full Changelog: [v0.688.0...v0.689.0](https://github.com/aiinbx/aiinbx-py/compare/v0.688.0...v0.689.0)

### Features

* **api:** api update ([8bb9abd](https://github.com/aiinbx/aiinbx-py/commit/8bb9abdaaafbba19f1d1af6caf5d98096572c2fa))

## 0.688.0 (2026-03-16)

Full Changelog: [v0.687.0...v0.688.0](https://github.com/aiinbx/aiinbx-py/compare/v0.687.0...v0.688.0)

### Features

* **api:** api update ([2a60b6b](https://github.com/aiinbx/aiinbx-py/commit/2a60b6b4f026edaa998ad3aab0b7bb32e28f4ff4))

## 0.687.0 (2026-03-16)

Full Changelog: [v0.686.0...v0.687.0](https://github.com/aiinbx/aiinbx-py/compare/v0.686.0...v0.687.0)

### Features

* **api:** api update ([1805331](https://github.com/aiinbx/aiinbx-py/commit/1805331f65d7a1ac98823f346810fdd2ad11ccf0))

## 0.686.0 (2026-03-16)

Full Changelog: [v0.685.0...v0.686.0](https://github.com/aiinbx/aiinbx-py/compare/v0.685.0...v0.686.0)

### Features

* **api:** api update ([5e80434](https://github.com/aiinbx/aiinbx-py/commit/5e80434fb37b404358fc838a03ccdb6f00ecc6f2))

## 0.685.0 (2026-03-16)

Full Changelog: [v0.684.0...v0.685.0](https://github.com/aiinbx/aiinbx-py/compare/v0.684.0...v0.685.0)

### Features

* **api:** api update ([0dd988f](https://github.com/aiinbx/aiinbx-py/commit/0dd988f40dd8e3aebdc57d2db35cf50e3d247afc))

## 0.684.0 (2026-03-15)

Full Changelog: [v0.683.0...v0.684.0](https://github.com/aiinbx/aiinbx-py/compare/v0.683.0...v0.684.0)

### Features

* **api:** api update ([5495791](https://github.com/aiinbx/aiinbx-py/commit/5495791134f044adb955a530d159731a19c32292))

## 0.683.0 (2026-03-15)

Full Changelog: [v0.682.0...v0.683.0](https://github.com/aiinbx/aiinbx-py/compare/v0.682.0...v0.683.0)

### Features

* **api:** api update ([9ad762e](https://github.com/aiinbx/aiinbx-py/commit/9ad762e456a721d8dbb76821ac2e417fe8bb99f9))

## 0.682.0 (2026-03-15)

Full Changelog: [v0.681.0...v0.682.0](https://github.com/aiinbx/aiinbx-py/compare/v0.681.0...v0.682.0)

### Features

* **api:** api update ([972ab38](https://github.com/aiinbx/aiinbx-py/commit/972ab38245ad6c688ef6fe87511b8cd9a329e6e7))

## 0.681.0 (2026-03-15)

Full Changelog: [v0.680.0...v0.681.0](https://github.com/aiinbx/aiinbx-py/compare/v0.680.0...v0.681.0)

### Features

* **api:** api update ([bec3dee](https://github.com/aiinbx/aiinbx-py/commit/bec3dee26405044b307eb540e715f05ba965b47d))

## 0.680.0 (2026-03-15)

Full Changelog: [v0.679.0...v0.680.0](https://github.com/aiinbx/aiinbx-py/compare/v0.679.0...v0.680.0)

### Features

* **api:** api update ([69a1386](https://github.com/aiinbx/aiinbx-py/commit/69a1386b0db2b36d7308c962f5dbd2fc4d31b637))

## 0.679.0 (2026-03-15)

Full Changelog: [v0.678.0...v0.679.0](https://github.com/aiinbx/aiinbx-py/compare/v0.678.0...v0.679.0)

### Features

* **api:** api update ([437b557](https://github.com/aiinbx/aiinbx-py/commit/437b5574581c08a5998cd8deca71a4e1ef794ff6))

## 0.678.0 (2026-03-14)

Full Changelog: [v0.677.0...v0.678.0](https://github.com/aiinbx/aiinbx-py/compare/v0.677.0...v0.678.0)

### Features

* **api:** api update ([a42af2d](https://github.com/aiinbx/aiinbx-py/commit/a42af2d24850a63a4ddb03c9753d06bea074712d))

## 0.677.0 (2026-03-14)

Full Changelog: [v0.676.0...v0.677.0](https://github.com/aiinbx/aiinbx-py/compare/v0.676.0...v0.677.0)

### Features

* **api:** api update ([9697ca2](https://github.com/aiinbx/aiinbx-py/commit/9697ca29d2d97daa3442e6c2be691cbfd5bf98d8))

## 0.676.0 (2026-03-14)

Full Changelog: [v0.675.0...v0.676.0](https://github.com/aiinbx/aiinbx-py/compare/v0.675.0...v0.676.0)

### Features

* **api:** api update ([276d9f6](https://github.com/aiinbx/aiinbx-py/commit/276d9f6b3feab02da90201b0e86b1bd1cf0b2e09))

## 0.675.0 (2026-03-14)

Full Changelog: [v0.674.0...v0.675.0](https://github.com/aiinbx/aiinbx-py/compare/v0.674.0...v0.675.0)

### Features

* **api:** api update ([b3294c3](https://github.com/aiinbx/aiinbx-py/commit/b3294c3980a2652f96d6ec4387e3a10a90e386d1))

## 0.674.0 (2026-03-14)

Full Changelog: [v0.673.0...v0.674.0](https://github.com/aiinbx/aiinbx-py/compare/v0.673.0...v0.674.0)

### Features

* **api:** api update ([5cf3e05](https://github.com/aiinbx/aiinbx-py/commit/5cf3e05e876b91b55846a69be1d8a38dfc79b3c1))

## 0.673.0 (2026-03-14)

Full Changelog: [v0.672.0...v0.673.0](https://github.com/aiinbx/aiinbx-py/compare/v0.672.0...v0.673.0)

### Features

* **api:** api update ([a6704f5](https://github.com/aiinbx/aiinbx-py/commit/a6704f58eec24595929a991d1674bc385bbf9f69))

## 0.672.0 (2026-03-14)

Full Changelog: [v0.671.0...v0.672.0](https://github.com/aiinbx/aiinbx-py/compare/v0.671.0...v0.672.0)

### Features

* **api:** api update ([416ba51](https://github.com/aiinbx/aiinbx-py/commit/416ba5182cb065e8b3161c330a5b2a5a90e2db7a))

## 0.671.0 (2026-03-14)

Full Changelog: [v0.670.0...v0.671.0](https://github.com/aiinbx/aiinbx-py/compare/v0.670.0...v0.671.0)

### Features

* **api:** api update ([bebca68](https://github.com/aiinbx/aiinbx-py/commit/bebca683a03cc4e585b0995442af186cde26eca2))

## 0.670.0 (2026-03-13)

Full Changelog: [v0.669.0...v0.670.0](https://github.com/aiinbx/aiinbx-py/compare/v0.669.0...v0.670.0)

### Features

* **api:** api update ([ed153c2](https://github.com/aiinbx/aiinbx-py/commit/ed153c2ab07fec06647b89171f86cce2e79b25b7))

## 0.669.0 (2026-03-13)

Full Changelog: [v0.668.0...v0.669.0](https://github.com/aiinbx/aiinbx-py/compare/v0.668.0...v0.669.0)

### Features

* **api:** api update ([a4aa1eb](https://github.com/aiinbx/aiinbx-py/commit/a4aa1ebae686ac36be988a9ce9bc685384d427c9))

## 0.668.0 (2026-03-13)

Full Changelog: [v0.667.0...v0.668.0](https://github.com/aiinbx/aiinbx-py/compare/v0.667.0...v0.668.0)

### Features

* **api:** api update ([0a495ca](https://github.com/aiinbx/aiinbx-py/commit/0a495ca94e83309310c05d866049bce80cacf3cf))

## 0.667.0 (2026-03-13)

Full Changelog: [v0.666.0...v0.667.0](https://github.com/aiinbx/aiinbx-py/compare/v0.666.0...v0.667.0)

### Features

* **api:** api update ([b643825](https://github.com/aiinbx/aiinbx-py/commit/b643825f1cad8da10e6b697600adff8fa7044e75))

## 0.666.0 (2026-03-13)

Full Changelog: [v0.665.0...v0.666.0](https://github.com/aiinbx/aiinbx-py/compare/v0.665.0...v0.666.0)

### Features

* **api:** api update ([1dc9e84](https://github.com/aiinbx/aiinbx-py/commit/1dc9e844a044f7ef5a0e79f4396d52e9c72b423b))

## 0.665.0 (2026-03-13)

Full Changelog: [v0.664.0...v0.665.0](https://github.com/aiinbx/aiinbx-py/compare/v0.664.0...v0.665.0)

### Features

* **api:** api update ([176c8b8](https://github.com/aiinbx/aiinbx-py/commit/176c8b8f45cec89eef1d4c58a6bc91795c901e7a))

## 0.664.0 (2026-03-13)

Full Changelog: [v0.663.0...v0.664.0](https://github.com/aiinbx/aiinbx-py/compare/v0.663.0...v0.664.0)

### Features

* **api:** api update ([9a3aa62](https://github.com/aiinbx/aiinbx-py/commit/9a3aa62e7df021fb350a8a6bb5271a0523d74613))

## 0.663.0 (2026-03-13)

Full Changelog: [v0.662.0...v0.663.0](https://github.com/aiinbx/aiinbx-py/compare/v0.662.0...v0.663.0)

### Features

* **api:** api update ([021528e](https://github.com/aiinbx/aiinbx-py/commit/021528e6e8e740a80af8b316211fa56043fc98d7))

## 0.662.0 (2026-03-13)

Full Changelog: [v0.661.0...v0.662.0](https://github.com/aiinbx/aiinbx-py/compare/v0.661.0...v0.662.0)

### Features

* **api:** api update ([b9f9250](https://github.com/aiinbx/aiinbx-py/commit/b9f92507d0932517ad7b9d95a9167efddca3b420))

## 0.661.0 (2026-03-13)

Full Changelog: [v0.660.0...v0.661.0](https://github.com/aiinbx/aiinbx-py/compare/v0.660.0...v0.661.0)

### Features

* **api:** api update ([669087a](https://github.com/aiinbx/aiinbx-py/commit/669087a58f5c60b795b460a56ed6876cb981ce65))

## 0.660.0 (2026-03-13)

Full Changelog: [v0.659.0...v0.660.0](https://github.com/aiinbx/aiinbx-py/compare/v0.659.0...v0.660.0)

### Features

* **api:** api update ([c939897](https://github.com/aiinbx/aiinbx-py/commit/c939897f08ac315262d155fdb2a84ac56ed17013))

## 0.659.0 (2026-03-13)

Full Changelog: [v0.658.0...v0.659.0](https://github.com/aiinbx/aiinbx-py/compare/v0.658.0...v0.659.0)

### Features

* **api:** api update ([8b2883f](https://github.com/aiinbx/aiinbx-py/commit/8b2883f0e7e970aa12752f8f335039730c9d10ab))

## 0.658.0 (2026-03-12)

Full Changelog: [v0.657.0...v0.658.0](https://github.com/aiinbx/aiinbx-py/compare/v0.657.0...v0.658.0)

### Features

* **api:** api update ([1d565aa](https://github.com/aiinbx/aiinbx-py/commit/1d565aafec030bb9c3b45461495ce1f6d348cc36))

## 0.657.0 (2026-03-12)

Full Changelog: [v0.656.0...v0.657.0](https://github.com/aiinbx/aiinbx-py/compare/v0.656.0...v0.657.0)

### Features

* **api:** api update ([ad8201d](https://github.com/aiinbx/aiinbx-py/commit/ad8201d66093428318ccf146224626765844040c))

## 0.656.0 (2026-03-12)

Full Changelog: [v0.655.0...v0.656.0](https://github.com/aiinbx/aiinbx-py/compare/v0.655.0...v0.656.0)

### Features

* **api:** api update ([42d0bc5](https://github.com/aiinbx/aiinbx-py/commit/42d0bc553e62cbc039d59411a05f05f2927af2f1))

## 0.655.0 (2026-03-12)

Full Changelog: [v0.654.0...v0.655.0](https://github.com/aiinbx/aiinbx-py/compare/v0.654.0...v0.655.0)

### Features

* **api:** api update ([c881a84](https://github.com/aiinbx/aiinbx-py/commit/c881a84380991c39aa2882b94b9bf5b7f18fd7b2))

## 0.654.0 (2026-03-12)

Full Changelog: [v0.653.0...v0.654.0](https://github.com/aiinbx/aiinbx-py/compare/v0.653.0...v0.654.0)

### Features

* **api:** api update ([457d9db](https://github.com/aiinbx/aiinbx-py/commit/457d9db9db7512226c7188c9e5778c4bd09967c8))

## 0.653.0 (2026-03-12)

Full Changelog: [v0.652.0...v0.653.0](https://github.com/aiinbx/aiinbx-py/compare/v0.652.0...v0.653.0)

### Features

* **api:** api update ([9ea0856](https://github.com/aiinbx/aiinbx-py/commit/9ea085605ae7d22c1e9e54c6c3eeb2ce00dedabb))

## 0.652.0 (2026-03-12)

Full Changelog: [v0.651.0...v0.652.0](https://github.com/aiinbx/aiinbx-py/compare/v0.651.0...v0.652.0)

### Features

* **api:** api update ([820a97d](https://github.com/aiinbx/aiinbx-py/commit/820a97dffe65e8f9afacf05778bcb66ade275d6f))
* **api:** api update ([4a0d976](https://github.com/aiinbx/aiinbx-py/commit/4a0d976cb01a46991a6df20f619490d98bf87c60))

## 0.651.0 (2026-03-12)

Full Changelog: [v0.650.0...v0.651.0](https://github.com/aiinbx/aiinbx-py/compare/v0.650.0...v0.651.0)

### Features

* **api:** api update ([f7fa139](https://github.com/aiinbx/aiinbx-py/commit/f7fa1394fbe3c556e884ae1888e52d9a3895c5b6))

## 0.650.0 (2026-03-12)

Full Changelog: [v0.649.0...v0.650.0](https://github.com/aiinbx/aiinbx-py/compare/v0.649.0...v0.650.0)

### Features

* **api:** api update ([f9e0520](https://github.com/aiinbx/aiinbx-py/commit/f9e0520b050edaa0d25e390f58d97065c644b679))

## 0.649.0 (2026-03-12)

Full Changelog: [v0.648.0...v0.649.0](https://github.com/aiinbx/aiinbx-py/compare/v0.648.0...v0.649.0)

### Features

* **api:** api update ([e5759e6](https://github.com/aiinbx/aiinbx-py/commit/e5759e630c7ac6283f1a114f9a518327c97b944c))

## 0.648.0 (2026-03-11)

Full Changelog: [v0.647.0...v0.648.0](https://github.com/aiinbx/aiinbx-py/compare/v0.647.0...v0.648.0)

### Features

* **api:** api update ([af7ef1d](https://github.com/aiinbx/aiinbx-py/commit/af7ef1d175c6062ff76e26561090eb17713db304))

## 0.647.0 (2026-03-11)

Full Changelog: [v0.646.0...v0.647.0](https://github.com/aiinbx/aiinbx-py/compare/v0.646.0...v0.647.0)

### Features

* **api:** api update ([b0ec1b8](https://github.com/aiinbx/aiinbx-py/commit/b0ec1b809fb6f98f49f842098df427d250bb5aa2))

## 0.646.0 (2026-03-11)

Full Changelog: [v0.645.0...v0.646.0](https://github.com/aiinbx/aiinbx-py/compare/v0.645.0...v0.646.0)

### Features

* **api:** api update ([52e4f48](https://github.com/aiinbx/aiinbx-py/commit/52e4f48146efbb133a4fc692f4e40b528cae999f))

## 0.645.0 (2026-03-11)

Full Changelog: [v0.644.0...v0.645.0](https://github.com/aiinbx/aiinbx-py/compare/v0.644.0...v0.645.0)

### Features

* **api:** api update ([2a7dd38](https://github.com/aiinbx/aiinbx-py/commit/2a7dd38c7322f8403efee2b75948a82cd5d01115))

## 0.644.0 (2026-03-11)

Full Changelog: [v0.643.0...v0.644.0](https://github.com/aiinbx/aiinbx-py/compare/v0.643.0...v0.644.0)

### Features

* **api:** api update ([4e7962f](https://github.com/aiinbx/aiinbx-py/commit/4e7962f093ad8437452b454427bdb1d2e2a60a43))

## 0.643.0 (2026-03-11)

Full Changelog: [v0.642.0...v0.643.0](https://github.com/aiinbx/aiinbx-py/compare/v0.642.0...v0.643.0)

### Features

* **api:** api update ([8fd1f01](https://github.com/aiinbx/aiinbx-py/commit/8fd1f016a2299a93d41b04ebf75692a70bb98930))

## 0.642.0 (2026-03-11)

Full Changelog: [v0.641.0...v0.642.0](https://github.com/aiinbx/aiinbx-py/compare/v0.641.0...v0.642.0)

### Features

* **api:** api update ([416fc8b](https://github.com/aiinbx/aiinbx-py/commit/416fc8be0ae26033e3336cc1932837f0cc1da61d))

## 0.641.0 (2026-03-10)

Full Changelog: [v0.640.0...v0.641.0](https://github.com/aiinbx/aiinbx-py/compare/v0.640.0...v0.641.0)

### Features

* **api:** api update ([be44786](https://github.com/aiinbx/aiinbx-py/commit/be4478670b3565d8d1905f4bc4f4cc945e444bae))

## 0.640.0 (2026-03-10)

Full Changelog: [v0.639.0...v0.640.0](https://github.com/aiinbx/aiinbx-py/compare/v0.639.0...v0.640.0)

### Features

* **api:** api update ([39ad0af](https://github.com/aiinbx/aiinbx-py/commit/39ad0afef3a3d0a702a05fcdcb42d4e9289ef2d8))

## 0.639.0 (2026-03-10)

Full Changelog: [v0.638.0...v0.639.0](https://github.com/aiinbx/aiinbx-py/compare/v0.638.0...v0.639.0)

### Features

* **api:** api update ([f735921](https://github.com/aiinbx/aiinbx-py/commit/f7359210fd33433e6c405617a2e6b2dd9077c045))

## 0.638.0 (2026-03-10)

Full Changelog: [v0.637.0...v0.638.0](https://github.com/aiinbx/aiinbx-py/compare/v0.637.0...v0.638.0)

### Features

* **api:** api update ([b458caf](https://github.com/aiinbx/aiinbx-py/commit/b458caf716308845ef68f389054c4bb178e64999))

## 0.637.0 (2026-03-10)

Full Changelog: [v0.636.0...v0.637.0](https://github.com/aiinbx/aiinbx-py/compare/v0.636.0...v0.637.0)

### Features

* **api:** api update ([527de94](https://github.com/aiinbx/aiinbx-py/commit/527de94bd11f6882483cb75068496768fc358864))

## 0.636.0 (2026-03-10)

Full Changelog: [v0.635.0...v0.636.0](https://github.com/aiinbx/aiinbx-py/compare/v0.635.0...v0.636.0)

### Features

* **api:** api update ([d41fab0](https://github.com/aiinbx/aiinbx-py/commit/d41fab01dc4ce4d26f2b5eefccd67a309e338ca8))

## 0.635.0 (2026-03-10)

Full Changelog: [v0.634.0...v0.635.0](https://github.com/aiinbx/aiinbx-py/compare/v0.634.0...v0.635.0)

### Features

* **api:** api update ([04c3eb4](https://github.com/aiinbx/aiinbx-py/commit/04c3eb4b54cdcfb874069d0fed6b539d9057ade1))

## 0.634.0 (2026-03-09)

Full Changelog: [v0.633.0...v0.634.0](https://github.com/aiinbx/aiinbx-py/compare/v0.633.0...v0.634.0)

### Features

* **api:** api update ([6790ff9](https://github.com/aiinbx/aiinbx-py/commit/6790ff9d7e24c5a232a75a5deb188ed98da69c7a))

## 0.633.0 (2026-03-09)

Full Changelog: [v0.632.0...v0.633.0](https://github.com/aiinbx/aiinbx-py/compare/v0.632.0...v0.633.0)

### Features

* **api:** api update ([f4695a1](https://github.com/aiinbx/aiinbx-py/commit/f4695a19beb579f356a6f7f9599d18e80dc9d650))

## 0.632.0 (2026-03-09)

Full Changelog: [v0.631.0...v0.632.0](https://github.com/aiinbx/aiinbx-py/compare/v0.631.0...v0.632.0)

### Features

* **api:** api update ([314f66f](https://github.com/aiinbx/aiinbx-py/commit/314f66fe0eb7b3015c1ded421bb70c32371b50fb))

## 0.631.0 (2026-03-09)

Full Changelog: [v0.630.0...v0.631.0](https://github.com/aiinbx/aiinbx-py/compare/v0.630.0...v0.631.0)

### Features

* **api:** api update ([0f15b58](https://github.com/aiinbx/aiinbx-py/commit/0f15b589e58903f4dcb93f8298b48d535a17f2df))

## 0.630.0 (2026-03-09)

Full Changelog: [v0.629.0...v0.630.0](https://github.com/aiinbx/aiinbx-py/compare/v0.629.0...v0.630.0)

### Features

* **api:** api update ([c6347cb](https://github.com/aiinbx/aiinbx-py/commit/c6347cbdc87999cd0e9acfc827ad8976c7ea37ed))

## 0.629.0 (2026-03-09)

Full Changelog: [v0.628.0...v0.629.0](https://github.com/aiinbx/aiinbx-py/compare/v0.628.0...v0.629.0)

### Features

* **api:** api update ([9a3e2a4](https://github.com/aiinbx/aiinbx-py/commit/9a3e2a40f014fef004b1fb76d164802460531853))

## 0.628.0 (2026-03-09)

Full Changelog: [v0.627.0...v0.628.0](https://github.com/aiinbx/aiinbx-py/compare/v0.627.0...v0.628.0)

### Features

* **api:** api update ([34ab6f4](https://github.com/aiinbx/aiinbx-py/commit/34ab6f4bec41c3eab055aef13e341ddbf7a7fdcc))

## 0.627.0 (2026-03-09)

Full Changelog: [v0.626.0...v0.627.0](https://github.com/aiinbx/aiinbx-py/compare/v0.626.0...v0.627.0)

### Features

* **api:** api update ([65b2deb](https://github.com/aiinbx/aiinbx-py/commit/65b2deb592a8b88aafbaacd271a807b840032a1d))

## 0.626.0 (2026-03-09)

Full Changelog: [v0.625.0...v0.626.0](https://github.com/aiinbx/aiinbx-py/compare/v0.625.0...v0.626.0)

### Features

* **api:** api update ([9e83763](https://github.com/aiinbx/aiinbx-py/commit/9e837637e23e6b4d0b676b861cb106b5f020ef5f))

## 0.625.0 (2026-03-09)

Full Changelog: [v0.624.0...v0.625.0](https://github.com/aiinbx/aiinbx-py/compare/v0.624.0...v0.625.0)

### Features

* **api:** api update ([4ab5c26](https://github.com/aiinbx/aiinbx-py/commit/4ab5c26bc0e2f53e5343351ff39ea70e7c522655))

## 0.624.0 (2026-03-09)

Full Changelog: [v0.623.0...v0.624.0](https://github.com/aiinbx/aiinbx-py/compare/v0.623.0...v0.624.0)

### Features

* **api:** api update ([191d7d9](https://github.com/aiinbx/aiinbx-py/commit/191d7d9f4c94608fb21d3c9d28f89b05d731889d))

## 0.623.0 (2026-03-09)

Full Changelog: [v0.622.0...v0.623.0](https://github.com/aiinbx/aiinbx-py/compare/v0.622.0...v0.623.0)

### Features

* **api:** api update ([3deecad](https://github.com/aiinbx/aiinbx-py/commit/3deecade556f3a19db74b2684ae4758b01857fae))

## 0.622.0 (2026-03-09)

Full Changelog: [v0.621.0...v0.622.0](https://github.com/aiinbx/aiinbx-py/compare/v0.621.0...v0.622.0)

### Features

* **api:** api update ([28a797e](https://github.com/aiinbx/aiinbx-py/commit/28a797e598b36df04577e9269c14d9d8f101e4af))

## 0.621.0 (2026-03-08)

Full Changelog: [v0.620.0...v0.621.0](https://github.com/aiinbx/aiinbx-py/compare/v0.620.0...v0.621.0)

### Features

* **api:** api update ([7895dbe](https://github.com/aiinbx/aiinbx-py/commit/7895dbe01fb706d9b94e9f357cb6cdce68d94648))

## 0.620.0 (2026-03-08)

Full Changelog: [v0.619.0...v0.620.0](https://github.com/aiinbx/aiinbx-py/compare/v0.619.0...v0.620.0)

### Features

* **api:** api update ([64ff142](https://github.com/aiinbx/aiinbx-py/commit/64ff142210f9b7518260233196c728e3e4adb437))

## 0.619.0 (2026-03-08)

Full Changelog: [v0.618.0...v0.619.0](https://github.com/aiinbx/aiinbx-py/compare/v0.618.0...v0.619.0)

### Features

* **api:** api update ([1c1efff](https://github.com/aiinbx/aiinbx-py/commit/1c1efffd999e7d1a660c6f7635c92fe984a1710c))

## 0.618.0 (2026-03-08)

Full Changelog: [v0.617.0...v0.618.0](https://github.com/aiinbx/aiinbx-py/compare/v0.617.0...v0.618.0)

### Features

* **api:** api update ([b943bab](https://github.com/aiinbx/aiinbx-py/commit/b943bab2c23993bdf5e9305f247e942135e148c7))

## 0.617.0 (2026-03-08)

Full Changelog: [v0.616.0...v0.617.0](https://github.com/aiinbx/aiinbx-py/compare/v0.616.0...v0.617.0)

### Features

* **api:** api update ([86ad674](https://github.com/aiinbx/aiinbx-py/commit/86ad674bb59e1302187d66d4b6c894456dcf4562))

## 0.616.0 (2026-03-08)

Full Changelog: [v0.615.0...v0.616.0](https://github.com/aiinbx/aiinbx-py/compare/v0.615.0...v0.616.0)

### Features

* **api:** api update ([439b726](https://github.com/aiinbx/aiinbx-py/commit/439b72641cda09bffc47ba0ad3b00a72c741913a))

## 0.615.0 (2026-03-08)

Full Changelog: [v0.614.0...v0.615.0](https://github.com/aiinbx/aiinbx-py/compare/v0.614.0...v0.615.0)

### Features

* **api:** api update ([a3349fc](https://github.com/aiinbx/aiinbx-py/commit/a3349fc49a0a625cf96a5429553ae8b172af2313))

## 0.614.0 (2026-03-08)

Full Changelog: [v0.613.0...v0.614.0](https://github.com/aiinbx/aiinbx-py/compare/v0.613.0...v0.614.0)

### Features

* **api:** api update ([8f0b7c1](https://github.com/aiinbx/aiinbx-py/commit/8f0b7c143024f137334246338d63ad4b651a087a))

## 0.613.0 (2026-03-08)

Full Changelog: [v0.612.0...v0.613.0](https://github.com/aiinbx/aiinbx-py/compare/v0.612.0...v0.613.0)

### Features

* **api:** api update ([56650a4](https://github.com/aiinbx/aiinbx-py/commit/56650a4d4fb439d1ddd09eb5f1dd905d70d10477))

## 0.612.0 (2026-03-08)

Full Changelog: [v0.611.0...v0.612.0](https://github.com/aiinbx/aiinbx-py/compare/v0.611.0...v0.612.0)

### Features

* **api:** api update ([7054e6b](https://github.com/aiinbx/aiinbx-py/commit/7054e6b442759c7edeefef2523bb2b97523f5c64))

## 0.611.0 (2026-03-08)

Full Changelog: [v0.610.0...v0.611.0](https://github.com/aiinbx/aiinbx-py/compare/v0.610.0...v0.611.0)

### Features

* **api:** api update ([496e71a](https://github.com/aiinbx/aiinbx-py/commit/496e71aaa637a20965cddede0bcaeda88d19486e))

## 0.610.0 (2026-03-08)

Full Changelog: [v0.609.0...v0.610.0](https://github.com/aiinbx/aiinbx-py/compare/v0.609.0...v0.610.0)

### Features

* **api:** api update ([103a913](https://github.com/aiinbx/aiinbx-py/commit/103a9136fd931c982538d6efe8d0428af633298a))

## 0.609.0 (2026-03-07)

Full Changelog: [v0.608.0...v0.609.0](https://github.com/aiinbx/aiinbx-py/compare/v0.608.0...v0.609.0)

### Features

* **api:** api update ([7ea4561](https://github.com/aiinbx/aiinbx-py/commit/7ea45616e60ced441cba995ebb4d9163c16cfaed))

## 0.608.0 (2026-03-07)

Full Changelog: [v0.607.0...v0.608.0](https://github.com/aiinbx/aiinbx-py/compare/v0.607.0...v0.608.0)

### Features

* **api:** api update ([631c4ef](https://github.com/aiinbx/aiinbx-py/commit/631c4efb119608c0e45609df4b29b126d0b1b249))


### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([54b7b89](https://github.com/aiinbx/aiinbx-py/commit/54b7b89a0da269e8a0a450d01312781490186fa3))

## 0.607.0 (2026-03-07)

Full Changelog: [v0.606.0...v0.607.0](https://github.com/aiinbx/aiinbx-py/compare/v0.606.0...v0.607.0)

### Features

* **api:** api update ([57cae9d](https://github.com/aiinbx/aiinbx-py/commit/57cae9d3621c322844cb9e7b1e194eb390e436ed))

## 0.606.0 (2026-03-07)

Full Changelog: [v0.605.0...v0.606.0](https://github.com/aiinbx/aiinbx-py/compare/v0.605.0...v0.606.0)

### Features

* **api:** api update ([b3ac23d](https://github.com/aiinbx/aiinbx-py/commit/b3ac23dd87a8a1f2be041be93d38646e9686af94))

## 0.605.0 (2026-03-07)

Full Changelog: [v0.604.0...v0.605.0](https://github.com/aiinbx/aiinbx-py/compare/v0.604.0...v0.605.0)

### Features

* **api:** api update ([bf6ecf3](https://github.com/aiinbx/aiinbx-py/commit/bf6ecf30c25987f23ce7c9939b92a18c43e5e0db))

## 0.604.0 (2026-03-07)

Full Changelog: [v0.603.0...v0.604.0](https://github.com/aiinbx/aiinbx-py/compare/v0.603.0...v0.604.0)

### Features

* **api:** api update ([cd87b00](https://github.com/aiinbx/aiinbx-py/commit/cd87b00f5bc45b7f9bb1d23d6fb87ebff20e5e62))

## 0.603.0 (2026-03-07)

Full Changelog: [v0.602.0...v0.603.0](https://github.com/aiinbx/aiinbx-py/compare/v0.602.0...v0.603.0)

### Features

* **api:** api update ([058aff6](https://github.com/aiinbx/aiinbx-py/commit/058aff6dd851c63a26b89aa897f47b37dc985b5f))

## 0.602.0 (2026-03-07)

Full Changelog: [v0.601.0...v0.602.0](https://github.com/aiinbx/aiinbx-py/compare/v0.601.0...v0.602.0)

### Features

* **api:** api update ([a3720de](https://github.com/aiinbx/aiinbx-py/commit/a3720de0582a5861ab2b3b36707c7a7ed5bbc97a))

## 0.601.0 (2026-03-07)

Full Changelog: [v0.600.0...v0.601.0](https://github.com/aiinbx/aiinbx-py/compare/v0.600.0...v0.601.0)

### Features

* **api:** api update ([5128cb3](https://github.com/aiinbx/aiinbx-py/commit/5128cb3bff1f7809597e112193c540b67836565f))

## 0.600.0 (2026-03-07)

Full Changelog: [v0.599.0...v0.600.0](https://github.com/aiinbx/aiinbx-py/compare/v0.599.0...v0.600.0)

### Features

* **api:** api update ([8c51508](https://github.com/aiinbx/aiinbx-py/commit/8c51508ff2532433fcecb9032adf3ccf6d92f11f))

## 0.599.0 (2026-03-07)

Full Changelog: [v0.598.0...v0.599.0](https://github.com/aiinbx/aiinbx-py/compare/v0.598.0...v0.599.0)

### Features

* **api:** api update ([f541694](https://github.com/aiinbx/aiinbx-py/commit/f541694810b6c2cc6e9ecaf04e3a2fb7a86524d3))

## 0.598.0 (2026-03-06)

Full Changelog: [v0.597.0...v0.598.0](https://github.com/aiinbx/aiinbx-py/compare/v0.597.0...v0.598.0)

### Features

* **api:** api update ([0a25b0d](https://github.com/aiinbx/aiinbx-py/commit/0a25b0d7d36784a75563fa623532948abcaa7288))

## 0.597.0 (2026-03-06)

Full Changelog: [v0.596.0...v0.597.0](https://github.com/aiinbx/aiinbx-py/compare/v0.596.0...v0.597.0)

### Features

* **api:** api update ([a1a3fd6](https://github.com/aiinbx/aiinbx-py/commit/a1a3fd6df52184df315b3b1484dd4bb1bbcc5323))

## 0.596.0 (2026-03-06)

Full Changelog: [v0.595.0...v0.596.0](https://github.com/aiinbx/aiinbx-py/compare/v0.595.0...v0.596.0)

### Features

* **api:** api update ([9f4c5a2](https://github.com/aiinbx/aiinbx-py/commit/9f4c5a21e6430049c8ad88be7776f915518569f6))

## 0.595.0 (2026-03-06)

Full Changelog: [v0.594.0...v0.595.0](https://github.com/aiinbx/aiinbx-py/compare/v0.594.0...v0.595.0)

### Features

* **api:** api update ([f764c4e](https://github.com/aiinbx/aiinbx-py/commit/f764c4ee53b2a57d1ecddf5572aaa5f96113feaa))

## 0.594.0 (2026-03-06)

Full Changelog: [v0.593.0...v0.594.0](https://github.com/aiinbx/aiinbx-py/compare/v0.593.0...v0.594.0)

### Features

* **api:** api update ([5586c4f](https://github.com/aiinbx/aiinbx-py/commit/5586c4fe4c54b00fa08c3c1e586fc79052514922))
* **api:** api update ([28aae16](https://github.com/aiinbx/aiinbx-py/commit/28aae1679fb35c8455362cae8bf4d9364c9f7737))

## 0.593.0 (2026-03-06)

Full Changelog: [v0.592.0...v0.593.0](https://github.com/aiinbx/aiinbx-py/compare/v0.592.0...v0.593.0)

### Features

* **api:** api update ([257f41f](https://github.com/aiinbx/aiinbx-py/commit/257f41f23c2718e3c241e168756f289090822a2f))
* **api:** api update ([d5fc67e](https://github.com/aiinbx/aiinbx-py/commit/d5fc67eb2194aedb4d924253391f0311251f83a9))

## 0.592.0 (2026-03-05)

Full Changelog: [v0.591.0...v0.592.0](https://github.com/aiinbx/aiinbx-py/compare/v0.591.0...v0.592.0)

### Features

* **api:** api update ([2fe08bd](https://github.com/aiinbx/aiinbx-py/commit/2fe08bd2d2aeec4ccb33697348ba7eac45fa8b95))

## 0.591.0 (2026-03-05)

Full Changelog: [v0.590.0...v0.591.0](https://github.com/aiinbx/aiinbx-py/compare/v0.590.0...v0.591.0)

### Features

* **api:** api update ([1dc30de](https://github.com/aiinbx/aiinbx-py/commit/1dc30de179922f5a1cc18bb3c4da87399b20ae15))

## 0.590.0 (2026-03-05)

Full Changelog: [v0.589.0...v0.590.0](https://github.com/aiinbx/aiinbx-py/compare/v0.589.0...v0.590.0)

### Features

* **api:** api update ([00773fb](https://github.com/aiinbx/aiinbx-py/commit/00773fbc5f4daf0bdb0e0912414de2b60ed37557))

## 0.589.0 (2026-03-05)

Full Changelog: [v0.588.0...v0.589.0](https://github.com/aiinbx/aiinbx-py/compare/v0.588.0...v0.589.0)

### Features

* **api:** api update ([c3d3ee5](https://github.com/aiinbx/aiinbx-py/commit/c3d3ee5cdca96d69a3fe32a2af2d8109d2c924aa))
* **api:** api update ([c4d36cc](https://github.com/aiinbx/aiinbx-py/commit/c4d36cc918b627ce37e7c73e079820cbc7151499))

## 0.588.0 (2026-03-05)

Full Changelog: [v0.587.0...v0.588.0](https://github.com/aiinbx/aiinbx-py/compare/v0.587.0...v0.588.0)

### Features

* **api:** api update ([1929a62](https://github.com/aiinbx/aiinbx-py/commit/1929a624c4970878868065d7c34025e0137d7f37))

## 0.587.0 (2026-03-05)

Full Changelog: [v0.586.0...v0.587.0](https://github.com/aiinbx/aiinbx-py/compare/v0.586.0...v0.587.0)

### Features

* **api:** api update ([07fa36c](https://github.com/aiinbx/aiinbx-py/commit/07fa36c93de0ce8ebe18c5438325d950375283f9))

## 0.586.0 (2026-03-05)

Full Changelog: [v0.585.0...v0.586.0](https://github.com/aiinbx/aiinbx-py/compare/v0.585.0...v0.586.0)

### Features

* **api:** api update ([cb3dca1](https://github.com/aiinbx/aiinbx-py/commit/cb3dca11cb96ab58f5e3656fe78edd374a5232c0))

## 0.585.0 (2026-03-05)

Full Changelog: [v0.584.0...v0.585.0](https://github.com/aiinbx/aiinbx-py/compare/v0.584.0...v0.585.0)

### Features

* **api:** api update ([f66efb9](https://github.com/aiinbx/aiinbx-py/commit/f66efb92a3e749ac6c82e09a28c574e2a4596283))

## 0.584.0 (2026-03-05)

Full Changelog: [v0.583.0...v0.584.0](https://github.com/aiinbx/aiinbx-py/compare/v0.583.0...v0.584.0)

### Features

* **api:** api update ([d014c27](https://github.com/aiinbx/aiinbx-py/commit/d014c27ab5a73385294bf1a2f2e6da9c39212bb8))

## 0.583.0 (2026-03-05)

Full Changelog: [v0.582.0...v0.583.0](https://github.com/aiinbx/aiinbx-py/compare/v0.582.0...v0.583.0)

### Features

* **api:** api update ([d9a3ce1](https://github.com/aiinbx/aiinbx-py/commit/d9a3ce1737f266838ed4ff7b5b35f722ee20012a))

## 0.582.0 (2026-03-05)

Full Changelog: [v0.581.0...v0.582.0](https://github.com/aiinbx/aiinbx-py/compare/v0.581.0...v0.582.0)

### Features

* **api:** api update ([7f87b47](https://github.com/aiinbx/aiinbx-py/commit/7f87b472fcb64941bd6d46a061eb33aa7df40db9))

## 0.581.0 (2026-03-05)

Full Changelog: [v0.580.0...v0.581.0](https://github.com/aiinbx/aiinbx-py/compare/v0.580.0...v0.581.0)

### Features

* **api:** api update ([bccad7d](https://github.com/aiinbx/aiinbx-py/commit/bccad7d84d5517c45658f0280411293264d55fd8))

## 0.580.0 (2026-03-05)

Full Changelog: [v0.579.0...v0.580.0](https://github.com/aiinbx/aiinbx-py/compare/v0.579.0...v0.580.0)

### Features

* **api:** api update ([6fabde7](https://github.com/aiinbx/aiinbx-py/commit/6fabde752f7f3036e3c8edf7315d94cd000b2222))

## 0.579.0 (2026-03-05)

Full Changelog: [v0.578.0...v0.579.0](https://github.com/aiinbx/aiinbx-py/compare/v0.578.0...v0.579.0)

### Features

* **api:** api update ([7a96f34](https://github.com/aiinbx/aiinbx-py/commit/7a96f349c1a6f43406e4145a1b95ca0af83ec86d))

## 0.578.0 (2026-03-05)

Full Changelog: [v0.577.0...v0.578.0](https://github.com/aiinbx/aiinbx-py/compare/v0.577.0...v0.578.0)

### Features

* **api:** api update ([31dd2d1](https://github.com/aiinbx/aiinbx-py/commit/31dd2d199f4de60bd794c1d6caa5c9e806f4f2db))

## 0.577.0 (2026-03-05)

Full Changelog: [v0.576.0...v0.577.0](https://github.com/aiinbx/aiinbx-py/compare/v0.576.0...v0.577.0)

### Features

* **api:** api update ([c656f9e](https://github.com/aiinbx/aiinbx-py/commit/c656f9eaa3a53164aef3a7032a4aec1fb82fb437))

## 0.576.0 (2026-03-04)

Full Changelog: [v0.575.0...v0.576.0](https://github.com/aiinbx/aiinbx-py/compare/v0.575.0...v0.576.0)

### Features

* **api:** api update ([6f295fd](https://github.com/aiinbx/aiinbx-py/commit/6f295fd970a03efa75178f15b77dbca4b8044bf5))

## 0.575.0 (2026-03-04)

Full Changelog: [v0.574.0...v0.575.0](https://github.com/aiinbx/aiinbx-py/compare/v0.574.0...v0.575.0)

### Features

* **api:** api update ([fe61af4](https://github.com/aiinbx/aiinbx-py/commit/fe61af490420f3981dcc6e0822dba8dd478045a6))

## 0.574.0 (2026-03-04)

Full Changelog: [v0.573.0...v0.574.0](https://github.com/aiinbx/aiinbx-py/compare/v0.573.0...v0.574.0)

### Features

* **api:** api update ([3a99338](https://github.com/aiinbx/aiinbx-py/commit/3a99338aa4ea0ca45fde52b82aa5eb8871c1c3a7))

## 0.573.0 (2026-03-04)

Full Changelog: [v0.572.0...v0.573.0](https://github.com/aiinbx/aiinbx-py/compare/v0.572.0...v0.573.0)

### Features

* **api:** api update ([0562b72](https://github.com/aiinbx/aiinbx-py/commit/0562b7243f724a13069068f486cad031c1929084))

## 0.572.0 (2026-03-04)

Full Changelog: [v0.571.0...v0.572.0](https://github.com/aiinbx/aiinbx-py/compare/v0.571.0...v0.572.0)

### Features

* **api:** api update ([44c3aff](https://github.com/aiinbx/aiinbx-py/commit/44c3aff040324caa586e31033dbdd9e2148b2cfa))

## 0.571.0 (2026-03-04)

Full Changelog: [v0.570.0...v0.571.0](https://github.com/aiinbx/aiinbx-py/compare/v0.570.0...v0.571.0)

### Features

* **api:** api update ([2b0fb3a](https://github.com/aiinbx/aiinbx-py/commit/2b0fb3a9c96a0d26c866a579c23a7392ac58d271))

## 0.570.0 (2026-03-04)

Full Changelog: [v0.569.0...v0.570.0](https://github.com/aiinbx/aiinbx-py/compare/v0.569.0...v0.570.0)

### Features

* **api:** api update ([d504e24](https://github.com/aiinbx/aiinbx-py/commit/d504e24709f062ae9ce5c869e6a41221cf247244))

## 0.569.0 (2026-03-04)

Full Changelog: [v0.568.0...v0.569.0](https://github.com/aiinbx/aiinbx-py/compare/v0.568.0...v0.569.0)

### Features

* **api:** api update ([d4032d2](https://github.com/aiinbx/aiinbx-py/commit/d4032d2be0f1e8949d57270545ed583a3da5c8f1))

## 0.568.0 (2026-03-04)

Full Changelog: [v0.567.0...v0.568.0](https://github.com/aiinbx/aiinbx-py/compare/v0.567.0...v0.568.0)

### Features

* **api:** api update ([c7dc527](https://github.com/aiinbx/aiinbx-py/commit/c7dc52722f019aa3111011fcb80fe349955ff04c))

## 0.567.0 (2026-03-04)

Full Changelog: [v0.566.0...v0.567.0](https://github.com/aiinbx/aiinbx-py/compare/v0.566.0...v0.567.0)

### Features

* **api:** api update ([dd5cac0](https://github.com/aiinbx/aiinbx-py/commit/dd5cac0d37a909d23e5605b5d62be89f83d854fc))

## 0.566.0 (2026-03-04)

Full Changelog: [v0.565.0...v0.566.0](https://github.com/aiinbx/aiinbx-py/compare/v0.565.0...v0.566.0)

### Features

* **api:** api update ([4abbd1a](https://github.com/aiinbx/aiinbx-py/commit/4abbd1a7cde8afc1668c2ffb98390b985402a078))

## 0.565.0 (2026-03-04)

Full Changelog: [v0.564.0...v0.565.0](https://github.com/aiinbx/aiinbx-py/compare/v0.564.0...v0.565.0)

### Features

* **api:** api update ([00a54b7](https://github.com/aiinbx/aiinbx-py/commit/00a54b7f70061ec419cd93e51073871e6b9a6147))

## 0.564.0 (2026-03-04)

Full Changelog: [v0.563.0...v0.564.0](https://github.com/aiinbx/aiinbx-py/compare/v0.563.0...v0.564.0)

### Features

* **api:** api update ([aa5b4dc](https://github.com/aiinbx/aiinbx-py/commit/aa5b4dc6e396039aa07ea82b4fff84a3fc8e6cdd))

## 0.563.0 (2026-03-04)

Full Changelog: [v0.562.0...v0.563.0](https://github.com/aiinbx/aiinbx-py/compare/v0.562.0...v0.563.0)

### Features

* **api:** api update ([4bcae2e](https://github.com/aiinbx/aiinbx-py/commit/4bcae2ece9ab97e5189f1b8d2df33116e38cbfc2))

## 0.562.0 (2026-03-04)

Full Changelog: [v0.561.0...v0.562.0](https://github.com/aiinbx/aiinbx-py/compare/v0.561.0...v0.562.0)

### Features

* **api:** api update ([f9bc193](https://github.com/aiinbx/aiinbx-py/commit/f9bc19372925ec44a8c481cdb43caec78b1514a5))

## 0.561.0 (2026-03-03)

Full Changelog: [v0.560.0...v0.561.0](https://github.com/aiinbx/aiinbx-py/compare/v0.560.0...v0.561.0)

### Features

* **api:** api update ([56ca4a3](https://github.com/aiinbx/aiinbx-py/commit/56ca4a3c7ff96335bb0568609c0b8e0fea41cd3b))

## 0.560.0 (2026-03-03)

Full Changelog: [v0.559.0...v0.560.0](https://github.com/aiinbx/aiinbx-py/compare/v0.559.0...v0.560.0)

### Features

* **api:** api update ([ac810ea](https://github.com/aiinbx/aiinbx-py/commit/ac810eac0491176985541bd45d31aae621557311))

## 0.559.0 (2026-03-03)

Full Changelog: [v0.558.0...v0.559.0](https://github.com/aiinbx/aiinbx-py/compare/v0.558.0...v0.559.0)

### Features

* **api:** api update ([2637dce](https://github.com/aiinbx/aiinbx-py/commit/2637dce3cd554d330db6334bce945be568f4d55f))

## 0.558.0 (2026-03-03)

Full Changelog: [v0.557.0...v0.558.0](https://github.com/aiinbx/aiinbx-py/compare/v0.557.0...v0.558.0)

### Features

* **api:** api update ([bc0464a](https://github.com/aiinbx/aiinbx-py/commit/bc0464a071107ba288c7794a0fbd1c332863ca8d))

## 0.557.0 (2026-03-03)

Full Changelog: [v0.556.0...v0.557.0](https://github.com/aiinbx/aiinbx-py/compare/v0.556.0...v0.557.0)

### Features

* **api:** api update ([b2ec3c3](https://github.com/aiinbx/aiinbx-py/commit/b2ec3c3973c8f9be982934e6e27868aebe76d5af))

## 0.556.0 (2026-03-03)

Full Changelog: [v0.555.0...v0.556.0](https://github.com/aiinbx/aiinbx-py/compare/v0.555.0...v0.556.0)

### Features

* **api:** api update ([b5544c2](https://github.com/aiinbx/aiinbx-py/commit/b5544c223c3727ddf3a03a14b88dd2adb8c5bac9))

## 0.555.0 (2026-03-03)

Full Changelog: [v0.554.0...v0.555.0](https://github.com/aiinbx/aiinbx-py/compare/v0.554.0...v0.555.0)

### Features

* **api:** api update ([823f108](https://github.com/aiinbx/aiinbx-py/commit/823f1080ce0b535741a16498d93d10fd22995050))

## 0.554.0 (2026-03-03)

Full Changelog: [v0.553.0...v0.554.0](https://github.com/aiinbx/aiinbx-py/compare/v0.553.0...v0.554.0)

### Features

* **api:** api update ([e8ee289](https://github.com/aiinbx/aiinbx-py/commit/e8ee289ffdcb651adf8451d9de808346a428618f))

## 0.553.0 (2026-03-03)

Full Changelog: [v0.552.0...v0.553.0](https://github.com/aiinbx/aiinbx-py/compare/v0.552.0...v0.553.0)

### Features

* **api:** api update ([c087f4e](https://github.com/aiinbx/aiinbx-py/commit/c087f4e8ae78ad50d96631826a08a6077f812191))

## 0.552.0 (2026-03-03)

Full Changelog: [v0.551.0...v0.552.0](https://github.com/aiinbx/aiinbx-py/compare/v0.551.0...v0.552.0)

### Features

* **api:** api update ([6da36bb](https://github.com/aiinbx/aiinbx-py/commit/6da36bb8933edc5de70a6df1ca03a75ca2881316))

## 0.551.0 (2026-03-03)

Full Changelog: [v0.550.0...v0.551.0](https://github.com/aiinbx/aiinbx-py/compare/v0.550.0...v0.551.0)

### Features

* **api:** api update ([c6bab60](https://github.com/aiinbx/aiinbx-py/commit/c6bab605ddb9c7766cf93371d7f7a7952473a04a))

## 0.550.0 (2026-03-03)

Full Changelog: [v0.549.0...v0.550.0](https://github.com/aiinbx/aiinbx-py/compare/v0.549.0...v0.550.0)

### Features

* **api:** api update ([4f80f17](https://github.com/aiinbx/aiinbx-py/commit/4f80f174c4d9211b4ef488e521b7ba784891ebc4))

## 0.549.0 (2026-03-03)

Full Changelog: [v0.548.0...v0.549.0](https://github.com/aiinbx/aiinbx-py/compare/v0.548.0...v0.549.0)

### Features

* **api:** api update ([8281eb2](https://github.com/aiinbx/aiinbx-py/commit/8281eb2a71a8662bcaeca46dbe82bdc817dfd753))

## 0.548.0 (2026-03-02)

Full Changelog: [v0.547.0...v0.548.0](https://github.com/aiinbx/aiinbx-py/compare/v0.547.0...v0.548.0)

### Features

* **api:** api update ([e782f11](https://github.com/aiinbx/aiinbx-py/commit/e782f11d8ca560f28596de3b6234efc8d1a87604))

## 0.547.0 (2026-03-02)

Full Changelog: [v0.546.0...v0.547.0](https://github.com/aiinbx/aiinbx-py/compare/v0.546.0...v0.547.0)

### Features

* **api:** api update ([23567f9](https://github.com/aiinbx/aiinbx-py/commit/23567f9c99df9d2799653d5c79e7475d935d740d))

## 0.546.0 (2026-03-02)

Full Changelog: [v0.545.0...v0.546.0](https://github.com/aiinbx/aiinbx-py/compare/v0.545.0...v0.546.0)

### Features

* **api:** api update ([bc31333](https://github.com/aiinbx/aiinbx-py/commit/bc313333322ae3ba1f8e4f907765c2cdb0c3b8cb))

## 0.545.0 (2026-03-02)

Full Changelog: [v0.544.0...v0.545.0](https://github.com/aiinbx/aiinbx-py/compare/v0.544.0...v0.545.0)

### Features

* **api:** api update ([05a78e5](https://github.com/aiinbx/aiinbx-py/commit/05a78e54ca5ffaf84a8149565091b94b0bcc0ce1))

## 0.544.0 (2026-03-02)

Full Changelog: [v0.543.0...v0.544.0](https://github.com/aiinbx/aiinbx-py/compare/v0.543.0...v0.544.0)

### Features

* **api:** api update ([882b588](https://github.com/aiinbx/aiinbx-py/commit/882b588d3f76bfd2a30ce92872d5cb74f8eb9fe9))

## 0.543.0 (2026-03-02)

Full Changelog: [v0.542.0...v0.543.0](https://github.com/aiinbx/aiinbx-py/compare/v0.542.0...v0.543.0)

### Features

* **api:** api update ([3fdd81a](https://github.com/aiinbx/aiinbx-py/commit/3fdd81ac411b0573a4e11e386537b7cbfa44ed59))

## 0.542.0 (2026-03-02)

Full Changelog: [v0.541.0...v0.542.0](https://github.com/aiinbx/aiinbx-py/compare/v0.541.0...v0.542.0)

### Features

* **api:** api update ([65283ff](https://github.com/aiinbx/aiinbx-py/commit/65283ffb82a7abe243fd676159ec978d6251428f))

## 0.541.0 (2026-03-02)

Full Changelog: [v0.540.0...v0.541.0](https://github.com/aiinbx/aiinbx-py/compare/v0.540.0...v0.541.0)

### Features

* **api:** api update ([334b5c7](https://github.com/aiinbx/aiinbx-py/commit/334b5c7bb47ac330a9b9af4eccba7f51eace658a))

## 0.540.0 (2026-03-02)

Full Changelog: [v0.539.0...v0.540.0](https://github.com/aiinbx/aiinbx-py/compare/v0.539.0...v0.540.0)

### Features

* **api:** api update ([6950cd2](https://github.com/aiinbx/aiinbx-py/commit/6950cd22c0f319d39876d2d788cb7967658134e4))

## 0.539.0 (2026-03-02)

Full Changelog: [v0.538.0...v0.539.0](https://github.com/aiinbx/aiinbx-py/compare/v0.538.0...v0.539.0)

### Features

* **api:** api update ([0c7101e](https://github.com/aiinbx/aiinbx-py/commit/0c7101e37007dddf1d143e52af48c31de37d5431))

## 0.538.0 (2026-03-01)

Full Changelog: [v0.537.0...v0.538.0](https://github.com/aiinbx/aiinbx-py/compare/v0.537.0...v0.538.0)

### Features

* **api:** api update ([44dab11](https://github.com/aiinbx/aiinbx-py/commit/44dab11d1bed1673a0d24e50795e8f74de0157bc))

## 0.537.0 (2026-03-01)

Full Changelog: [v0.536.0...v0.537.0](https://github.com/aiinbx/aiinbx-py/compare/v0.536.0...v0.537.0)

### Features

* **api:** api update ([37a4bb1](https://github.com/aiinbx/aiinbx-py/commit/37a4bb1d62def65726ff0e3ac62cea914d15ef32))

## 0.536.0 (2026-03-01)

Full Changelog: [v0.535.0...v0.536.0](https://github.com/aiinbx/aiinbx-py/compare/v0.535.0...v0.536.0)

### Features

* **api:** api update ([51dd16e](https://github.com/aiinbx/aiinbx-py/commit/51dd16ece8b86846ecd503cd5f5da4b462487330))

## 0.535.0 (2026-03-01)

Full Changelog: [v0.534.0...v0.535.0](https://github.com/aiinbx/aiinbx-py/compare/v0.534.0...v0.535.0)

### Features

* **api:** api update ([a80cbe2](https://github.com/aiinbx/aiinbx-py/commit/a80cbe2e53b67f8bd947ae1e24579536de217165))

## 0.534.0 (2026-03-01)

Full Changelog: [v0.533.0...v0.534.0](https://github.com/aiinbx/aiinbx-py/compare/v0.533.0...v0.534.0)

### Features

* **api:** api update ([dc60f62](https://github.com/aiinbx/aiinbx-py/commit/dc60f620a8dabb17568dee03da4eceb775e20403))

## 0.533.0 (2026-03-01)

Full Changelog: [v0.532.0...v0.533.0](https://github.com/aiinbx/aiinbx-py/compare/v0.532.0...v0.533.0)

### Features

* **api:** api update ([b937605](https://github.com/aiinbx/aiinbx-py/commit/b937605cfc09cb3cb2eac002ce3ce7681e08ef07))

## 0.532.0 (2026-03-01)

Full Changelog: [v0.531.0...v0.532.0](https://github.com/aiinbx/aiinbx-py/compare/v0.531.0...v0.532.0)

### Features

* **api:** api update ([3972d85](https://github.com/aiinbx/aiinbx-py/commit/3972d856aad9393245de2475cf666cf7cc539d73))

## 0.531.0 (2026-03-01)

Full Changelog: [v0.530.0...v0.531.0](https://github.com/aiinbx/aiinbx-py/compare/v0.530.0...v0.531.0)

### Features

* **api:** api update ([270e283](https://github.com/aiinbx/aiinbx-py/commit/270e283123e7823fa642ca30295e85b5f3e07564))

## 0.530.0 (2026-03-01)

Full Changelog: [v0.529.0...v0.530.0](https://github.com/aiinbx/aiinbx-py/compare/v0.529.0...v0.530.0)

### Features

* **api:** api update ([e699506](https://github.com/aiinbx/aiinbx-py/commit/e699506e203df6a2a2cf6fb1d9c79a25436710c2))

## 0.529.0 (2026-03-01)

Full Changelog: [v0.528.0...v0.529.0](https://github.com/aiinbx/aiinbx-py/compare/v0.528.0...v0.529.0)

### Features

* **api:** api update ([c74fc0a](https://github.com/aiinbx/aiinbx-py/commit/c74fc0a0d9d1e4e11a24806a73f72c4f850550e7))

## 0.528.0 (2026-03-01)

Full Changelog: [v0.527.0...v0.528.0](https://github.com/aiinbx/aiinbx-py/compare/v0.527.0...v0.528.0)

### Features

* **api:** api update ([41cdfde](https://github.com/aiinbx/aiinbx-py/commit/41cdfde2fd82015eb3e7607783b1578e2a5b91ff))

## 0.527.0 (2026-03-01)

Full Changelog: [v0.526.0...v0.527.0](https://github.com/aiinbx/aiinbx-py/compare/v0.526.0...v0.527.0)

### Features

* **api:** api update ([72d2ac4](https://github.com/aiinbx/aiinbx-py/commit/72d2ac41418056174c242844ff43fb1bcd46d98c))

## 0.526.0 (2026-03-01)

Full Changelog: [v0.525.0...v0.526.0](https://github.com/aiinbx/aiinbx-py/compare/v0.525.0...v0.526.0)

### Features

* **api:** api update ([1697f0e](https://github.com/aiinbx/aiinbx-py/commit/1697f0ea41375e34bf1e5c5b14b5ca73d10dc31d))

## 0.525.0 (2026-03-01)

Full Changelog: [v0.524.0...v0.525.0](https://github.com/aiinbx/aiinbx-py/compare/v0.524.0...v0.525.0)

### Features

* **api:** api update ([8fded18](https://github.com/aiinbx/aiinbx-py/commit/8fded188fe8bac251578b90e495960b0fe468917))

## 0.524.0 (2026-03-01)

Full Changelog: [v0.523.0...v0.524.0](https://github.com/aiinbx/aiinbx-py/compare/v0.523.0...v0.524.0)

### Features

* **api:** api update ([3ee30df](https://github.com/aiinbx/aiinbx-py/commit/3ee30df91d18b80783b34746f431974ab9787b55))

## 0.523.0 (2026-02-28)

Full Changelog: [v0.522.0...v0.523.0](https://github.com/aiinbx/aiinbx-py/compare/v0.522.0...v0.523.0)

### Features

* **api:** api update ([71540a1](https://github.com/aiinbx/aiinbx-py/commit/71540a13580b3e4663da9dfd300d8092403bec46))
* **api:** api update ([5c6ee64](https://github.com/aiinbx/aiinbx-py/commit/5c6ee64f59f32c10a3c23f8022dae496f1cd6c75))

## 0.522.0 (2026-02-28)

Full Changelog: [v0.521.0...v0.522.0](https://github.com/aiinbx/aiinbx-py/compare/v0.521.0...v0.522.0)

### Features

* **api:** api update ([ecedcbb](https://github.com/aiinbx/aiinbx-py/commit/ecedcbb5c6311b36cad402f39bf72268b9d72fde))

## 0.521.0 (2026-02-28)

Full Changelog: [v0.520.0...v0.521.0](https://github.com/aiinbx/aiinbx-py/compare/v0.520.0...v0.521.0)

### Features

* **api:** api update ([31b6134](https://github.com/aiinbx/aiinbx-py/commit/31b61349665e4ee6524e8dd6e9055d6c423b1a76))

## 0.520.0 (2026-02-28)

Full Changelog: [v0.519.0...v0.520.0](https://github.com/aiinbx/aiinbx-py/compare/v0.519.0...v0.520.0)

### Features

* **api:** api update ([1a98fb6](https://github.com/aiinbx/aiinbx-py/commit/1a98fb6a1c9d4b729901c63bdf0b1559d31fba5b))

## 0.519.0 (2026-02-28)

Full Changelog: [v0.518.0...v0.519.0](https://github.com/aiinbx/aiinbx-py/compare/v0.518.0...v0.519.0)

### Features

* **api:** api update ([b2940c2](https://github.com/aiinbx/aiinbx-py/commit/b2940c2d7377c5353c9eaa625b27c361934bfc18))

## 0.518.0 (2026-02-28)

Full Changelog: [v0.517.0...v0.518.0](https://github.com/aiinbx/aiinbx-py/compare/v0.517.0...v0.518.0)

### Features

* **api:** api update ([80f4e7e](https://github.com/aiinbx/aiinbx-py/commit/80f4e7efdbf391561065f3779211406a33abab61))

## 0.517.0 (2026-02-28)

Full Changelog: [v0.516.0...v0.517.0](https://github.com/aiinbx/aiinbx-py/compare/v0.516.0...v0.517.0)

### Features

* **api:** api update ([3f990c0](https://github.com/aiinbx/aiinbx-py/commit/3f990c042351c302a0b7a9e231491f976df9232f))

## 0.516.0 (2026-02-27)

Full Changelog: [v0.515.0...v0.516.0](https://github.com/aiinbx/aiinbx-py/compare/v0.515.0...v0.516.0)

### Features

* **api:** api update ([7912cc9](https://github.com/aiinbx/aiinbx-py/commit/7912cc9e4424384dc97f10132c2362772a4d36ca))

## 0.515.0 (2026-02-27)

Full Changelog: [v0.514.0...v0.515.0](https://github.com/aiinbx/aiinbx-py/compare/v0.514.0...v0.515.0)

### Features

* **api:** api update ([7cc2153](https://github.com/aiinbx/aiinbx-py/commit/7cc2153243c688f15c2ad2b803e2d9255a258ec7))

## 0.514.0 (2026-02-27)

Full Changelog: [v0.513.0...v0.514.0](https://github.com/aiinbx/aiinbx-py/compare/v0.513.0...v0.514.0)

### Features

* **api:** api update ([f4780ef](https://github.com/aiinbx/aiinbx-py/commit/f4780ef6cbcc087cda4b225a38fe486ba733503e))

## 0.513.0 (2026-02-27)

Full Changelog: [v0.512.0...v0.513.0](https://github.com/aiinbx/aiinbx-py/compare/v0.512.0...v0.513.0)

### Features

* **api:** api update ([35d82b1](https://github.com/aiinbx/aiinbx-py/commit/35d82b1a4605efc1343292b9fb25067ee6c99a53))

## 0.512.0 (2026-02-27)

Full Changelog: [v0.511.0...v0.512.0](https://github.com/aiinbx/aiinbx-py/compare/v0.511.0...v0.512.0)

### Features

* **api:** api update ([472dfa6](https://github.com/aiinbx/aiinbx-py/commit/472dfa63b667f003491a2f1be29f25a6d98bb437))

## 0.511.0 (2026-02-27)

Full Changelog: [v0.510.0...v0.511.0](https://github.com/aiinbx/aiinbx-py/compare/v0.510.0...v0.511.0)

### Features

* **api:** api update ([70487be](https://github.com/aiinbx/aiinbx-py/commit/70487be951b0b5684a7e03772ec011b35efc7738))

## 0.510.0 (2026-02-26)

Full Changelog: [v0.509.0...v0.510.0](https://github.com/aiinbx/aiinbx-py/compare/v0.509.0...v0.510.0)

### Features

* **api:** api update ([249ce99](https://github.com/aiinbx/aiinbx-py/commit/249ce99f8b81fd68ac1782fb92c7e4becabd619a))
* **api:** api update ([088e5ec](https://github.com/aiinbx/aiinbx-py/commit/088e5ecff4e7aa2908d1833de17867f177d9cd66))

## 0.509.0 (2026-02-26)

Full Changelog: [v0.508.0...v0.509.0](https://github.com/aiinbx/aiinbx-py/compare/v0.508.0...v0.509.0)

### Features

* **api:** api update ([5a00776](https://github.com/aiinbx/aiinbx-py/commit/5a00776005d346d5ba3c3cec3c578de50823c594))

## 0.508.0 (2026-02-26)

Full Changelog: [v0.507.0...v0.508.0](https://github.com/aiinbx/aiinbx-py/compare/v0.507.0...v0.508.0)

### Features

* **api:** api update ([4869786](https://github.com/aiinbx/aiinbx-py/commit/48697867f0cff28db785ddd35128015e869d8041))

## 0.507.0 (2026-02-26)

Full Changelog: [v0.506.0...v0.507.0](https://github.com/aiinbx/aiinbx-py/compare/v0.506.0...v0.507.0)

### Features

* **api:** api update ([f0c9f36](https://github.com/aiinbx/aiinbx-py/commit/f0c9f36c02894179f26bc0d26409187cfbb4101c))

## 0.506.0 (2026-02-25)

Full Changelog: [v0.505.0...v0.506.0](https://github.com/aiinbx/aiinbx-py/compare/v0.505.0...v0.506.0)

### Features

* **api:** api update ([4d47c39](https://github.com/aiinbx/aiinbx-py/commit/4d47c3972371cc030cd4ff0a30cad65701705370))

## 0.505.0 (2026-02-25)

Full Changelog: [v0.504.0...v0.505.0](https://github.com/aiinbx/aiinbx-py/compare/v0.504.0...v0.505.0)

### Features

* **api:** api update ([51e1969](https://github.com/aiinbx/aiinbx-py/commit/51e1969d1776215f3732ddb8133b5906be4a2f51))

## 0.504.0 (2026-02-25)

Full Changelog: [v0.503.0...v0.504.0](https://github.com/aiinbx/aiinbx-py/compare/v0.503.0...v0.504.0)

### Features

* **api:** api update ([4b48e79](https://github.com/aiinbx/aiinbx-py/commit/4b48e793e22aa25dc3043d071d4ebb19e194fd6c))

## 0.503.0 (2026-02-25)

Full Changelog: [v0.502.0...v0.503.0](https://github.com/aiinbx/aiinbx-py/compare/v0.502.0...v0.503.0)

### Features

* **api:** api update ([1f31b3e](https://github.com/aiinbx/aiinbx-py/commit/1f31b3e9810787e1ab8ca81b847ea607449a36f0))

## 0.502.0 (2026-02-25)

Full Changelog: [v0.501.0...v0.502.0](https://github.com/aiinbx/aiinbx-py/compare/v0.501.0...v0.502.0)

### Features

* **api:** api update ([40c81fa](https://github.com/aiinbx/aiinbx-py/commit/40c81fac35b6521af22a46cff15f5a4156a7e313))


### Chores

* **internal:** make `test_proxy_environment_variables` more resilient to env ([b44bc1d](https://github.com/aiinbx/aiinbx-py/commit/b44bc1d1b79d608fd81dd1e23c33b0f9fe711800))

## 0.501.0 (2026-02-24)

Full Changelog: [v0.500.0...v0.501.0](https://github.com/aiinbx/aiinbx-py/compare/v0.500.0...v0.501.0)

### Features

* **api:** api update ([b714308](https://github.com/aiinbx/aiinbx-py/commit/b7143088644eda175a65cb3f0b77c08f2604ca90))

## 0.500.0 (2026-02-24)

Full Changelog: [v0.499.0...v0.500.0](https://github.com/aiinbx/aiinbx-py/compare/v0.499.0...v0.500.0)

### Features

* **api:** api update ([7369258](https://github.com/aiinbx/aiinbx-py/commit/7369258886c5d9d4576a4c89ab3dd7251a1d174b))

## 0.499.0 (2026-02-24)

Full Changelog: [v0.498.0...v0.499.0](https://github.com/aiinbx/aiinbx-py/compare/v0.498.0...v0.499.0)

### Features

* **api:** api update ([443e58d](https://github.com/aiinbx/aiinbx-py/commit/443e58d1a1f188c118af9eecceba6ce0e2bdf8d9))

## 0.498.0 (2026-02-24)

Full Changelog: [v0.497.0...v0.498.0](https://github.com/aiinbx/aiinbx-py/compare/v0.497.0...v0.498.0)

### Features

* **api:** api update ([9635c9d](https://github.com/aiinbx/aiinbx-py/commit/9635c9d15c494741bab71ec1f2c5fce89fc52fff))

## 0.497.0 (2026-02-24)

Full Changelog: [v0.496.0...v0.497.0](https://github.com/aiinbx/aiinbx-py/compare/v0.496.0...v0.497.0)

### Features

* **api:** api update ([7bdad09](https://github.com/aiinbx/aiinbx-py/commit/7bdad09c6f8c0a95516946c402c19d811947f5f0))


### Chores

* **internal:** add request options to SSE classes ([cc15103](https://github.com/aiinbx/aiinbx-py/commit/cc1510393136daaf9505b1f3ed48010a89cba9ba))
* **internal:** make `test_proxy_environment_variables` more resilient ([2b00a65](https://github.com/aiinbx/aiinbx-py/commit/2b00a65eecb0a3752b74765bc82c72b26059ecc9))

## 0.496.0 (2026-02-24)

Full Changelog: [v0.495.0...v0.496.0](https://github.com/aiinbx/aiinbx-py/compare/v0.495.0...v0.496.0)

### Features

* **api:** api update ([7521337](https://github.com/aiinbx/aiinbx-py/commit/752133737351c147c70872cb787eb13ed4899d75))

## 0.495.0 (2026-02-24)

Full Changelog: [v0.494.0...v0.495.0](https://github.com/aiinbx/aiinbx-py/compare/v0.494.0...v0.495.0)

### Features

* **api:** api update ([b4ba713](https://github.com/aiinbx/aiinbx-py/commit/b4ba71322dec4fce1ab5db5ee52cd22309c84756))

## 0.494.0 (2026-02-24)

Full Changelog: [v0.493.0...v0.494.0](https://github.com/aiinbx/aiinbx-py/compare/v0.493.0...v0.494.0)

### Features

* **api:** api update ([fa356e6](https://github.com/aiinbx/aiinbx-py/commit/fa356e6df7c9d687696abcc3d62de6a0811dfb10))

## 0.493.0 (2026-02-23)

Full Changelog: [v0.492.0...v0.493.0](https://github.com/aiinbx/aiinbx-py/compare/v0.492.0...v0.493.0)

### Features

* **api:** api update ([a88e77b](https://github.com/aiinbx/aiinbx-py/commit/a88e77beae893dff906d7c5fd0152cc481eb6472))

## 0.492.0 (2026-02-23)

Full Changelog: [v0.491.0...v0.492.0](https://github.com/aiinbx/aiinbx-py/compare/v0.491.0...v0.492.0)

### Features

* **api:** api update ([d4be3c3](https://github.com/aiinbx/aiinbx-py/commit/d4be3c3e34f30629f5d4dee4e4e7beb1978e0873))

## 0.491.0 (2026-02-23)

Full Changelog: [v0.490.0...v0.491.0](https://github.com/aiinbx/aiinbx-py/compare/v0.490.0...v0.491.0)

### Features

* **api:** api update ([b7efb42](https://github.com/aiinbx/aiinbx-py/commit/b7efb42d9a15637bdfa7bb11594b2272a0bc3d90))

## 0.490.0 (2026-02-23)

Full Changelog: [v0.489.0...v0.490.0](https://github.com/aiinbx/aiinbx-py/compare/v0.489.0...v0.490.0)

### Features

* **api:** api update ([6bbd726](https://github.com/aiinbx/aiinbx-py/commit/6bbd726c5a7dacd74d050323675f5a5c4bce49a4))

## 0.489.0 (2026-02-23)

Full Changelog: [v0.488.0...v0.489.0](https://github.com/aiinbx/aiinbx-py/compare/v0.488.0...v0.489.0)

### Features

* **api:** api update ([16d329c](https://github.com/aiinbx/aiinbx-py/commit/16d329cd1c7ca4a1c83e55783dde9714f49fe00f))

## 0.488.0 (2026-02-23)

Full Changelog: [v0.487.0...v0.488.0](https://github.com/aiinbx/aiinbx-py/compare/v0.487.0...v0.488.0)

### Features

* **api:** api update ([0bb6b57](https://github.com/aiinbx/aiinbx-py/commit/0bb6b57bf1c1e425185d4041f81bfac02f746e21))

## 0.487.0 (2026-02-22)

Full Changelog: [v0.486.0...v0.487.0](https://github.com/aiinbx/aiinbx-py/compare/v0.486.0...v0.487.0)

### Features

* **api:** api update ([1347032](https://github.com/aiinbx/aiinbx-py/commit/13470328f7e440153a62ff5444cc0cb4bee9933f))

## 0.486.0 (2026-02-22)

Full Changelog: [v0.485.0...v0.486.0](https://github.com/aiinbx/aiinbx-py/compare/v0.485.0...v0.486.0)

### Features

* **api:** api update ([904d94e](https://github.com/aiinbx/aiinbx-py/commit/904d94e1889a6f4b66dcad0fc3ec89ceb42d241e))

## 0.485.0 (2026-02-22)

Full Changelog: [v0.484.0...v0.485.0](https://github.com/aiinbx/aiinbx-py/compare/v0.484.0...v0.485.0)

### Features

* **api:** api update ([a4a7fef](https://github.com/aiinbx/aiinbx-py/commit/a4a7fef3465e374086d7d50ee012ccecbb49ad44))

## 0.484.0 (2026-02-22)

Full Changelog: [v0.483.0...v0.484.0](https://github.com/aiinbx/aiinbx-py/compare/v0.483.0...v0.484.0)

### Features

* **api:** api update ([4478469](https://github.com/aiinbx/aiinbx-py/commit/447846973e79b4e3346294f897fe32b55301373e))

## 0.483.0 (2026-02-22)

Full Changelog: [v0.482.0...v0.483.0](https://github.com/aiinbx/aiinbx-py/compare/v0.482.0...v0.483.0)

### Features

* **api:** api update ([871aa6c](https://github.com/aiinbx/aiinbx-py/commit/871aa6cfbd27dcded7e82b986e7f3a8bfac2de42))

## 0.482.0 (2026-02-22)

Full Changelog: [v0.481.0...v0.482.0](https://github.com/aiinbx/aiinbx-py/compare/v0.481.0...v0.482.0)

### Features

* **api:** api update ([ad852a3](https://github.com/aiinbx/aiinbx-py/commit/ad852a3bbc7521abc7796cad227eb68083ab2a33))

## 0.481.0 (2026-02-22)

Full Changelog: [v0.480.0...v0.481.0](https://github.com/aiinbx/aiinbx-py/compare/v0.480.0...v0.481.0)

### Features

* **api:** api update ([4ac9af7](https://github.com/aiinbx/aiinbx-py/commit/4ac9af74c16f25231f26cbde01c84aa327f3e13c))

## 0.480.0 (2026-02-22)

Full Changelog: [v0.479.0...v0.480.0](https://github.com/aiinbx/aiinbx-py/compare/v0.479.0...v0.480.0)

### Features

* **api:** api update ([bd86384](https://github.com/aiinbx/aiinbx-py/commit/bd863844dbb759cd65ffaf0c01ed61e48968b723))

## 0.479.0 (2026-02-22)

Full Changelog: [v0.478.0...v0.479.0](https://github.com/aiinbx/aiinbx-py/compare/v0.478.0...v0.479.0)

### Features

* **api:** api update ([fdf657f](https://github.com/aiinbx/aiinbx-py/commit/fdf657f6330737d41141cf398b7430968a11b08e))

## 0.478.0 (2026-02-22)

Full Changelog: [v0.477.0...v0.478.0](https://github.com/aiinbx/aiinbx-py/compare/v0.477.0...v0.478.0)

### Features

* **api:** api update ([514bde3](https://github.com/aiinbx/aiinbx-py/commit/514bde34ce6dcf96fed02ca3ffe28924e3fb0f29))

## 0.477.0 (2026-02-22)

Full Changelog: [v0.476.0...v0.477.0](https://github.com/aiinbx/aiinbx-py/compare/v0.476.0...v0.477.0)

### Features

* **api:** api update ([fe2e3b7](https://github.com/aiinbx/aiinbx-py/commit/fe2e3b7bb333b1832a94495fd02728b0db70d384))

## 0.476.0 (2026-02-21)

Full Changelog: [v0.475.0...v0.476.0](https://github.com/aiinbx/aiinbx-py/compare/v0.475.0...v0.476.0)

### Features

* **api:** api update ([f29a5fb](https://github.com/aiinbx/aiinbx-py/commit/f29a5fb88445d8f953f9c1d71d267a1e5d07c7bd))

## 0.475.0 (2026-02-21)

Full Changelog: [v0.474.0...v0.475.0](https://github.com/aiinbx/aiinbx-py/compare/v0.474.0...v0.475.0)

### Features

* **api:** api update ([c86de12](https://github.com/aiinbx/aiinbx-py/commit/c86de1219dc223d05457af5281ee64c09bb5e517))

## 0.474.0 (2026-02-21)

Full Changelog: [v0.473.0...v0.474.0](https://github.com/aiinbx/aiinbx-py/compare/v0.473.0...v0.474.0)

### Features

* **api:** api update ([63bb8e3](https://github.com/aiinbx/aiinbx-py/commit/63bb8e371e1444481ee14fdba6307372e7f69973))

## 0.473.0 (2026-02-21)

Full Changelog: [v0.472.0...v0.473.0](https://github.com/aiinbx/aiinbx-py/compare/v0.472.0...v0.473.0)

### Features

* **api:** api update ([0c4e610](https://github.com/aiinbx/aiinbx-py/commit/0c4e61055f1e172545c813fb670872e4c21754ee))

## 0.472.0 (2026-02-21)

Full Changelog: [v0.471.0...v0.472.0](https://github.com/aiinbx/aiinbx-py/compare/v0.471.0...v0.472.0)

### Features

* **api:** api update ([1d295c1](https://github.com/aiinbx/aiinbx-py/commit/1d295c137ba7f80be3dbb4f908c47043c791c849))

## 0.471.0 (2026-02-21)

Full Changelog: [v0.470.0...v0.471.0](https://github.com/aiinbx/aiinbx-py/compare/v0.470.0...v0.471.0)

### Features

* **api:** api update ([7f59aee](https://github.com/aiinbx/aiinbx-py/commit/7f59aeeb0e3bb15882c30b9486282fdb8a4beb34))

## 0.470.0 (2026-02-21)

Full Changelog: [v0.469.0...v0.470.0](https://github.com/aiinbx/aiinbx-py/compare/v0.469.0...v0.470.0)

### Features

* **api:** api update ([3db94d5](https://github.com/aiinbx/aiinbx-py/commit/3db94d5a618df7ec7dad5708aaaecdd8bcd40f03))

## 0.469.0 (2026-02-21)

Full Changelog: [v0.468.0...v0.469.0](https://github.com/aiinbx/aiinbx-py/compare/v0.468.0...v0.469.0)

### Features

* **api:** api update ([5ff6012](https://github.com/aiinbx/aiinbx-py/commit/5ff6012870d63446823ce64f64c73013a6230511))

## 0.468.0 (2026-02-21)

Full Changelog: [v0.467.0...v0.468.0](https://github.com/aiinbx/aiinbx-py/compare/v0.467.0...v0.468.0)

### Features

* **api:** api update ([d8bbf28](https://github.com/aiinbx/aiinbx-py/commit/d8bbf2818655a40cf3043ec75db3e66dd0a6c9e9))

## 0.467.0 (2026-02-21)

Full Changelog: [v0.466.0...v0.467.0](https://github.com/aiinbx/aiinbx-py/compare/v0.466.0...v0.467.0)

### Features

* **api:** api update ([f709d22](https://github.com/aiinbx/aiinbx-py/commit/f709d2201cf8a3c68a8aa2f496d4bad776194ac8))

## 0.466.0 (2026-02-20)

Full Changelog: [v0.465.0...v0.466.0](https://github.com/aiinbx/aiinbx-py/compare/v0.465.0...v0.466.0)

### Features

* **api:** api update ([9f08063](https://github.com/aiinbx/aiinbx-py/commit/9f080633730e6f27927c0b1d2b555e3058e76b69))

## 0.465.0 (2026-02-20)

Full Changelog: [v0.464.0...v0.465.0](https://github.com/aiinbx/aiinbx-py/compare/v0.464.0...v0.465.0)

### Features

* **api:** api update ([66d2775](https://github.com/aiinbx/aiinbx-py/commit/66d2775bd6c7c2cc86f34b498afeda6d0ac8849b))

## 0.464.0 (2026-02-20)

Full Changelog: [v0.463.0...v0.464.0](https://github.com/aiinbx/aiinbx-py/compare/v0.463.0...v0.464.0)

### Features

* **api:** api update ([dce3cee](https://github.com/aiinbx/aiinbx-py/commit/dce3cee15f8e09581b8d4e2b08a21e86cbf5a236))

## 0.463.0 (2026-02-20)

Full Changelog: [v0.462.0...v0.463.0](https://github.com/aiinbx/aiinbx-py/compare/v0.462.0...v0.463.0)

### Features

* **api:** api update ([6d4c75c](https://github.com/aiinbx/aiinbx-py/commit/6d4c75c361e3873e687dc0620620e6ee2f4d979f))

## 0.462.0 (2026-02-20)

Full Changelog: [v0.461.0...v0.462.0](https://github.com/aiinbx/aiinbx-py/compare/v0.461.0...v0.462.0)

### Features

* **api:** api update ([1060b6a](https://github.com/aiinbx/aiinbx-py/commit/1060b6ae691bb169f1b50470a441469ad3a82f7f))

## 0.461.0 (2026-02-20)

Full Changelog: [v0.460.0...v0.461.0](https://github.com/aiinbx/aiinbx-py/compare/v0.460.0...v0.461.0)

### Features

* **api:** api update ([fc50fb8](https://github.com/aiinbx/aiinbx-py/commit/fc50fb86824537eba34bd406088d6c8f30f3a461))
* **api:** api update ([38080d4](https://github.com/aiinbx/aiinbx-py/commit/38080d4c6d4655f963db894ddf386bcb6d5419d2))
* **api:** api update ([399286d](https://github.com/aiinbx/aiinbx-py/commit/399286db999ba4b08c7904b1e84fa0998b959824))
* **api:** api update ([c135310](https://github.com/aiinbx/aiinbx-py/commit/c1353108f022468258a485c6ef37268a2aa62646))
* **api:** api update ([89c6fc9](https://github.com/aiinbx/aiinbx-py/commit/89c6fc9e22f487a4889cb8a7bd0c6946c86f0261))
* **api:** api update ([459609a](https://github.com/aiinbx/aiinbx-py/commit/459609acc15319798dfeedf88e4f782c9c84a018))
* **api:** api update ([d6d3588](https://github.com/aiinbx/aiinbx-py/commit/d6d35885b712c4f4ba5c107be43983a8d77b70f9))
* **api:** api update ([08aa6f1](https://github.com/aiinbx/aiinbx-py/commit/08aa6f1e3d41bd4f5f40558ba54b9bd2cecca82e))
* **api:** api update ([f3b1cc4](https://github.com/aiinbx/aiinbx-py/commit/f3b1cc4f63c96269d130c24031df6199c86b629a))
* **api:** api update ([e8b5241](https://github.com/aiinbx/aiinbx-py/commit/e8b52412bae04e4a1b72b4efc694dab8567be4e6))
* **api:** api update ([d0bb8fd](https://github.com/aiinbx/aiinbx-py/commit/d0bb8fdeb2c86767dd17d35622f6d801e9c62a09))
* **api:** api update ([a38ee82](https://github.com/aiinbx/aiinbx-py/commit/a38ee82b3a4944907e83f8a66c5058054cc419bc))
* **api:** api update ([03175cd](https://github.com/aiinbx/aiinbx-py/commit/03175cdbc58d4410d9ec1dd28f70ef491efd7888))
* **api:** api update ([1ded92f](https://github.com/aiinbx/aiinbx-py/commit/1ded92fe3d3c7786aa74711d5ce763557bdfa388))


### Chores

* **internal:** remove mock server code ([1800315](https://github.com/aiinbx/aiinbx-py/commit/1800315a4cb5c4ec65d788c427952baa41e401c0))
* update mock server docs ([a79c639](https://github.com/aiinbx/aiinbx-py/commit/a79c639422aa422a7c6dcec472d3cd12779059d4))

## 0.460.0 (2026-02-18)

Full Changelog: [v0.459.0...v0.460.0](https://github.com/aiinbx/aiinbx-py/compare/v0.459.0...v0.460.0)

### Features

* **api:** api update ([7dc8f93](https://github.com/aiinbx/aiinbx-py/commit/7dc8f93b828a46b79fe6e4d66959d5dd472c41af))

## 0.459.0 (2026-02-18)

Full Changelog: [v0.458.0...v0.459.0](https://github.com/aiinbx/aiinbx-py/compare/v0.458.0...v0.459.0)

### Features

* **api:** api update ([5059499](https://github.com/aiinbx/aiinbx-py/commit/50594993afe11b17709c557f01279dd61e63557b))

## 0.458.0 (2026-02-18)

Full Changelog: [v0.457.0...v0.458.0](https://github.com/aiinbx/aiinbx-py/compare/v0.457.0...v0.458.0)

### Features

* **api:** api update ([bc74ebb](https://github.com/aiinbx/aiinbx-py/commit/bc74ebb8985a58bc08d599c29aa4331b52d3f472))

## 0.457.0 (2026-02-18)

Full Changelog: [v0.456.0...v0.457.0](https://github.com/aiinbx/aiinbx-py/compare/v0.456.0...v0.457.0)

### Features

* **api:** api update ([de70d23](https://github.com/aiinbx/aiinbx-py/commit/de70d236df9c6b53b247ca7cf8426d99b6511251))

## 0.456.0 (2026-02-18)

Full Changelog: [v0.455.0...v0.456.0](https://github.com/aiinbx/aiinbx-py/compare/v0.455.0...v0.456.0)

### Features

* **api:** api update ([aec0809](https://github.com/aiinbx/aiinbx-py/commit/aec080958740abdab7b0b75c9450644ecad8e029))

## 0.455.0 (2026-02-18)

Full Changelog: [v0.454.0...v0.455.0](https://github.com/aiinbx/aiinbx-py/compare/v0.454.0...v0.455.0)

### Features

* **api:** api update ([de514ef](https://github.com/aiinbx/aiinbx-py/commit/de514efc0e0cb42a81cdc8df5441f8adf893e1b6))

## 0.454.0 (2026-02-17)

Full Changelog: [v0.453.0...v0.454.0](https://github.com/aiinbx/aiinbx-py/compare/v0.453.0...v0.454.0)

### Features

* **api:** api update ([f001f5a](https://github.com/aiinbx/aiinbx-py/commit/f001f5a5df7502b53a6bddceb66a2642bab0af13))

## 0.453.0 (2026-02-17)

Full Changelog: [v0.452.0...v0.453.0](https://github.com/aiinbx/aiinbx-py/compare/v0.452.0...v0.453.0)

### Features

* **api:** api update ([08a485e](https://github.com/aiinbx/aiinbx-py/commit/08a485ec8aae90b58ade841319a7456d03c9d06b))

## 0.452.0 (2026-02-17)

Full Changelog: [v0.451.0...v0.452.0](https://github.com/aiinbx/aiinbx-py/compare/v0.451.0...v0.452.0)

### Features

* **api:** api update ([ccd3510](https://github.com/aiinbx/aiinbx-py/commit/ccd3510f07da12f790c0c62a8d6afb2a372d5e33))

## 0.451.0 (2026-02-17)

Full Changelog: [v0.450.0...v0.451.0](https://github.com/aiinbx/aiinbx-py/compare/v0.450.0...v0.451.0)

### Features

* **api:** api update ([7344f75](https://github.com/aiinbx/aiinbx-py/commit/7344f7523a9e6e1f0f6c08878e807617e4c9867a))

## 0.450.0 (2026-02-17)

Full Changelog: [v0.449.0...v0.450.0](https://github.com/aiinbx/aiinbx-py/compare/v0.449.0...v0.450.0)

### Features

* **api:** api update ([2684923](https://github.com/aiinbx/aiinbx-py/commit/2684923e418d315612050012532c5cd4335fa263))

## 0.449.0 (2026-02-17)

Full Changelog: [v0.448.0...v0.449.0](https://github.com/aiinbx/aiinbx-py/compare/v0.448.0...v0.449.0)

### Features

* **api:** api update ([0bebbda](https://github.com/aiinbx/aiinbx-py/commit/0bebbdae17353b90141e7832b2b204433be3d4a0))

## 0.448.0 (2026-02-17)

Full Changelog: [v0.447.0...v0.448.0](https://github.com/aiinbx/aiinbx-py/compare/v0.447.0...v0.448.0)

### Features

* **api:** api update ([fb12e2d](https://github.com/aiinbx/aiinbx-py/commit/fb12e2d92ced90470c46bae299cfcaf1588360b6))

## 0.447.0 (2026-02-17)

Full Changelog: [v0.446.0...v0.447.0](https://github.com/aiinbx/aiinbx-py/compare/v0.446.0...v0.447.0)

### Features

* **api:** api update ([0bc7c32](https://github.com/aiinbx/aiinbx-py/commit/0bc7c3236eb611baea537279a3c26d4d34df945f))

## 0.446.0 (2026-02-17)

Full Changelog: [v0.445.0...v0.446.0](https://github.com/aiinbx/aiinbx-py/compare/v0.445.0...v0.446.0)

### Features

* **api:** api update ([7b842f1](https://github.com/aiinbx/aiinbx-py/commit/7b842f1a1eb383039d2c62aed7f128afae568a23))

## 0.445.0 (2026-02-17)

Full Changelog: [v0.444.0...v0.445.0](https://github.com/aiinbx/aiinbx-py/compare/v0.444.0...v0.445.0)

### Features

* **api:** api update ([536cfc5](https://github.com/aiinbx/aiinbx-py/commit/536cfc5d4e65e4939604e05be8cfe688ba9cf857))

## 0.444.0 (2026-02-17)

Full Changelog: [v0.443.0...v0.444.0](https://github.com/aiinbx/aiinbx-py/compare/v0.443.0...v0.444.0)

### Features

* **api:** api update ([b61ca90](https://github.com/aiinbx/aiinbx-py/commit/b61ca906177a8a40f26e0f7eb3285a333b37c953))

## 0.443.0 (2026-02-16)

Full Changelog: [v0.442.0...v0.443.0](https://github.com/aiinbx/aiinbx-py/compare/v0.442.0...v0.443.0)

### Features

* **api:** api update ([82400c6](https://github.com/aiinbx/aiinbx-py/commit/82400c6d63e2b70c752d652eb61f88bfc70e4dbe))

## 0.442.0 (2026-02-16)

Full Changelog: [v0.441.0...v0.442.0](https://github.com/aiinbx/aiinbx-py/compare/v0.441.0...v0.442.0)

### Features

* **api:** api update ([5a93dde](https://github.com/aiinbx/aiinbx-py/commit/5a93dde116ffac11af7acba8877405574ac9288f))

## 0.441.0 (2026-02-16)

Full Changelog: [v0.440.0...v0.441.0](https://github.com/aiinbx/aiinbx-py/compare/v0.440.0...v0.441.0)

### Features

* **api:** api update ([621ff66](https://github.com/aiinbx/aiinbx-py/commit/621ff66f5aad066a37b3cce9b3774e41bd13378e))

## 0.440.0 (2026-02-16)

Full Changelog: [v0.439.0...v0.440.0](https://github.com/aiinbx/aiinbx-py/compare/v0.439.0...v0.440.0)

### Features

* **api:** api update ([5c211ce](https://github.com/aiinbx/aiinbx-py/commit/5c211cee6a92640a378d2d4a0271836291b7439a))

## 0.439.0 (2026-02-16)

Full Changelog: [v0.438.0...v0.439.0](https://github.com/aiinbx/aiinbx-py/compare/v0.438.0...v0.439.0)

### Features

* **api:** api update ([abf5903](https://github.com/aiinbx/aiinbx-py/commit/abf590305da3c891df8b6c41dcb15633df0eaea9))

## 0.438.0 (2026-02-16)

Full Changelog: [v0.437.0...v0.438.0](https://github.com/aiinbx/aiinbx-py/compare/v0.437.0...v0.438.0)

### Features

* **api:** api update ([982bd5f](https://github.com/aiinbx/aiinbx-py/commit/982bd5f28ff8173b16358ee1e683c7402eb98484))

## 0.437.0 (2026-02-16)

Full Changelog: [v0.436.0...v0.437.0](https://github.com/aiinbx/aiinbx-py/compare/v0.436.0...v0.437.0)

### Features

* **api:** api update ([4a8939b](https://github.com/aiinbx/aiinbx-py/commit/4a8939b5fb366581db14bb772e7d43576f88875b))

## 0.436.0 (2026-02-16)

Full Changelog: [v0.435.0...v0.436.0](https://github.com/aiinbx/aiinbx-py/compare/v0.435.0...v0.436.0)

### Features

* **api:** api update ([97d160f](https://github.com/aiinbx/aiinbx-py/commit/97d160fccff321025ff24bffcd23d8d71234a57e))

## 0.435.0 (2026-02-16)

Full Changelog: [v0.434.0...v0.435.0](https://github.com/aiinbx/aiinbx-py/compare/v0.434.0...v0.435.0)

### Features

* **api:** api update ([e65c273](https://github.com/aiinbx/aiinbx-py/commit/e65c273bfb14d0678707baa3a42bbf8f3b6de3bb))

## 0.434.0 (2026-02-16)

Full Changelog: [v0.433.0...v0.434.0](https://github.com/aiinbx/aiinbx-py/compare/v0.433.0...v0.434.0)

### Features

* **api:** api update ([1811283](https://github.com/aiinbx/aiinbx-py/commit/18112831895adaba3a5098eb2b3bef4d86f6961d))

## 0.433.0 (2026-02-16)

Full Changelog: [v0.432.0...v0.433.0](https://github.com/aiinbx/aiinbx-py/compare/v0.432.0...v0.433.0)

### Features

* **api:** api update ([1dd8c18](https://github.com/aiinbx/aiinbx-py/commit/1dd8c18d789bbdfadfe6d9ed0ef0da9276f98ea5))

## 0.432.0 (2026-02-15)

Full Changelog: [v0.431.0...v0.432.0](https://github.com/aiinbx/aiinbx-py/compare/v0.431.0...v0.432.0)

### Features

* **api:** api update ([0aa4785](https://github.com/aiinbx/aiinbx-py/commit/0aa4785a4805ef79ef24cf8a32f6b189c99ae79f))

## 0.431.0 (2026-02-15)

Full Changelog: [v0.430.0...v0.431.0](https://github.com/aiinbx/aiinbx-py/compare/v0.430.0...v0.431.0)

### Features

* **api:** api update ([b92d7de](https://github.com/aiinbx/aiinbx-py/commit/b92d7dee98519259469e2f7bfcd3b01b04fb04da))

## 0.430.0 (2026-02-15)

Full Changelog: [v0.429.0...v0.430.0](https://github.com/aiinbx/aiinbx-py/compare/v0.429.0...v0.430.0)

### Features

* **api:** api update ([78abeff](https://github.com/aiinbx/aiinbx-py/commit/78abeffc4b599203e1420508d7785d67a6207265))

## 0.429.0 (2026-02-15)

Full Changelog: [v0.428.0...v0.429.0](https://github.com/aiinbx/aiinbx-py/compare/v0.428.0...v0.429.0)

### Features

* **api:** api update ([e2e61d4](https://github.com/aiinbx/aiinbx-py/commit/e2e61d4a0e58a2c0f49025cf22b9946c31ee8cca))

## 0.428.0 (2026-02-15)

Full Changelog: [v0.427.0...v0.428.0](https://github.com/aiinbx/aiinbx-py/compare/v0.427.0...v0.428.0)

### Features

* **api:** api update ([d095ace](https://github.com/aiinbx/aiinbx-py/commit/d095ace31e3e44dba7592dee197e16c19a4f67f3))

## 0.427.0 (2026-02-15)

Full Changelog: [v0.426.0...v0.427.0](https://github.com/aiinbx/aiinbx-py/compare/v0.426.0...v0.427.0)

### Features

* **api:** api update ([bee2ef7](https://github.com/aiinbx/aiinbx-py/commit/bee2ef785b9db26cb24c04fd39f3b0cf7da59ab2))

## 0.426.0 (2026-02-15)

Full Changelog: [v0.425.0...v0.426.0](https://github.com/aiinbx/aiinbx-py/compare/v0.425.0...v0.426.0)

### Features

* **api:** api update ([e128c0d](https://github.com/aiinbx/aiinbx-py/commit/e128c0d64ba7de765eee33c2198673eaff456884))

## 0.425.0 (2026-02-15)

Full Changelog: [v0.424.0...v0.425.0](https://github.com/aiinbx/aiinbx-py/compare/v0.424.0...v0.425.0)

### Features

* **api:** api update ([028624c](https://github.com/aiinbx/aiinbx-py/commit/028624c8721f9dcce5d2e9c293a9cfdd59040751))

## 0.424.0 (2026-02-14)

Full Changelog: [v0.423.0...v0.424.0](https://github.com/aiinbx/aiinbx-py/compare/v0.423.0...v0.424.0)

### Features

* **api:** api update ([d0ce65f](https://github.com/aiinbx/aiinbx-py/commit/d0ce65fcc454f2215d896331ea3fec5fcc789e74))

## 0.423.0 (2026-02-14)

Full Changelog: [v0.422.0...v0.423.0](https://github.com/aiinbx/aiinbx-py/compare/v0.422.0...v0.423.0)

### Features

* **api:** api update ([9883abd](https://github.com/aiinbx/aiinbx-py/commit/9883abd16f8dde721f9958b7747f67651ccc055b))

## 0.422.0 (2026-02-14)

Full Changelog: [v0.421.0...v0.422.0](https://github.com/aiinbx/aiinbx-py/compare/v0.421.0...v0.422.0)

### Features

* **api:** api update ([ed77def](https://github.com/aiinbx/aiinbx-py/commit/ed77deff01577c9564a34a79e768d020eefaa795))

## 0.421.0 (2026-02-14)

Full Changelog: [v0.420.0...v0.421.0](https://github.com/aiinbx/aiinbx-py/compare/v0.420.0...v0.421.0)

### Features

* **api:** api update ([0b5e507](https://github.com/aiinbx/aiinbx-py/commit/0b5e507e4b23c95c90edb8a1c2420fb15a9f92bc))

## 0.420.0 (2026-02-14)

Full Changelog: [v0.419.0...v0.420.0](https://github.com/aiinbx/aiinbx-py/compare/v0.419.0...v0.420.0)

### Features

* **api:** api update ([2adf10f](https://github.com/aiinbx/aiinbx-py/commit/2adf10f24cdd16dbe2782b5d0fe2c20675fc7b08))

## 0.419.0 (2026-02-14)

Full Changelog: [v0.418.0...v0.419.0](https://github.com/aiinbx/aiinbx-py/compare/v0.418.0...v0.419.0)

### Features

* **api:** api update ([8524905](https://github.com/aiinbx/aiinbx-py/commit/8524905a194800cf179bd3aa755e68d94fd673e5))

## 0.418.0 (2026-02-14)

Full Changelog: [v0.417.0...v0.418.0](https://github.com/aiinbx/aiinbx-py/compare/v0.417.0...v0.418.0)

### Features

* **api:** api update ([9587fa8](https://github.com/aiinbx/aiinbx-py/commit/9587fa830a0c98fb04efd2c233eb47d8a431a4da))

## 0.417.0 (2026-02-13)

Full Changelog: [v0.416.0...v0.417.0](https://github.com/aiinbx/aiinbx-py/compare/v0.416.0...v0.417.0)

### Features

* **api:** api update ([6d009a9](https://github.com/aiinbx/aiinbx-py/commit/6d009a96479d23c4e33a32716a618f04e72b67c5))

## 0.416.0 (2026-02-13)

Full Changelog: [v0.415.0...v0.416.0](https://github.com/aiinbx/aiinbx-py/compare/v0.415.0...v0.416.0)

### Features

* **api:** api update ([f8b1c2d](https://github.com/aiinbx/aiinbx-py/commit/f8b1c2d72c0e5a48f8fce11c945137f12882a57c))

## 0.415.0 (2026-02-13)

Full Changelog: [v0.414.0...v0.415.0](https://github.com/aiinbx/aiinbx-py/compare/v0.414.0...v0.415.0)

### Features

* **api:** api update ([1aa3886](https://github.com/aiinbx/aiinbx-py/commit/1aa3886229d967337da9c6841e68efad66357923))

## 0.414.0 (2026-02-13)

Full Changelog: [v0.413.0...v0.414.0](https://github.com/aiinbx/aiinbx-py/compare/v0.413.0...v0.414.0)

### Features

* **api:** api update ([a21a205](https://github.com/aiinbx/aiinbx-py/commit/a21a205af40b99753a076f0328547bf7416726de))

## 0.413.0 (2026-02-13)

Full Changelog: [v0.412.0...v0.413.0](https://github.com/aiinbx/aiinbx-py/compare/v0.412.0...v0.413.0)

### Features

* **api:** api update ([23594e3](https://github.com/aiinbx/aiinbx-py/commit/23594e3ffa07b388c723faacc4317a1fc940f160))

## 0.412.0 (2026-02-13)

Full Changelog: [v0.411.0...v0.412.0](https://github.com/aiinbx/aiinbx-py/compare/v0.411.0...v0.412.0)

### Features

* **api:** api update ([c1186f4](https://github.com/aiinbx/aiinbx-py/commit/c1186f49bef4a09fcc97a3e0428dd1ec24bdb26a))


### Chores

* format all `api.md` files ([9ae08e1](https://github.com/aiinbx/aiinbx-py/commit/9ae08e1ffe1739fba2527ea34d5b92d498866fa5))

## 0.411.0 (2026-02-13)

Full Changelog: [v0.410.0...v0.411.0](https://github.com/aiinbx/aiinbx-py/compare/v0.410.0...v0.411.0)

### Features

* **api:** api update ([9e9b749](https://github.com/aiinbx/aiinbx-py/commit/9e9b74944c5c41d5b37605da505f2365bc9b4f5e))

## 0.410.0 (2026-02-12)

Full Changelog: [v0.409.0...v0.410.0](https://github.com/aiinbx/aiinbx-py/compare/v0.409.0...v0.410.0)

### Features

* **api:** api update ([2e0cd4a](https://github.com/aiinbx/aiinbx-py/commit/2e0cd4acdd2e7ba8d861baac908c6fe83aa683ce))

## 0.409.0 (2026-02-12)

Full Changelog: [v0.408.0...v0.409.0](https://github.com/aiinbx/aiinbx-py/compare/v0.408.0...v0.409.0)

### Features

* **api:** api update ([ea962aa](https://github.com/aiinbx/aiinbx-py/commit/ea962aac26d7889d11fd9fabb4ddda5ed86aa098))

## 0.408.0 (2026-02-12)

Full Changelog: [v0.407.0...v0.408.0](https://github.com/aiinbx/aiinbx-py/compare/v0.407.0...v0.408.0)

### Features

* **api:** api update ([82032d4](https://github.com/aiinbx/aiinbx-py/commit/82032d4ceb5d10689dfe5b0128f95ed50818d828))


### Chores

* **internal:** fix lint error on Python 3.14 ([4088794](https://github.com/aiinbx/aiinbx-py/commit/40887943195a6ebb841b3078714d3d9a764f1d82))

## 0.407.0 (2026-02-11)

Full Changelog: [v0.406.0...v0.407.0](https://github.com/aiinbx/aiinbx-py/compare/v0.406.0...v0.407.0)

### Features

* **api:** api update ([6168f42](https://github.com/aiinbx/aiinbx-py/commit/6168f42c737b9c0cab2cf5433818ec95940ddd6f))

## 0.406.0 (2026-02-11)

Full Changelog: [v0.405.0...v0.406.0](https://github.com/aiinbx/aiinbx-py/compare/v0.405.0...v0.406.0)

### Features

* **api:** api update ([4c962e3](https://github.com/aiinbx/aiinbx-py/commit/4c962e3b06c9bb803f95baa8584208d648626f09))

## 0.405.0 (2026-02-10)

Full Changelog: [v0.404.0...v0.405.0](https://github.com/aiinbx/aiinbx-py/compare/v0.404.0...v0.405.0)

### Features

* **api:** api update ([4ee4ea8](https://github.com/aiinbx/aiinbx-py/commit/4ee4ea8771a0edf4f0bd7a64f471e4b80aa69152))

## 0.404.0 (2026-02-10)

Full Changelog: [v0.403.0...v0.404.0](https://github.com/aiinbx/aiinbx-py/compare/v0.403.0...v0.404.0)

### Features

* **api:** api update ([321e867](https://github.com/aiinbx/aiinbx-py/commit/321e8673fde50f2139e894ea22818b9ac775d5ae))


### Chores

* **internal:** bump dependencies ([c361540](https://github.com/aiinbx/aiinbx-py/commit/c361540a05a5aa0ba04ecaa371fd1749aee88741))

## 0.403.0 (2026-02-10)

Full Changelog: [v0.402.0...v0.403.0](https://github.com/aiinbx/aiinbx-py/compare/v0.402.0...v0.403.0)

### Features

* **api:** api update ([1c5d885](https://github.com/aiinbx/aiinbx-py/commit/1c5d885f9b5ebda1fbc38146a91e72259078819c))

## 0.402.0 (2026-02-10)

Full Changelog: [v0.401.0...v0.402.0](https://github.com/aiinbx/aiinbx-py/compare/v0.401.0...v0.402.0)

### Features

* **api:** api update ([50b1943](https://github.com/aiinbx/aiinbx-py/commit/50b19430fae0ab0cbdcedf5da0bc7c8f506c94b1))

## 0.401.0 (2026-02-09)

Full Changelog: [v0.400.0...v0.401.0](https://github.com/aiinbx/aiinbx-py/compare/v0.400.0...v0.401.0)

### Features

* **api:** api update ([d1b554d](https://github.com/aiinbx/aiinbx-py/commit/d1b554dc7554c978a8ce05487cc32e8228d0499f))

## 0.400.0 (2026-02-09)

Full Changelog: [v0.399.0...v0.400.0](https://github.com/aiinbx/aiinbx-py/compare/v0.399.0...v0.400.0)

### Features

* **api:** api update ([144ae29](https://github.com/aiinbx/aiinbx-py/commit/144ae29d7dbfd3984300703f87d673a921970805))

## 0.399.0 (2026-02-08)

Full Changelog: [v0.398.0...v0.399.0](https://github.com/aiinbx/aiinbx-py/compare/v0.398.0...v0.399.0)

### Features

* **api:** api update ([0bb3437](https://github.com/aiinbx/aiinbx-py/commit/0bb3437ffc02112129cd88bbd37112bc656c51f0))

## 0.398.0 (2026-02-08)

Full Changelog: [v0.397.0...v0.398.0](https://github.com/aiinbx/aiinbx-py/compare/v0.397.0...v0.398.0)

### Features

* **api:** api update ([fcfa1db](https://github.com/aiinbx/aiinbx-py/commit/fcfa1db4fefe256c63fe62543518fce8717778b6))

## 0.397.0 (2026-02-07)

Full Changelog: [v0.396.0...v0.397.0](https://github.com/aiinbx/aiinbx-py/compare/v0.396.0...v0.397.0)

### Features

* **api:** api update ([340b101](https://github.com/aiinbx/aiinbx-py/commit/340b101779836d6a515987dcdeaef342d7fdab2f))

## 0.396.0 (2026-02-07)

Full Changelog: [v0.395.0...v0.396.0](https://github.com/aiinbx/aiinbx-py/compare/v0.395.0...v0.396.0)

### Features

* **api:** api update ([5254d51](https://github.com/aiinbx/aiinbx-py/commit/5254d512a5a31b49149314681ba2b50bde318ae7))

## 0.395.0 (2026-02-07)

Full Changelog: [v0.394.0...v0.395.0](https://github.com/aiinbx/aiinbx-py/compare/v0.394.0...v0.395.0)

### Features

* **api:** api update ([1bda60c](https://github.com/aiinbx/aiinbx-py/commit/1bda60ca5084b3c17a1b1859ffa3f33aa5f10d21))

## 0.394.0 (2026-02-07)

Full Changelog: [v0.393.0...v0.394.0](https://github.com/aiinbx/aiinbx-py/compare/v0.393.0...v0.394.0)

### Features

* **api:** api update ([2d696b8](https://github.com/aiinbx/aiinbx-py/commit/2d696b810c46e2f76d7892380da736f9a4ed1f0c))

## 0.393.0 (2026-02-07)

Full Changelog: [v0.392.0...v0.393.0](https://github.com/aiinbx/aiinbx-py/compare/v0.392.0...v0.393.0)

### Features

* **api:** api update ([0fb64a7](https://github.com/aiinbx/aiinbx-py/commit/0fb64a7f5b7f3fbc20e622d586471ea3da8a4d51))

## 0.392.0 (2026-02-07)

Full Changelog: [v0.391.0...v0.392.0](https://github.com/aiinbx/aiinbx-py/compare/v0.391.0...v0.392.0)

### Features

* **api:** api update ([9523b78](https://github.com/aiinbx/aiinbx-py/commit/9523b789ca6acd31bc51959f317fb9a76e5e0c01))

## 0.391.0 (2026-02-07)

Full Changelog: [v0.390.0...v0.391.0](https://github.com/aiinbx/aiinbx-py/compare/v0.390.0...v0.391.0)

### Features

* **api:** api update ([45a2957](https://github.com/aiinbx/aiinbx-py/commit/45a29579c9bcd216ea9e29db5f36f5532fe1b13e))

## 0.390.0 (2026-02-07)

Full Changelog: [v0.389.0...v0.390.0](https://github.com/aiinbx/aiinbx-py/compare/v0.389.0...v0.390.0)

### Features

* **api:** api update ([c9fddbc](https://github.com/aiinbx/aiinbx-py/commit/c9fddbc86428273bea9648f96158f3829ca73324))

## 0.389.0 (2026-02-07)

Full Changelog: [v0.388.0...v0.389.0](https://github.com/aiinbx/aiinbx-py/compare/v0.388.0...v0.389.0)

### Features

* **api:** api update ([932ee9a](https://github.com/aiinbx/aiinbx-py/commit/932ee9a450f8c52c4861cff3ad0c47ec9ff2112c))

## 0.388.0 (2026-02-07)

Full Changelog: [v0.387.0...v0.388.0](https://github.com/aiinbx/aiinbx-py/compare/v0.387.0...v0.388.0)

### Features

* **api:** api update ([9e2c928](https://github.com/aiinbx/aiinbx-py/commit/9e2c928c85cd7cec08019b5af16a32c73598aa58))

## 0.387.0 (2026-02-07)

Full Changelog: [v0.386.0...v0.387.0](https://github.com/aiinbx/aiinbx-py/compare/v0.386.0...v0.387.0)

### Features

* **api:** api update ([ac4e088](https://github.com/aiinbx/aiinbx-py/commit/ac4e088601dba95059aa9f9ad0d260f5528376e8))

## 0.386.0 (2026-02-06)

Full Changelog: [v0.385.0...v0.386.0](https://github.com/aiinbx/aiinbx-py/compare/v0.385.0...v0.386.0)

### Features

* **api:** api update ([81171c2](https://github.com/aiinbx/aiinbx-py/commit/81171c24a5552e8b570e72807053676d2bf866b9))

## 0.385.0 (2026-02-06)

Full Changelog: [v0.384.0...v0.385.0](https://github.com/aiinbx/aiinbx-py/compare/v0.384.0...v0.385.0)

### Features

* **api:** api update ([200b1ec](https://github.com/aiinbx/aiinbx-py/commit/200b1ec1a31c312c0a89d7f3813fce7230b92944))

## 0.384.0 (2026-02-06)

Full Changelog: [v0.383.0...v0.384.0](https://github.com/aiinbx/aiinbx-py/compare/v0.383.0...v0.384.0)

### Features

* **api:** api update ([88e3026](https://github.com/aiinbx/aiinbx-py/commit/88e302676fbb44875e05e27cda7b570c4c4019d1))

## 0.383.0 (2026-02-05)

Full Changelog: [v0.382.0...v0.383.0](https://github.com/aiinbx/aiinbx-py/compare/v0.382.0...v0.383.0)

### Features

* **api:** api update ([5938da5](https://github.com/aiinbx/aiinbx-py/commit/5938da56bcef03f98fd216114852c7b984382f51))

## 0.382.0 (2026-02-05)

Full Changelog: [v0.381.0...v0.382.0](https://github.com/aiinbx/aiinbx-py/compare/v0.381.0...v0.382.0)

### Features

* **api:** api update ([5a1189a](https://github.com/aiinbx/aiinbx-py/commit/5a1189a2db8276cd2b15f6d622f364989f873454))

## 0.381.0 (2026-02-05)

Full Changelog: [v0.380.0...v0.381.0](https://github.com/aiinbx/aiinbx-py/compare/v0.380.0...v0.381.0)

### Features

* **api:** api update ([3235c12](https://github.com/aiinbx/aiinbx-py/commit/3235c12e876bf74d5935e1666302ccbfac5a2fde))

## 0.380.0 (2026-02-04)

Full Changelog: [v0.379.0...v0.380.0](https://github.com/aiinbx/aiinbx-py/compare/v0.379.0...v0.380.0)

### Features

* **api:** api update ([22b5145](https://github.com/aiinbx/aiinbx-py/commit/22b5145e5e8401286467df211a199b3c5ef5a889))
* **api:** api update ([5d8ba3b](https://github.com/aiinbx/aiinbx-py/commit/5d8ba3b766bf17d015c031a6474d4265aacdc9d6))

## 0.379.0 (2026-02-03)

Full Changelog: [v0.378.0...v0.379.0](https://github.com/aiinbx/aiinbx-py/compare/v0.378.0...v0.379.0)

### Features

* **api:** api update ([4516a8f](https://github.com/aiinbx/aiinbx-py/commit/4516a8fb1ad5646bdd3e464c9cabe88e0ede29dd))

## 0.378.0 (2026-02-03)

Full Changelog: [v0.377.0...v0.378.0](https://github.com/aiinbx/aiinbx-py/compare/v0.377.0...v0.378.0)

### Features

* **api:** api update ([8c55bb8](https://github.com/aiinbx/aiinbx-py/commit/8c55bb887cf719f5d2927eb8e51bc28646ae29af))

## 0.377.0 (2026-02-03)

Full Changelog: [v0.376.0...v0.377.0](https://github.com/aiinbx/aiinbx-py/compare/v0.376.0...v0.377.0)

### Features

* **api:** api update ([3d33f9f](https://github.com/aiinbx/aiinbx-py/commit/3d33f9fedb6207413e2e86b3a0994058a31d50ce))

## 0.376.0 (2026-02-03)

Full Changelog: [v0.375.0...v0.376.0](https://github.com/aiinbx/aiinbx-py/compare/v0.375.0...v0.376.0)

### Features

* **api:** api update ([ceaaa19](https://github.com/aiinbx/aiinbx-py/commit/ceaaa19ba1fc37e3440b10027f5e3b0a8eb4ce23))

## 0.375.0 (2026-02-03)

Full Changelog: [v0.374.0...v0.375.0](https://github.com/aiinbx/aiinbx-py/compare/v0.374.0...v0.375.0)

### Features

* **api:** api update ([b0ead11](https://github.com/aiinbx/aiinbx-py/commit/b0ead11d7deac619055bfd05b6a33ecf6ab7094a))

## 0.374.0 (2026-02-03)

Full Changelog: [v0.373.0...v0.374.0](https://github.com/aiinbx/aiinbx-py/compare/v0.373.0...v0.374.0)

### Features

* **api:** api update ([66cd18e](https://github.com/aiinbx/aiinbx-py/commit/66cd18e4cb5754eadac98ed554874963169224b6))

## 0.373.0 (2026-02-03)

Full Changelog: [v0.372.0...v0.373.0](https://github.com/aiinbx/aiinbx-py/compare/v0.372.0...v0.373.0)

### Features

* **api:** api update ([de31329](https://github.com/aiinbx/aiinbx-py/commit/de3132986a35365186887def9dc3daf98e8e20dc))
* **api:** api update ([320e3ca](https://github.com/aiinbx/aiinbx-py/commit/320e3cab09bfb6edc2553438e939388e769e85f1))

## 0.372.0 (2026-02-02)

Full Changelog: [v0.371.0...v0.372.0](https://github.com/aiinbx/aiinbx-py/compare/v0.371.0...v0.372.0)

### Features

* **api:** api update ([fe322d5](https://github.com/aiinbx/aiinbx-py/commit/fe322d53b0b91a63a4d5834e29b6be925300727d))

## 0.371.0 (2026-02-02)

Full Changelog: [v0.370.0...v0.371.0](https://github.com/aiinbx/aiinbx-py/compare/v0.370.0...v0.371.0)

### Features

* **api:** api update ([ca0fe3d](https://github.com/aiinbx/aiinbx-py/commit/ca0fe3de17ace79b1c4a17df5f287ef1597cc9a3))

## 0.370.0 (2026-02-02)

Full Changelog: [v0.369.0...v0.370.0](https://github.com/aiinbx/aiinbx-py/compare/v0.369.0...v0.370.0)

### Features

* **api:** api update ([ce89f94](https://github.com/aiinbx/aiinbx-py/commit/ce89f944c146b4413e8eac1dffabc88deaf3c5a5))

## 0.369.0 (2026-02-02)

Full Changelog: [v0.368.0...v0.369.0](https://github.com/aiinbx/aiinbx-py/compare/v0.368.0...v0.369.0)

### Features

* **api:** api update ([396fcc5](https://github.com/aiinbx/aiinbx-py/commit/396fcc5930661964a8abb7dd3224db272140ef97))

## 0.368.0 (2026-02-02)

Full Changelog: [v0.367.0...v0.368.0](https://github.com/aiinbx/aiinbx-py/compare/v0.367.0...v0.368.0)

### Features

* **api:** api update ([a011eed](https://github.com/aiinbx/aiinbx-py/commit/a011eedfebb27d4de5e2cb1e0a5863fe9a5a8603))

## 0.367.0 (2026-02-02)

Full Changelog: [v0.366.0...v0.367.0](https://github.com/aiinbx/aiinbx-py/compare/v0.366.0...v0.367.0)

### Features

* **api:** api update ([e58d0ce](https://github.com/aiinbx/aiinbx-py/commit/e58d0ce58e0e57ea9eea3962de6d0df1d8dd020a))

## 0.366.0 (2026-02-02)

Full Changelog: [v0.365.0...v0.366.0](https://github.com/aiinbx/aiinbx-py/compare/v0.365.0...v0.366.0)

### Features

* **api:** api update ([cedc8de](https://github.com/aiinbx/aiinbx-py/commit/cedc8de6e1560c15175fc1a7bb0c150da3fe1a57))

## 0.365.0 (2026-02-02)

Full Changelog: [v0.364.0...v0.365.0](https://github.com/aiinbx/aiinbx-py/compare/v0.364.0...v0.365.0)

### Features

* **api:** api update ([e626f7b](https://github.com/aiinbx/aiinbx-py/commit/e626f7b0afe1a75006a8f563fd9eeedd154a2da3))

## 0.364.0 (2026-02-02)

Full Changelog: [v0.363.0...v0.364.0](https://github.com/aiinbx/aiinbx-py/compare/v0.363.0...v0.364.0)

### Features

* **api:** api update ([a49136e](https://github.com/aiinbx/aiinbx-py/commit/a49136efa25075c41bbeb63dbf49cf9276342cd7))

## 0.363.0 (2026-02-01)

Full Changelog: [v0.362.0...v0.363.0](https://github.com/aiinbx/aiinbx-py/compare/v0.362.0...v0.363.0)

### Features

* **api:** api update ([cdbee3b](https://github.com/aiinbx/aiinbx-py/commit/cdbee3be08883d7e6fb3279db8b8839432566765))

## 0.362.0 (2026-02-01)

Full Changelog: [v0.361.0...v0.362.0](https://github.com/aiinbx/aiinbx-py/compare/v0.361.0...v0.362.0)

### Features

* **api:** api update ([463e2c7](https://github.com/aiinbx/aiinbx-py/commit/463e2c7b242b3fe06ea07ddb625c02d7ee15fe33))

## 0.361.0 (2026-02-01)

Full Changelog: [v0.360.0...v0.361.0](https://github.com/aiinbx/aiinbx-py/compare/v0.360.0...v0.361.0)

### Features

* **api:** api update ([352d676](https://github.com/aiinbx/aiinbx-py/commit/352d67648cbb2beabff14fa01b2221d563ac3026))

## 0.360.0 (2026-02-01)

Full Changelog: [v0.359.0...v0.360.0](https://github.com/aiinbx/aiinbx-py/compare/v0.359.0...v0.360.0)

### Features

* **api:** api update ([b757697](https://github.com/aiinbx/aiinbx-py/commit/b757697b627db42d6fcf5bc6b73321797bac25cd))

## 0.359.0 (2026-02-01)

Full Changelog: [v0.358.0...v0.359.0](https://github.com/aiinbx/aiinbx-py/compare/v0.358.0...v0.359.0)

### Features

* **api:** api update ([1da4d3e](https://github.com/aiinbx/aiinbx-py/commit/1da4d3e73ae37d5ad6d1fe966a946d4a32756d43))

## 0.358.0 (2026-02-01)

Full Changelog: [v0.357.0...v0.358.0](https://github.com/aiinbx/aiinbx-py/compare/v0.357.0...v0.358.0)

### Features

* **api:** api update ([738c93d](https://github.com/aiinbx/aiinbx-py/commit/738c93d83329a630a9e12ef2fe5901c759fa0d13))

## 0.357.0 (2026-01-31)

Full Changelog: [v0.356.0...v0.357.0](https://github.com/aiinbx/aiinbx-py/compare/v0.356.0...v0.357.0)

### Features

* **api:** api update ([37e5358](https://github.com/aiinbx/aiinbx-py/commit/37e53581b6665aa3ba15c9e7f4c8f132d108108f))

## 0.356.0 (2026-01-31)

Full Changelog: [v0.355.0...v0.356.0](https://github.com/aiinbx/aiinbx-py/compare/v0.355.0...v0.356.0)

### Features

* **api:** api update ([9e49498](https://github.com/aiinbx/aiinbx-py/commit/9e494982c80014a9958de3679bbf9f8fa6023113))

## 0.355.0 (2026-01-31)

Full Changelog: [v0.354.0...v0.355.0](https://github.com/aiinbx/aiinbx-py/compare/v0.354.0...v0.355.0)

### Features

* **api:** api update ([15b5356](https://github.com/aiinbx/aiinbx-py/commit/15b5356aff92add8540a9a4d4b9dbc1072a34a15))

## 0.354.0 (2026-01-31)

Full Changelog: [v0.353.0...v0.354.0](https://github.com/aiinbx/aiinbx-py/compare/v0.353.0...v0.354.0)

### Features

* **api:** api update ([c18b143](https://github.com/aiinbx/aiinbx-py/commit/c18b1438e653d45ab4ee6483a3c36cdcd8fb19b3))

## 0.353.0 (2026-01-30)

Full Changelog: [v0.352.0...v0.353.0](https://github.com/aiinbx/aiinbx-py/compare/v0.352.0...v0.353.0)

### Features

* **api:** api update ([6dec5ef](https://github.com/aiinbx/aiinbx-py/commit/6dec5ef55c0c9927d5d95cb5c57279848ee3f02c))

## 0.352.0 (2026-01-30)

Full Changelog: [v0.351.0...v0.352.0](https://github.com/aiinbx/aiinbx-py/compare/v0.351.0...v0.352.0)

### Features

* **api:** api update ([67d6d81](https://github.com/aiinbx/aiinbx-py/commit/67d6d81b1d699b38eb65bf48abf46557558bc76b))

## 0.351.0 (2026-01-30)

Full Changelog: [v0.350.0...v0.351.0](https://github.com/aiinbx/aiinbx-py/compare/v0.350.0...v0.351.0)

### Features

* **api:** api update ([95c7292](https://github.com/aiinbx/aiinbx-py/commit/95c7292c6e9098d502fdb6093d769bc91908a6b5))

## 0.350.0 (2026-01-30)

Full Changelog: [v0.349.0...v0.350.0](https://github.com/aiinbx/aiinbx-py/compare/v0.349.0...v0.350.0)

### Features

* **api:** api update ([4c0411c](https://github.com/aiinbx/aiinbx-py/commit/4c0411cdf22205e4470ca16e1e908c69d3b58fef))

## 0.349.0 (2026-01-30)

Full Changelog: [v0.348.0...v0.349.0](https://github.com/aiinbx/aiinbx-py/compare/v0.348.0...v0.349.0)

### Features

* **client:** add custom JSON encoder for extended type support ([c4c3b87](https://github.com/aiinbx/aiinbx-py/commit/c4c3b87f91c4287f8ed851e81683e68d87b9c8ba))

## 0.348.0 (2026-01-29)

Full Changelog: [v0.347.0...v0.348.0](https://github.com/aiinbx/aiinbx-py/compare/v0.347.0...v0.348.0)

### Features

* **api:** api update ([559c181](https://github.com/aiinbx/aiinbx-py/commit/559c1814fca5e419eb94d95f268a4fc3334a2e34))

## 0.347.0 (2026-01-29)

Full Changelog: [v0.346.0...v0.347.0](https://github.com/aiinbx/aiinbx-py/compare/v0.346.0...v0.347.0)

### Features

* **api:** api update ([5fd4b61](https://github.com/aiinbx/aiinbx-py/commit/5fd4b6133a54df160d1cb81f8881632fafa78b71))

## 0.346.0 (2026-01-29)

Full Changelog: [v0.345.0...v0.346.0](https://github.com/aiinbx/aiinbx-py/compare/v0.345.0...v0.346.0)

### Features

* **api:** api update ([b199601](https://github.com/aiinbx/aiinbx-py/commit/b199601de9cecfe45f58d18174b9ddeeb69a0925))

## 0.345.0 (2026-01-29)

Full Changelog: [v0.344.1...v0.345.0](https://github.com/aiinbx/aiinbx-py/compare/v0.344.1...v0.345.0)

### Features

* **api:** api update ([fcb3db4](https://github.com/aiinbx/aiinbx-py/commit/fcb3db428a99e46575e78bc4fef3d9f588d8db2c))

## 0.344.1 (2026-01-29)

Full Changelog: [v0.344.0...v0.344.1](https://github.com/aiinbx/aiinbx-py/compare/v0.344.0...v0.344.1)

### Bug Fixes

* **docs:** fix mcp installation instructions for remote servers ([2412e56](https://github.com/aiinbx/aiinbx-py/commit/2412e56eb5d8581c27410751aa7b11e171237b18))

## 0.344.0 (2026-01-25)

Full Changelog: [v0.343.0...v0.344.0](https://github.com/aiinbx/aiinbx-py/compare/v0.343.0...v0.344.0)

### Features

* **api:** api update ([642d731](https://github.com/aiinbx/aiinbx-py/commit/642d731d464972da9c17829092f11de2cec913fa))

## 0.343.0 (2026-01-25)

Full Changelog: [v0.342.0...v0.343.0](https://github.com/aiinbx/aiinbx-py/compare/v0.342.0...v0.343.0)

### Features

* **api:** api update ([8b0a1bb](https://github.com/aiinbx/aiinbx-py/commit/8b0a1bb92ee6d8a7e829b7b1afadd2acbb6584c0))

## 0.342.0 (2026-01-24)

Full Changelog: [v0.341.0...v0.342.0](https://github.com/aiinbx/aiinbx-py/compare/v0.341.0...v0.342.0)

### Features

* **api:** api update ([84fca1c](https://github.com/aiinbx/aiinbx-py/commit/84fca1cbab2914b5f1eab97e3f5382df611655bb))

## 0.341.0 (2026-01-24)

Full Changelog: [v0.340.0...v0.341.0](https://github.com/aiinbx/aiinbx-py/compare/v0.340.0...v0.341.0)

### Features

* **api:** api update ([e469a86](https://github.com/aiinbx/aiinbx-py/commit/e469a86e1526fc37acb5956248553a09b54bc735))


### Chores

* **ci:** upgrade `actions/github-script` ([370be24](https://github.com/aiinbx/aiinbx-py/commit/370be2442e8f6d5c11add94d640742016e3d32d6))

## 0.340.0 (2026-01-24)

Full Changelog: [v0.339.0...v0.340.0](https://github.com/aiinbx/aiinbx-py/compare/v0.339.0...v0.340.0)

### Features

* **api:** api update ([5a2cfd4](https://github.com/aiinbx/aiinbx-py/commit/5a2cfd4c07f5ddd9cc29bac8e7572bda3745a671))

## 0.339.0 (2026-01-24)

Full Changelog: [v0.338.0...v0.339.0](https://github.com/aiinbx/aiinbx-py/compare/v0.338.0...v0.339.0)

### Features

* **api:** api update ([ea833e0](https://github.com/aiinbx/aiinbx-py/commit/ea833e010df99287939263173b387d1d82750827))

## 0.338.0 (2026-01-23)

Full Changelog: [v0.337.0...v0.338.0](https://github.com/aiinbx/aiinbx-py/compare/v0.337.0...v0.338.0)

### Features

* **api:** api update ([8fa6e63](https://github.com/aiinbx/aiinbx-py/commit/8fa6e639fe982f21874286eb3e7e508f9fa92bdf))

## 0.337.0 (2026-01-23)

Full Changelog: [v0.336.0...v0.337.0](https://github.com/aiinbx/aiinbx-py/compare/v0.336.0...v0.337.0)

### Features

* **api:** api update ([5178368](https://github.com/aiinbx/aiinbx-py/commit/51783684d3144589af5fd481c681afa93f288cef))

## 0.336.0 (2026-01-23)

Full Changelog: [v0.335.0...v0.336.0](https://github.com/aiinbx/aiinbx-py/compare/v0.335.0...v0.336.0)

### Features

* **api:** api update ([3af17bd](https://github.com/aiinbx/aiinbx-py/commit/3af17bd71621a978cbaba9c1a2b9a9add606a9f7))

## 0.335.0 (2026-01-23)

Full Changelog: [v0.334.0...v0.335.0](https://github.com/aiinbx/aiinbx-py/compare/v0.334.0...v0.335.0)

### Features

* **api:** api update ([598b14f](https://github.com/aiinbx/aiinbx-py/commit/598b14ffdf2569df9834a421739a2b60092c4275))

## 0.334.0 (2026-01-22)

Full Changelog: [v0.333.0...v0.334.0](https://github.com/aiinbx/aiinbx-py/compare/v0.333.0...v0.334.0)

### Features

* **api:** api update ([27c802f](https://github.com/aiinbx/aiinbx-py/commit/27c802f7b807fc85a70a02f3495c243889c988ad))

## 0.333.0 (2026-01-22)

Full Changelog: [v0.332.0...v0.333.0](https://github.com/aiinbx/aiinbx-py/compare/v0.332.0...v0.333.0)

### Features

* **api:** api update ([cdc9980](https://github.com/aiinbx/aiinbx-py/commit/cdc998090d64d6e0bf3d07414e68bb3fa9384a84))

## 0.332.0 (2026-01-20)

Full Changelog: [v0.331.0...v0.332.0](https://github.com/aiinbx/aiinbx-py/compare/v0.331.0...v0.332.0)

### Features

* **api:** api update ([ee30ebf](https://github.com/aiinbx/aiinbx-py/commit/ee30ebf739854f585f6d66da51fa69dd93ed4a54))

## 0.331.0 (2026-01-20)

Full Changelog: [v0.330.0...v0.331.0](https://github.com/aiinbx/aiinbx-py/compare/v0.330.0...v0.331.0)

### Features

* **api:** api update ([cc45c3f](https://github.com/aiinbx/aiinbx-py/commit/cc45c3fc0027a3b078d0cbd29f8c7eb915687688))

## 0.330.0 (2026-01-20)

Full Changelog: [v0.329.0...v0.330.0](https://github.com/aiinbx/aiinbx-py/compare/v0.329.0...v0.330.0)

### Features

* **api:** api update ([785f38a](https://github.com/aiinbx/aiinbx-py/commit/785f38ab7c36d31a27bf149da797a4380f6dd2ee))

## 0.329.0 (2026-01-20)

Full Changelog: [v0.328.0...v0.329.0](https://github.com/aiinbx/aiinbx-py/compare/v0.328.0...v0.329.0)

### Features

* **api:** api update ([99314c9](https://github.com/aiinbx/aiinbx-py/commit/99314c964a02375ad27fd9656e2e2ce6ed581021))

## 0.328.0 (2026-01-20)

Full Changelog: [v0.327.0...v0.328.0](https://github.com/aiinbx/aiinbx-py/compare/v0.327.0...v0.328.0)

### Features

* **api:** api update ([7f42d0f](https://github.com/aiinbx/aiinbx-py/commit/7f42d0f17c6e5ddc2bb64c1966c20b7c5b172367))

## 0.327.0 (2026-01-20)

Full Changelog: [v0.326.0...v0.327.0](https://github.com/aiinbx/aiinbx-py/compare/v0.326.0...v0.327.0)

### Features

* **api:** api update ([6e8a3fa](https://github.com/aiinbx/aiinbx-py/commit/6e8a3fa8119aadb685a83c5b64944e946f8791f2))

## 0.326.0 (2026-01-20)

Full Changelog: [v0.325.0...v0.326.0](https://github.com/aiinbx/aiinbx-py/compare/v0.325.0...v0.326.0)

### Features

* **api:** api update ([8836d86](https://github.com/aiinbx/aiinbx-py/commit/8836d8628c4abbf276085c010e9350b805edf071))

## 0.325.0 (2026-01-20)

Full Changelog: [v0.324.0...v0.325.0](https://github.com/aiinbx/aiinbx-py/compare/v0.324.0...v0.325.0)

### Features

* **api:** api update ([9275315](https://github.com/aiinbx/aiinbx-py/commit/927531550f80aefa0632356a1a086ea4c770d5cc))

## 0.324.0 (2026-01-20)

Full Changelog: [v0.323.0...v0.324.0](https://github.com/aiinbx/aiinbx-py/compare/v0.323.0...v0.324.0)

### Features

* **api:** api update ([cf5bde0](https://github.com/aiinbx/aiinbx-py/commit/cf5bde08044d3cbe8218c3f7ef549e7f2a694e80))

## 0.323.0 (2026-01-20)

Full Changelog: [v0.322.0...v0.323.0](https://github.com/aiinbx/aiinbx-py/compare/v0.322.0...v0.323.0)

### Features

* **api:** api update ([0d974ca](https://github.com/aiinbx/aiinbx-py/commit/0d974cadca8266ded3e4e9560a24fafc2d9ff0d4))

## 0.322.0 (2026-01-19)

Full Changelog: [v0.321.0...v0.322.0](https://github.com/aiinbx/aiinbx-py/compare/v0.321.0...v0.322.0)

### Features

* **api:** api update ([b02ef63](https://github.com/aiinbx/aiinbx-py/commit/b02ef63008fe02da3768370aea7a2ea595ec8b68))

## 0.321.0 (2026-01-19)

Full Changelog: [v0.320.0...v0.321.0](https://github.com/aiinbx/aiinbx-py/compare/v0.320.0...v0.321.0)

### Features

* **api:** api update ([56b4e46](https://github.com/aiinbx/aiinbx-py/commit/56b4e46ccb03f29f6661af6d3e3284e70409e38a))

## 0.320.0 (2026-01-19)

Full Changelog: [v0.319.0...v0.320.0](https://github.com/aiinbx/aiinbx-py/compare/v0.319.0...v0.320.0)

### Features

* **api:** api update ([ec4b564](https://github.com/aiinbx/aiinbx-py/commit/ec4b564be82619385e7e6415aa812bfbfbca2bbd))
* **api:** api update ([176671d](https://github.com/aiinbx/aiinbx-py/commit/176671dcaeb8a6a6144dc0de7e646fb73c82edb9))
* **api:** api update ([4e79166](https://github.com/aiinbx/aiinbx-py/commit/4e79166fcac42a34509bf0b2cb2d96ec1e5092cd))
* **api:** api update ([302ce57](https://github.com/aiinbx/aiinbx-py/commit/302ce57628883681b3942a32ce2be2a0fd0f8462))

## 0.319.0 (2026-01-19)

Full Changelog: [v0.318.0...v0.319.0](https://github.com/aiinbx/aiinbx-py/compare/v0.318.0...v0.319.0)

### Features

* **api:** api update ([864f45a](https://github.com/aiinbx/aiinbx-py/commit/864f45aaf5b82bfaf18f37559090e2a7543328d3))

## 0.318.0 (2026-01-19)

Full Changelog: [v0.317.0...v0.318.0](https://github.com/aiinbx/aiinbx-py/compare/v0.317.0...v0.318.0)

### Features

* **api:** api update ([8e27b4b](https://github.com/aiinbx/aiinbx-py/commit/8e27b4b91847b0c26e8a65ca4f38d57a4ea89fc1))

## 0.317.0 (2026-01-18)

Full Changelog: [v0.316.0...v0.317.0](https://github.com/aiinbx/aiinbx-py/compare/v0.316.0...v0.317.0)

### Features

* **api:** api update ([7ab93fc](https://github.com/aiinbx/aiinbx-py/commit/7ab93fc045cdba9c6bdf5a49a4fd2fd684e92007))

## 0.316.0 (2026-01-18)

Full Changelog: [v0.315.0...v0.316.0](https://github.com/aiinbx/aiinbx-py/compare/v0.315.0...v0.316.0)

### Features

* **api:** api update ([5fd28c6](https://github.com/aiinbx/aiinbx-py/commit/5fd28c6c003c03dff747314d711fd17d9ee42e38))

## 0.315.0 (2026-01-18)

Full Changelog: [v0.314.0...v0.315.0](https://github.com/aiinbx/aiinbx-py/compare/v0.314.0...v0.315.0)

### Features

* **api:** api update ([90d73c1](https://github.com/aiinbx/aiinbx-py/commit/90d73c13c03b99626fca2c7d88d772107100c439))

## 0.314.0 (2026-01-18)

Full Changelog: [v0.313.0...v0.314.0](https://github.com/aiinbx/aiinbx-py/compare/v0.313.0...v0.314.0)

### Features

* **api:** api update ([d9bd097](https://github.com/aiinbx/aiinbx-py/commit/d9bd097b204c361fbd8b0a3c12d47421084d0854))

## 0.313.0 (2026-01-17)

Full Changelog: [v0.312.0...v0.313.0](https://github.com/aiinbx/aiinbx-py/compare/v0.312.0...v0.313.0)

### Features

* **api:** api update ([2a00901](https://github.com/aiinbx/aiinbx-py/commit/2a00901d867bba313067778113498cb8af7de293))

## 0.312.0 (2026-01-17)

Full Changelog: [v0.311.0...v0.312.0](https://github.com/aiinbx/aiinbx-py/compare/v0.311.0...v0.312.0)

### Features

* **api:** api update ([c914564](https://github.com/aiinbx/aiinbx-py/commit/c91456484c84837a03d8f68415d8113d3e39812c))


### Chores

* **internal:** update `actions/checkout` version ([46e6739](https://github.com/aiinbx/aiinbx-py/commit/46e67394d5f674534aee6d157d2ba835410f3384))

## 0.311.0 (2026-01-16)

Full Changelog: [v0.310.0...v0.311.0](https://github.com/aiinbx/aiinbx-py/compare/v0.310.0...v0.311.0)

### Features

* **api:** api update ([8841790](https://github.com/aiinbx/aiinbx-py/commit/8841790f4c233f055f23bfe23a1492e520ad348c))

## 0.310.0 (2026-01-16)

Full Changelog: [v0.309.0...v0.310.0](https://github.com/aiinbx/aiinbx-py/compare/v0.309.0...v0.310.0)

### Features

* **api:** api update ([42d9e96](https://github.com/aiinbx/aiinbx-py/commit/42d9e96576a72a1915b96e4c4ab88a26807b8b47))

## 0.309.0 (2026-01-15)

Full Changelog: [v0.308.0...v0.309.0](https://github.com/aiinbx/aiinbx-py/compare/v0.308.0...v0.309.0)

### Features

* **api:** api update ([5ae02d2](https://github.com/aiinbx/aiinbx-py/commit/5ae02d2472673d29109d950afdbd1b04e0df7012))

## 0.308.0 (2026-01-15)

Full Changelog: [v0.307.0...v0.308.0](https://github.com/aiinbx/aiinbx-py/compare/v0.307.0...v0.308.0)

### Features

* **api:** api update ([19cde17](https://github.com/aiinbx/aiinbx-py/commit/19cde1777292940c890b364a46dd318594122d36))

## 0.307.0 (2026-01-15)

Full Changelog: [v0.306.0...v0.307.0](https://github.com/aiinbx/aiinbx-py/compare/v0.306.0...v0.307.0)

### Features

* **api:** api update ([3be4072](https://github.com/aiinbx/aiinbx-py/commit/3be407247dcf81c7e4d69e2f223a22b734e8527f))

## 0.306.0 (2026-01-15)

Full Changelog: [v0.305.0...v0.306.0](https://github.com/aiinbx/aiinbx-py/compare/v0.305.0...v0.306.0)

### Features

* **api:** api update ([1126f12](https://github.com/aiinbx/aiinbx-py/commit/1126f12f9d9830ae7579a92bf88709438a37e2b0))

## 0.305.0 (2026-01-14)

Full Changelog: [v0.304.0...v0.305.0](https://github.com/aiinbx/aiinbx-py/compare/v0.304.0...v0.305.0)

### Features

* **api:** api update ([df8c504](https://github.com/aiinbx/aiinbx-py/commit/df8c504085171b979a49da61a3adc57c519323b8))

## 0.304.0 (2026-01-14)

Full Changelog: [v0.303.0...v0.304.0](https://github.com/aiinbx/aiinbx-py/compare/v0.303.0...v0.304.0)

### Features

* **api:** api update ([9bb6b4e](https://github.com/aiinbx/aiinbx-py/commit/9bb6b4e3141a46ed68490ef81489ae08433f2366))
* **client:** add support for binary request streaming ([02248af](https://github.com/aiinbx/aiinbx-py/commit/02248af6ba4e738898c1dfe668d2f4a029cbbd72))

## 0.303.0 (2026-01-13)

Full Changelog: [v0.302.0...v0.303.0](https://github.com/aiinbx/aiinbx-py/compare/v0.302.0...v0.303.0)

### Features

* **api:** api update ([e12baaf](https://github.com/aiinbx/aiinbx-py/commit/e12baaf7346c7a719e054b4a768cd902b793f822))

## 0.302.0 (2026-01-13)

Full Changelog: [v0.301.0...v0.302.0](https://github.com/aiinbx/aiinbx-py/compare/v0.301.0...v0.302.0)

### Features

* **api:** api update ([54ce375](https://github.com/aiinbx/aiinbx-py/commit/54ce37583101591d0255ca2f83e24e69d3355303))

## 0.301.0 (2026-01-11)

Full Changelog: [v0.300.0...v0.301.0](https://github.com/aiinbx/aiinbx-py/compare/v0.300.0...v0.301.0)

### Features

* **api:** api update ([ea2abd0](https://github.com/aiinbx/aiinbx-py/commit/ea2abd09fe130d4dc689dd24a768a98feb86b215))

## 0.300.0 (2026-01-11)

Full Changelog: [v0.299.0...v0.300.0](https://github.com/aiinbx/aiinbx-py/compare/v0.299.0...v0.300.0)

### Features

* **api:** api update ([1909e9c](https://github.com/aiinbx/aiinbx-py/commit/1909e9c548295d815b6db8685e2d969c08d2c99e))

## 0.299.0 (2026-01-11)

Full Changelog: [v0.298.0...v0.299.0](https://github.com/aiinbx/aiinbx-py/compare/v0.298.0...v0.299.0)

### Features

* **api:** api update ([ae2160f](https://github.com/aiinbx/aiinbx-py/commit/ae2160f6daf3e71f6ef7aa3b3fbe2aa5e434cf44))

## 0.298.0 (2026-01-11)

Full Changelog: [v0.297.0...v0.298.0](https://github.com/aiinbx/aiinbx-py/compare/v0.297.0...v0.298.0)

### Features

* **api:** api update ([eefef4f](https://github.com/aiinbx/aiinbx-py/commit/eefef4f0c85946c278db2df5e1cdb3982e737f4c))

## 0.297.0 (2026-01-10)

Full Changelog: [v0.296.0...v0.297.0](https://github.com/aiinbx/aiinbx-py/compare/v0.296.0...v0.297.0)

### Features

* **api:** api update ([fdfcd76](https://github.com/aiinbx/aiinbx-py/commit/fdfcd76ee85072bec1d32802a0a01abec52b22eb))

## 0.296.0 (2026-01-10)

Full Changelog: [v0.295.0...v0.296.0](https://github.com/aiinbx/aiinbx-py/compare/v0.295.0...v0.296.0)

### Features

* **api:** api update ([901ed50](https://github.com/aiinbx/aiinbx-py/commit/901ed5027a79ab0b265ee8c6409a699693f5ed01))

## 0.295.0 (2026-01-10)

Full Changelog: [v0.294.0...v0.295.0](https://github.com/aiinbx/aiinbx-py/compare/v0.294.0...v0.295.0)

### Features

* **api:** api update ([7ab1ce3](https://github.com/aiinbx/aiinbx-py/commit/7ab1ce396a4de437e7e9e06431c5ec89fb9b0041))

## 0.294.0 (2026-01-10)

Full Changelog: [v0.293.0...v0.294.0](https://github.com/aiinbx/aiinbx-py/compare/v0.293.0...v0.294.0)

### Features

* **api:** api update ([8bdfae1](https://github.com/aiinbx/aiinbx-py/commit/8bdfae18d7d5b55ab600f91b7d8175c07185c294))

## 0.293.0 (2026-01-09)

Full Changelog: [v0.292.0...v0.293.0](https://github.com/aiinbx/aiinbx-py/compare/v0.292.0...v0.293.0)

### Features

* **api:** api update ([df005b4](https://github.com/aiinbx/aiinbx-py/commit/df005b49a90f7af619d4e9bb8c385ce28f0a99a3))

## 0.292.0 (2026-01-09)

Full Changelog: [v0.291.0...v0.292.0](https://github.com/aiinbx/aiinbx-py/compare/v0.291.0...v0.292.0)

### Features

* **api:** api update ([ff26617](https://github.com/aiinbx/aiinbx-py/commit/ff266173ea4b5e0374cd99182e1e37a6fa4b0644))

## 0.291.0 (2026-01-08)

Full Changelog: [v0.290.0...v0.291.0](https://github.com/aiinbx/aiinbx-py/compare/v0.290.0...v0.291.0)

### Features

* **api:** api update ([33d8487](https://github.com/aiinbx/aiinbx-py/commit/33d8487850833e3339dead1107fa46daf7047483))

## 0.290.0 (2026-01-08)

Full Changelog: [v0.289.0...v0.290.0](https://github.com/aiinbx/aiinbx-py/compare/v0.289.0...v0.290.0)

### Features

* **api:** api update ([4857853](https://github.com/aiinbx/aiinbx-py/commit/4857853666a7c99dcf8b07e845a2e753b871bdb3))

## 0.289.0 (2026-01-07)

Full Changelog: [v0.288.0...v0.289.0](https://github.com/aiinbx/aiinbx-py/compare/v0.288.0...v0.289.0)

### Features

* **api:** api update ([7df8c94](https://github.com/aiinbx/aiinbx-py/commit/7df8c94b8caf39f5845978fb3cc9bc5b8aab786b))

## 0.288.0 (2026-01-07)

Full Changelog: [v0.287.0...v0.288.0](https://github.com/aiinbx/aiinbx-py/compare/v0.287.0...v0.288.0)

### Features

* **api:** api update ([64cb4de](https://github.com/aiinbx/aiinbx-py/commit/64cb4de71ee854b5b188344078b03266a82d7e3c))

## 0.287.0 (2026-01-07)

Full Changelog: [v0.286.0...v0.287.0](https://github.com/aiinbx/aiinbx-py/compare/v0.286.0...v0.287.0)

### Features

* **api:** api update ([a9352f9](https://github.com/aiinbx/aiinbx-py/commit/a9352f94121a95e9867803a5ab8d61fd4c546828))

## 0.286.0 (2026-01-07)

Full Changelog: [v0.285.0...v0.286.0](https://github.com/aiinbx/aiinbx-py/compare/v0.285.0...v0.286.0)

### Features

* **api:** api update ([98830c2](https://github.com/aiinbx/aiinbx-py/commit/98830c27455d2fff942e6475154e14796f2fa8b7))


### Documentation

* prominently feature MCP server setup in root SDK readmes ([3df28c1](https://github.com/aiinbx/aiinbx-py/commit/3df28c1a1fde175530de2eca9a3574fccf26ac23))

## 0.285.0 (2026-01-06)

Full Changelog: [v0.284.0...v0.285.0](https://github.com/aiinbx/aiinbx-py/compare/v0.284.0...v0.285.0)

### Features

* **api:** api update ([3c5b036](https://github.com/aiinbx/aiinbx-py/commit/3c5b036d42270e48866d55aedcc22caf0d99d0d4))

## 0.284.0 (2026-01-06)

Full Changelog: [v0.283.0...v0.284.0](https://github.com/aiinbx/aiinbx-py/compare/v0.283.0...v0.284.0)

### Features

* **api:** api update ([3f2d95f](https://github.com/aiinbx/aiinbx-py/commit/3f2d95f8c4d2b0ff52acd231321fca47d24bb387))

## 0.283.0 (2026-01-04)

Full Changelog: [v0.282.0...v0.283.0](https://github.com/aiinbx/aiinbx-py/compare/v0.282.0...v0.283.0)

### Features

* **api:** api update ([598758f](https://github.com/aiinbx/aiinbx-py/commit/598758f83a40a68c28e467a748fdd655e0828ec9))

## 0.282.0 (2026-01-04)

Full Changelog: [v0.281.0...v0.282.0](https://github.com/aiinbx/aiinbx-py/compare/v0.281.0...v0.282.0)

### Features

* **api:** api update ([c3fcf69](https://github.com/aiinbx/aiinbx-py/commit/c3fcf69279dc8fb55faea720b848157cf6351fc4))

## 0.281.0 (2026-01-04)

Full Changelog: [v0.280.0...v0.281.0](https://github.com/aiinbx/aiinbx-py/compare/v0.280.0...v0.281.0)

### Features

* **api:** api update ([9cb1cb2](https://github.com/aiinbx/aiinbx-py/commit/9cb1cb2b2bc4b08b31c0bf997214597f0818986d))

## 0.280.0 (2026-01-04)

Full Changelog: [v0.279.0...v0.280.0](https://github.com/aiinbx/aiinbx-py/compare/v0.279.0...v0.280.0)

### Features

* **api:** api update ([a8b7c99](https://github.com/aiinbx/aiinbx-py/commit/a8b7c99b8dc1a43d95eef114df0ed9b6a86937e3))

## 0.279.0 (2026-01-04)

Full Changelog: [v0.278.0...v0.279.0](https://github.com/aiinbx/aiinbx-py/compare/v0.278.0...v0.279.0)

### Features

* **api:** api update ([ebbb487](https://github.com/aiinbx/aiinbx-py/commit/ebbb487dd4ae5dbefc316762b076d1fd7779bd0c))

## 0.278.0 (2026-01-04)

Full Changelog: [v0.277.0...v0.278.0](https://github.com/aiinbx/aiinbx-py/compare/v0.277.0...v0.278.0)

### Features

* **api:** api update ([42cb134](https://github.com/aiinbx/aiinbx-py/commit/42cb134e7ada539b083468f055b360aac05e5a11))

## 0.277.0 (2026-01-04)

Full Changelog: [v0.276.0...v0.277.0](https://github.com/aiinbx/aiinbx-py/compare/v0.276.0...v0.277.0)

### Features

* **api:** api update ([f1f74d3](https://github.com/aiinbx/aiinbx-py/commit/f1f74d37cebe0866bdda51528c992f821f68358e))

## 0.276.0 (2026-01-04)

Full Changelog: [v0.275.0...v0.276.0](https://github.com/aiinbx/aiinbx-py/compare/v0.275.0...v0.276.0)

### Features

* **api:** api update ([23a2c47](https://github.com/aiinbx/aiinbx-py/commit/23a2c47615a1cf911c0c6baff08f4f6fe850de14))

## 0.275.0 (2026-01-03)

Full Changelog: [v0.274.0...v0.275.0](https://github.com/aiinbx/aiinbx-py/compare/v0.274.0...v0.275.0)

### Features

* **api:** api update ([8db12ca](https://github.com/aiinbx/aiinbx-py/commit/8db12caeb00b39e85425f16c703d2c571d8fe021))
* **api:** api update ([5e26990](https://github.com/aiinbx/aiinbx-py/commit/5e269900ed71244ff5e65282ef3554ecff8773ea))

## 0.274.0 (2026-01-03)

Full Changelog: [v0.273.0...v0.274.0](https://github.com/aiinbx/aiinbx-py/compare/v0.273.0...v0.274.0)

### Features

* **api:** api update ([09bbf98](https://github.com/aiinbx/aiinbx-py/commit/09bbf985a0e65675ca5bc2727f64647e0d0596b1))

## 0.273.0 (2026-01-03)

Full Changelog: [v0.272.0...v0.273.0](https://github.com/aiinbx/aiinbx-py/compare/v0.272.0...v0.273.0)

### Features

* **api:** api update ([fd18b15](https://github.com/aiinbx/aiinbx-py/commit/fd18b155aa92a7d5f6c58058387324df73ab685d))

## 0.272.0 (2026-01-02)

Full Changelog: [v0.271.0...v0.272.0](https://github.com/aiinbx/aiinbx-py/compare/v0.271.0...v0.272.0)

### Features

* **api:** api update ([7debe54](https://github.com/aiinbx/aiinbx-py/commit/7debe546a80c19f9421b79588857acf4a19fe8d7))

## 0.271.0 (2026-01-02)

Full Changelog: [v0.270.0...v0.271.0](https://github.com/aiinbx/aiinbx-py/compare/v0.270.0...v0.271.0)

### Features

* **api:** api update ([f9d40e5](https://github.com/aiinbx/aiinbx-py/commit/f9d40e57c9303c01adeccebce2ba35a49f6ad6d5))

## 0.270.0 (2026-01-02)

Full Changelog: [v0.269.0...v0.270.0](https://github.com/aiinbx/aiinbx-py/compare/v0.269.0...v0.270.0)

### Features

* **api:** api update ([05af418](https://github.com/aiinbx/aiinbx-py/commit/05af41863c1fa702d2510c7d9eaa6e6be038cec4))

## 0.269.0 (2026-01-02)

Full Changelog: [v0.268.0...v0.269.0](https://github.com/aiinbx/aiinbx-py/compare/v0.268.0...v0.269.0)

### Features

* **api:** api update ([5e2b80a](https://github.com/aiinbx/aiinbx-py/commit/5e2b80ab729504fcf091222c562263730facc43f))

## 0.268.0 (2026-01-02)

Full Changelog: [v0.267.0...v0.268.0](https://github.com/aiinbx/aiinbx-py/compare/v0.267.0...v0.268.0)

### Features

* **api:** api update ([b46a2fb](https://github.com/aiinbx/aiinbx-py/commit/b46a2fbcc6596d2c864625c303ebd3e6ffe27296))

## 0.267.0 (2026-01-02)

Full Changelog: [v0.266.0...v0.267.0](https://github.com/aiinbx/aiinbx-py/compare/v0.266.0...v0.267.0)

### Features

* **api:** api update ([c538b3d](https://github.com/aiinbx/aiinbx-py/commit/c538b3d38e6390f6a9da7886d55976ff184372ff))

## 0.266.0 (2026-01-01)

Full Changelog: [v0.265.0...v0.266.0](https://github.com/aiinbx/aiinbx-py/compare/v0.265.0...v0.266.0)

### Features

* **api:** api update ([bc898ff](https://github.com/aiinbx/aiinbx-py/commit/bc898ffb67e28df36da0ce4ffae5ae6f2532f876))

## 0.265.0 (2026-01-01)

Full Changelog: [v0.264.0...v0.265.0](https://github.com/aiinbx/aiinbx-py/compare/v0.264.0...v0.265.0)

### Features

* **api:** api update ([16bb88d](https://github.com/aiinbx/aiinbx-py/commit/16bb88d318c5212a55bb8cf7e1d54853b990ffb2))

## 0.264.0 (2026-01-01)

Full Changelog: [v0.263.0...v0.264.0](https://github.com/aiinbx/aiinbx-py/compare/v0.263.0...v0.264.0)

### Features

* **api:** api update ([4629b2e](https://github.com/aiinbx/aiinbx-py/commit/4629b2e1fd699b4ed8892415959b82afea8da653))

## 0.263.0 (2026-01-01)

Full Changelog: [v0.262.0...v0.263.0](https://github.com/aiinbx/aiinbx-py/compare/v0.262.0...v0.263.0)

### Features

* **api:** api update ([9da2a44](https://github.com/aiinbx/aiinbx-py/commit/9da2a44e05b8f4bf583f32cefdd22573d6840c13))

## 0.262.0 (2026-01-01)

Full Changelog: [v0.261.0...v0.262.0](https://github.com/aiinbx/aiinbx-py/compare/v0.261.0...v0.262.0)

### Features

* **api:** api update ([e4a7610](https://github.com/aiinbx/aiinbx-py/commit/e4a76108683d2137e0c3ec950b04c82213983a29))

## 0.261.0 (2026-01-01)

Full Changelog: [v0.260.0...v0.261.0](https://github.com/aiinbx/aiinbx-py/compare/v0.260.0...v0.261.0)

### Features

* **api:** api update ([2e24493](https://github.com/aiinbx/aiinbx-py/commit/2e244935d3f3732cb48a48b69b745de586746258))

## 0.260.0 (2025-12-31)

Full Changelog: [v0.259.0...v0.260.0](https://github.com/aiinbx/aiinbx-py/compare/v0.259.0...v0.260.0)

### Features

* **api:** api update ([3797105](https://github.com/aiinbx/aiinbx-py/commit/37971052bc26a001c1828e85fd0e41ceb936072b))

## 0.259.0 (2025-12-31)

Full Changelog: [v0.258.0...v0.259.0](https://github.com/aiinbx/aiinbx-py/compare/v0.258.0...v0.259.0)

### Features

* **api:** api update ([ccea5b6](https://github.com/aiinbx/aiinbx-py/commit/ccea5b656de91cdf20f3c631360af7f1526673a3))

## 0.258.0 (2025-12-31)

Full Changelog: [v0.257.0...v0.258.0](https://github.com/aiinbx/aiinbx-py/compare/v0.257.0...v0.258.0)

### Features

* **api:** api update ([098a7c0](https://github.com/aiinbx/aiinbx-py/commit/098a7c06bb8e3d6c3175ebcee83d6d9e6a2c652f))

## 0.257.0 (2025-12-31)

Full Changelog: [v0.256.0...v0.257.0](https://github.com/aiinbx/aiinbx-py/compare/v0.256.0...v0.257.0)

### Features

* **api:** api update ([aab8ece](https://github.com/aiinbx/aiinbx-py/commit/aab8ece106c1dba8fad2391a382fab25fabf1b33))

## 0.256.0 (2025-12-31)

Full Changelog: [v0.255.0...v0.256.0](https://github.com/aiinbx/aiinbx-py/compare/v0.255.0...v0.256.0)

### Features

* **api:** api update ([4c344c9](https://github.com/aiinbx/aiinbx-py/commit/4c344c900bb0264cc2bfcfea4444c76c0cc16c75))

## 0.255.0 (2025-12-29)

Full Changelog: [v0.254.0...v0.255.0](https://github.com/aiinbx/aiinbx-py/compare/v0.254.0...v0.255.0)

### Features

* **api:** api update ([5bf2890](https://github.com/aiinbx/aiinbx-py/commit/5bf28906148c892ee3d6900a7848973bcff1f37b))

## 0.254.0 (2025-12-29)

Full Changelog: [v0.253.0...v0.254.0](https://github.com/aiinbx/aiinbx-py/compare/v0.253.0...v0.254.0)

### Features

* **api:** api update ([f7ce4f1](https://github.com/aiinbx/aiinbx-py/commit/f7ce4f1953ad31942c11c1774e812cc59bdba4ec))

## 0.253.0 (2025-12-28)

Full Changelog: [v0.252.0...v0.253.0](https://github.com/aiinbx/aiinbx-py/compare/v0.252.0...v0.253.0)

### Features

* **api:** api update ([ff82596](https://github.com/aiinbx/aiinbx-py/commit/ff8259658a6ab041b2057040892d943e2efb5db5))

## 0.252.0 (2025-12-28)

Full Changelog: [v0.251.0...v0.252.0](https://github.com/aiinbx/aiinbx-py/compare/v0.251.0...v0.252.0)

### Features

* **api:** api update ([afd2b4e](https://github.com/aiinbx/aiinbx-py/commit/afd2b4ea75e771583b18a2519d34837088c1d119))

## 0.251.0 (2025-12-28)

Full Changelog: [v0.250.0...v0.251.0](https://github.com/aiinbx/aiinbx-py/compare/v0.250.0...v0.251.0)

### Features

* **api:** api update ([ba96f02](https://github.com/aiinbx/aiinbx-py/commit/ba96f0251db5b4d0cd4c5e6c7c2189c4d5f2a24e))

## 0.250.0 (2025-12-28)

Full Changelog: [v0.249.0...v0.250.0](https://github.com/aiinbx/aiinbx-py/compare/v0.249.0...v0.250.0)

### Features

* **api:** api update ([ffc2783](https://github.com/aiinbx/aiinbx-py/commit/ffc2783aafbd27ba940015ab894dddd0904500c1))

## 0.249.0 (2025-12-27)

Full Changelog: [v0.248.0...v0.249.0](https://github.com/aiinbx/aiinbx-py/compare/v0.248.0...v0.249.0)

### Features

* **api:** api update ([12aaca2](https://github.com/aiinbx/aiinbx-py/commit/12aaca2b4ab004d51dce59607de54474729f9a0b))

## 0.248.0 (2025-12-26)

Full Changelog: [v0.247.0...v0.248.0](https://github.com/aiinbx/aiinbx-py/compare/v0.247.0...v0.248.0)

### Features

* **api:** api update ([642845c](https://github.com/aiinbx/aiinbx-py/commit/642845c31c2b0cffcea958ee5cb88585e14b1678))

## 0.247.0 (2025-12-26)

Full Changelog: [v0.246.0...v0.247.0](https://github.com/aiinbx/aiinbx-py/compare/v0.246.0...v0.247.0)

### Features

* **api:** api update ([1a5a659](https://github.com/aiinbx/aiinbx-py/commit/1a5a65992763c1f416edae183c75172e11b41c4d))

## 0.246.0 (2025-12-26)

Full Changelog: [v0.245.0...v0.246.0](https://github.com/aiinbx/aiinbx-py/compare/v0.245.0...v0.246.0)

### Features

* **api:** api update ([aaf2808](https://github.com/aiinbx/aiinbx-py/commit/aaf2808bf572bf06ae6ac24214da71a6cea49bf3))

## 0.245.0 (2025-12-25)

Full Changelog: [v0.244.0...v0.245.0](https://github.com/aiinbx/aiinbx-py/compare/v0.244.0...v0.245.0)

### Features

* **api:** api update ([b81f084](https://github.com/aiinbx/aiinbx-py/commit/b81f084a18b2b81c48e348f40ef02b3ded34523e))

## 0.244.0 (2025-12-25)

Full Changelog: [v0.243.0...v0.244.0](https://github.com/aiinbx/aiinbx-py/compare/v0.243.0...v0.244.0)

### Features

* **api:** api update ([3b10190](https://github.com/aiinbx/aiinbx-py/commit/3b10190c55ac240186fd1183e6e666bbb0f9ebeb))

## 0.243.0 (2025-12-24)

Full Changelog: [v0.242.0...v0.243.0](https://github.com/aiinbx/aiinbx-py/compare/v0.242.0...v0.243.0)

### Features

* **api:** api update ([d102d60](https://github.com/aiinbx/aiinbx-py/commit/d102d603c753d27071e323996f2f977009de5ae4))

## 0.242.0 (2025-12-24)

Full Changelog: [v0.241.0...v0.242.0](https://github.com/aiinbx/aiinbx-py/compare/v0.241.0...v0.242.0)

### Features

* **api:** api update ([0c6d08e](https://github.com/aiinbx/aiinbx-py/commit/0c6d08eafdc8b1b4a220e139ec195be2dff421b6))

## 0.241.0 (2025-12-23)

Full Changelog: [v0.240.0...v0.241.0](https://github.com/aiinbx/aiinbx-py/compare/v0.240.0...v0.241.0)

### Features

* **api:** api update ([d999709](https://github.com/aiinbx/aiinbx-py/commit/d999709e44259f98b7f0fe8b7e58291197955f42))

## 0.240.0 (2025-12-23)

Full Changelog: [v0.239.0...v0.240.0](https://github.com/aiinbx/aiinbx-py/compare/v0.239.0...v0.240.0)

### Features

* **api:** api update ([7d2c3f0](https://github.com/aiinbx/aiinbx-py/commit/7d2c3f0538bcd9e0876e0fe5420fd6e5025cd14d))

## 0.239.0 (2025-12-22)

Full Changelog: [v0.238.0...v0.239.0](https://github.com/aiinbx/aiinbx-py/compare/v0.238.0...v0.239.0)

### Features

* **api:** api update ([fe86fde](https://github.com/aiinbx/aiinbx-py/commit/fe86fdefc129164271064368aaa2edf156f1a44b))

## 0.238.0 (2025-12-22)

Full Changelog: [v0.237.0...v0.238.0](https://github.com/aiinbx/aiinbx-py/compare/v0.237.0...v0.238.0)

### Features

* **api:** api update ([a10d7ec](https://github.com/aiinbx/aiinbx-py/commit/a10d7ec210bbb727dbe3ab77fe021d91bf261139))

## 0.237.0 (2025-12-22)

Full Changelog: [v0.236.0...v0.237.0](https://github.com/aiinbx/aiinbx-py/compare/v0.236.0...v0.237.0)

### Features

* **api:** api update ([b014701](https://github.com/aiinbx/aiinbx-py/commit/b014701ea731100648d3449952fded286ea7f10c))
* **api:** api update ([2534a60](https://github.com/aiinbx/aiinbx-py/commit/2534a60ead85cb96f860a4e8249a42711a53e0c3))
* **api:** api update ([31d3620](https://github.com/aiinbx/aiinbx-py/commit/31d3620dff83711ebd0f2a21b572c9ff0929e475))

## 0.236.0 (2025-12-21)

Full Changelog: [v0.235.0...v0.236.0](https://github.com/aiinbx/aiinbx-py/compare/v0.235.0...v0.236.0)

### Features

* **api:** api update ([6592f54](https://github.com/aiinbx/aiinbx-py/commit/6592f545ec5c85f9bc4bbed8e8856f3a325e6399))

## 0.235.0 (2025-12-21)

Full Changelog: [v0.234.0...v0.235.0](https://github.com/aiinbx/aiinbx-py/compare/v0.234.0...v0.235.0)

### Features

* **api:** api update ([83c3729](https://github.com/aiinbx/aiinbx-py/commit/83c372963211dbb63c0c34b169fb5468ddb7b480))

## 0.234.0 (2025-12-21)

Full Changelog: [v0.233.0...v0.234.0](https://github.com/aiinbx/aiinbx-py/compare/v0.233.0...v0.234.0)

### Features

* **api:** api update ([5715324](https://github.com/aiinbx/aiinbx-py/commit/5715324f9e77764b0bcc32f223489e265c9f5178))

## 0.233.0 (2025-12-20)

Full Changelog: [v0.232.0...v0.233.0](https://github.com/aiinbx/aiinbx-py/compare/v0.232.0...v0.233.0)

### Features

* **api:** api update ([530e222](https://github.com/aiinbx/aiinbx-py/commit/530e222426dfcae119157daaff6e6039414962a0))

## 0.232.0 (2025-12-20)

Full Changelog: [v0.231.0...v0.232.0](https://github.com/aiinbx/aiinbx-py/compare/v0.231.0...v0.232.0)

### Features

* **api:** api update ([a2d5f32](https://github.com/aiinbx/aiinbx-py/commit/a2d5f32faa59e542076a964963219d117810c960))

## 0.231.0 (2025-12-20)

Full Changelog: [v0.230.0...v0.231.0](https://github.com/aiinbx/aiinbx-py/compare/v0.230.0...v0.231.0)

### Features

* **api:** api update ([284a8b8](https://github.com/aiinbx/aiinbx-py/commit/284a8b88ebed8918566c59b4d7b40f9156d6ddae))

## 0.230.0 (2025-12-20)

Full Changelog: [v0.229.0...v0.230.0](https://github.com/aiinbx/aiinbx-py/compare/v0.229.0...v0.230.0)

### Features

* **api:** api update ([b53e899](https://github.com/aiinbx/aiinbx-py/commit/b53e8991f3d7f41610e6a766416266625ec9c93d))

## 0.229.0 (2025-12-20)

Full Changelog: [v0.228.0...v0.229.0](https://github.com/aiinbx/aiinbx-py/compare/v0.228.0...v0.229.0)

### Features

* **api:** api update ([b61aada](https://github.com/aiinbx/aiinbx-py/commit/b61aada974931aba9549c306be0950edc2b600f4))

## 0.228.0 (2025-12-20)

Full Changelog: [v0.227.0...v0.228.0](https://github.com/aiinbx/aiinbx-py/compare/v0.227.0...v0.228.0)

### Features

* **api:** api update ([3ee4683](https://github.com/aiinbx/aiinbx-py/commit/3ee4683a5557b0cc6828ae84d5a502fd23a3b3b6))

## 0.227.0 (2025-12-19)

Full Changelog: [v0.226.0...v0.227.0](https://github.com/aiinbx/aiinbx-py/compare/v0.226.0...v0.227.0)

### Features

* **api:** api update ([3ae2f08](https://github.com/aiinbx/aiinbx-py/commit/3ae2f08640e85f460e9a3d708d84bef9cbef8bcb))


### Chores

* **internal:** add `--fix` argument to lint script ([1af0379](https://github.com/aiinbx/aiinbx-py/commit/1af0379356c3f03207ebbff709c7aac920764001))

## 0.226.0 (2025-12-18)

Full Changelog: [v0.225.1...v0.226.0](https://github.com/aiinbx/aiinbx-py/compare/v0.225.1...v0.226.0)

### Features

* **api:** api update ([4b33717](https://github.com/aiinbx/aiinbx-py/commit/4b33717a9a4e633026be35a3cffadcc8e1ada107))

## 0.225.1 (2025-12-18)

Full Changelog: [v0.225.0...v0.225.1](https://github.com/aiinbx/aiinbx-py/compare/v0.225.0...v0.225.1)

### Bug Fixes

* use async_to_httpx_files in patch method ([db08a78](https://github.com/aiinbx/aiinbx-py/commit/db08a785f058cba74a0a26f6852176fdef442129))

## 0.225.0 (2025-12-17)

Full Changelog: [v0.224.0...v0.225.0](https://github.com/aiinbx/aiinbx-py/compare/v0.224.0...v0.225.0)

### Features

* **api:** api update ([ad22125](https://github.com/aiinbx/aiinbx-py/commit/ad22125fd7e57529a5609a3a6bf7caa29a6fc535))

## 0.224.0 (2025-12-17)

Full Changelog: [v0.223.0...v0.224.0](https://github.com/aiinbx/aiinbx-py/compare/v0.223.0...v0.224.0)

### Features

* **api:** api update ([7b466d4](https://github.com/aiinbx/aiinbx-py/commit/7b466d4b61ca7e64d11457febbd77b943408019e))


### Chores

* speedup initial import ([8bdae09](https://github.com/aiinbx/aiinbx-py/commit/8bdae096cea1f3f975729ba6daa759852fe5e656))

## 0.223.0 (2025-12-16)

Full Changelog: [v0.222.0...v0.223.0](https://github.com/aiinbx/aiinbx-py/compare/v0.222.0...v0.223.0)

### Features

* **api:** api update ([ad5fbea](https://github.com/aiinbx/aiinbx-py/commit/ad5fbead604413f6b8b27af803219154269643fc))

## 0.222.0 (2025-12-16)

Full Changelog: [v0.221.0...v0.222.0](https://github.com/aiinbx/aiinbx-py/compare/v0.221.0...v0.222.0)

### Features

* **api:** api update ([cd00058](https://github.com/aiinbx/aiinbx-py/commit/cd00058f5a6a008ca5d435541b0b5ad8f3c2b2ee))

## 0.221.0 (2025-12-16)

Full Changelog: [v0.220.0...v0.221.0](https://github.com/aiinbx/aiinbx-py/compare/v0.220.0...v0.221.0)

### Features

* **api:** api update ([b41d280](https://github.com/aiinbx/aiinbx-py/commit/b41d2809bbbf29b5803494b6cd7e90889269169b))
* **api:** api update ([32e15a9](https://github.com/aiinbx/aiinbx-py/commit/32e15a9f180855f53ef4ac38dbb76d089b82b998))

## 0.220.0 (2025-12-16)

Full Changelog: [v0.219.0...v0.220.0](https://github.com/aiinbx/aiinbx-py/compare/v0.219.0...v0.220.0)

### Features

* **api:** api update ([e4ced7e](https://github.com/aiinbx/aiinbx-py/commit/e4ced7ea8cd82eaf78dfb286e359d3be94823275))


### Chores

* **internal:** add missing files argument to base client ([a11c7d9](https://github.com/aiinbx/aiinbx-py/commit/a11c7d9b4181341f10c827605d957895f39be6bb))

## 0.219.0 (2025-12-14)

Full Changelog: [v0.218.0...v0.219.0](https://github.com/aiinbx/aiinbx-py/compare/v0.218.0...v0.219.0)

### Features

* **api:** api update ([9658430](https://github.com/aiinbx/aiinbx-py/commit/96584305cdc6e97e569bd588de1086e31712746b))

## 0.218.0 (2025-12-14)

Full Changelog: [v0.217.0...v0.218.0](https://github.com/aiinbx/aiinbx-py/compare/v0.217.0...v0.218.0)

### Features

* **api:** api update ([52b32e3](https://github.com/aiinbx/aiinbx-py/commit/52b32e346d7f3b3dacb108fc41bc8c42d8b53230))

## 0.217.0 (2025-12-14)

Full Changelog: [v0.216.0...v0.217.0](https://github.com/aiinbx/aiinbx-py/compare/v0.216.0...v0.217.0)

### Features

* **api:** api update ([1aad158](https://github.com/aiinbx/aiinbx-py/commit/1aad1589c4be019f0d3834ebf96ac0a03866dc6c))

## 0.216.0 (2025-12-14)

Full Changelog: [v0.215.0...v0.216.0](https://github.com/aiinbx/aiinbx-py/compare/v0.215.0...v0.216.0)

### Features

* **api:** api update ([034d734](https://github.com/aiinbx/aiinbx-py/commit/034d734d4e13415fbca070a4a68be7083ad3a592))

## 0.215.0 (2025-12-12)

Full Changelog: [v0.214.0...v0.215.0](https://github.com/aiinbx/aiinbx-py/compare/v0.214.0...v0.215.0)

### Features

* **api:** api update ([2bf2f4c](https://github.com/aiinbx/aiinbx-py/commit/2bf2f4c06b65883a23f8cfaf15d364ca2921577c))

## 0.214.0 (2025-12-12)

Full Changelog: [v0.213.0...v0.214.0](https://github.com/aiinbx/aiinbx-py/compare/v0.213.0...v0.214.0)

### Features

* **api:** api update ([96bc00b](https://github.com/aiinbx/aiinbx-py/commit/96bc00b6f1e453df6db25e0007784e4ae8140d94))

## 0.213.0 (2025-12-11)

Full Changelog: [v0.212.0...v0.213.0](https://github.com/aiinbx/aiinbx-py/compare/v0.212.0...v0.213.0)

### Features

* **api:** api update ([15d7300](https://github.com/aiinbx/aiinbx-py/commit/15d730003e57134ce75205a315b7e9edd2c24e3b))

## 0.212.0 (2025-12-11)

Full Changelog: [v0.211.0...v0.212.0](https://github.com/aiinbx/aiinbx-py/compare/v0.211.0...v0.212.0)

### Features

* **api:** api update ([f1a2359](https://github.com/aiinbx/aiinbx-py/commit/f1a2359f4d7276a6321820cf8c4b64f9a7411944))

## 0.211.0 (2025-12-09)

Full Changelog: [v0.210.0...v0.211.0](https://github.com/aiinbx/aiinbx-py/compare/v0.210.0...v0.211.0)

### Features

* **api:** api update ([c73ca0f](https://github.com/aiinbx/aiinbx-py/commit/c73ca0fcaa079ed4015e4db7f00bbda81b6ddd79))

## 0.210.0 (2025-12-09)

Full Changelog: [v0.209.0...v0.210.0](https://github.com/aiinbx/aiinbx-py/compare/v0.209.0...v0.210.0)

### Features

* **api:** api update ([b1d2671](https://github.com/aiinbx/aiinbx-py/commit/b1d2671a2fdb072401cf4516894153bf39147840))

## 0.209.0 (2025-12-09)

Full Changelog: [v0.208.0...v0.209.0](https://github.com/aiinbx/aiinbx-py/compare/v0.208.0...v0.209.0)

### Features

* **api:** api update ([1ecf050](https://github.com/aiinbx/aiinbx-py/commit/1ecf050690af1d84f62b99a75d592ab1d3751380))

## 0.208.0 (2025-12-09)

Full Changelog: [v0.207.0...v0.208.0](https://github.com/aiinbx/aiinbx-py/compare/v0.207.0...v0.208.0)

### Features

* **api:** api update ([d123f50](https://github.com/aiinbx/aiinbx-py/commit/d123f50c3d6eee860164a43b2ba2f8e365205fe8))

## 0.207.0 (2025-12-09)

Full Changelog: [v0.206.0...v0.207.0](https://github.com/aiinbx/aiinbx-py/compare/v0.206.0...v0.207.0)

### Features

* **api:** api update ([4778044](https://github.com/aiinbx/aiinbx-py/commit/477804465392d86fcbeb109b4523ff82d19c2fe8))

## 0.206.0 (2025-12-09)

Full Changelog: [v0.205.1...v0.206.0](https://github.com/aiinbx/aiinbx-py/compare/v0.205.1...v0.206.0)

### Features

* **api:** api update ([1cb310d](https://github.com/aiinbx/aiinbx-py/commit/1cb310d5092cfd301ac7b63a8725db05f27fa0bc))

## 0.205.1 (2025-12-09)

Full Changelog: [v0.205.0...v0.205.1](https://github.com/aiinbx/aiinbx-py/compare/v0.205.0...v0.205.1)

### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([60a68e7](https://github.com/aiinbx/aiinbx-py/commit/60a68e79093f84f630404fe209801fcc11a560df))

## 0.205.0 (2025-12-08)

Full Changelog: [v0.204.0...v0.205.0](https://github.com/aiinbx/aiinbx-py/compare/v0.204.0...v0.205.0)

### Features

* **api:** api update ([435a74a](https://github.com/aiinbx/aiinbx-py/commit/435a74a54734b0cc3586743c6fdb2e87bd09a96c))

## 0.204.0 (2025-12-08)

Full Changelog: [v0.203.0...v0.204.0](https://github.com/aiinbx/aiinbx-py/compare/v0.203.0...v0.204.0)

### Features

* **api:** api update ([fea2aee](https://github.com/aiinbx/aiinbx-py/commit/fea2aee2d062789526aa48310a3e681f3cb8c6ef))

## 0.203.0 (2025-12-08)

Full Changelog: [v0.202.0...v0.203.0](https://github.com/aiinbx/aiinbx-py/compare/v0.202.0...v0.203.0)

### Features

* **api:** api update ([89932d1](https://github.com/aiinbx/aiinbx-py/commit/89932d19fdb02849bed273ffed9ea18353c406c3))

## 0.202.0 (2025-12-08)

Full Changelog: [v0.201.0...v0.202.0](https://github.com/aiinbx/aiinbx-py/compare/v0.201.0...v0.202.0)

### Features

* **api:** api update ([6b33466](https://github.com/aiinbx/aiinbx-py/commit/6b33466e2abddf0330f8428c6cf833360115fd42))

## 0.201.0 (2025-12-07)

Full Changelog: [v0.200.0...v0.201.0](https://github.com/aiinbx/aiinbx-py/compare/v0.200.0...v0.201.0)

### Features

* **api:** api update ([e295810](https://github.com/aiinbx/aiinbx-py/commit/e295810fd3920439289945558c0fee4e6e4bc64b))

## 0.200.0 (2025-12-07)

Full Changelog: [v0.199.0...v0.200.0](https://github.com/aiinbx/aiinbx-py/compare/v0.199.0...v0.200.0)

### Features

* **api:** api update ([64ba0c5](https://github.com/aiinbx/aiinbx-py/commit/64ba0c5de44bbd0ff052003ed4558874695b710d))

## 0.199.0 (2025-12-04)

Full Changelog: [v0.198.0...v0.199.0](https://github.com/aiinbx/aiinbx-py/compare/v0.198.0...v0.199.0)

### Features

* **api:** api update ([2a80f11](https://github.com/aiinbx/aiinbx-py/commit/2a80f11b733e0728f7aeaa09b9e4525b0b0b582c))

## 0.198.0 (2025-12-04)

Full Changelog: [v0.197.0...v0.198.0](https://github.com/aiinbx/aiinbx-py/compare/v0.197.0...v0.198.0)

### Features

* **api:** api update ([3861e7d](https://github.com/aiinbx/aiinbx-py/commit/3861e7d7cc5298c10837e6a693ec01a671206411))

## 0.197.0 (2025-12-04)

Full Changelog: [v0.196.0...v0.197.0](https://github.com/aiinbx/aiinbx-py/compare/v0.196.0...v0.197.0)

### Features

* **api:** api update ([88d45e6](https://github.com/aiinbx/aiinbx-py/commit/88d45e6241a9067302c5a3d6381ce22d780b9a8e))

## 0.196.0 (2025-12-04)

Full Changelog: [v0.195.0...v0.196.0](https://github.com/aiinbx/aiinbx-py/compare/v0.195.0...v0.196.0)

### Features

* **api:** api update ([e81d3c2](https://github.com/aiinbx/aiinbx-py/commit/e81d3c2c2fee5b155bc2655ba94f5df8957a6b69))

## 0.195.0 (2025-12-03)

Full Changelog: [v0.194.0...v0.195.0](https://github.com/aiinbx/aiinbx-py/compare/v0.194.0...v0.195.0)

### Features

* **api:** api update ([6757d59](https://github.com/aiinbx/aiinbx-py/commit/6757d5977fc8cfacc448327d03fa2a3c4bf54457))

## 0.194.0 (2025-12-03)

Full Changelog: [v0.193.0...v0.194.0](https://github.com/aiinbx/aiinbx-py/compare/v0.193.0...v0.194.0)

### Features

* **api:** api update ([8996b90](https://github.com/aiinbx/aiinbx-py/commit/8996b90d7fa3905f64adc1813e3830ee7bd96a80))


### Chores

* **docs:** use environment variables for authentication in code snippets ([d8471a9](https://github.com/aiinbx/aiinbx-py/commit/d8471a9f8c4cf903090ecd69208047392bd571f3))
* **internal:** codegen related update ([b5100ac](https://github.com/aiinbx/aiinbx-py/commit/b5100ac4d999efc9152ae9dd977380489bcc8a98))
* update lockfile ([fc736ad](https://github.com/aiinbx/aiinbx-py/commit/fc736ada56e81b991fd68a0eacfeaaa173926166))

## 0.193.0 (2025-12-03)

Full Changelog: [v0.192.0...v0.193.0](https://github.com/aiinbx/aiinbx-py/compare/v0.192.0...v0.193.0)

### Features

* **api:** api update ([14cce02](https://github.com/aiinbx/aiinbx-py/commit/14cce02323e853540ed6fe02f3db03ee8a61664d))

## 0.192.0 (2025-12-03)

Full Changelog: [v0.191.0...v0.192.0](https://github.com/aiinbx/aiinbx-py/compare/v0.191.0...v0.192.0)

### Features

* **api:** api update ([c46d62b](https://github.com/aiinbx/aiinbx-py/commit/c46d62b416076de8c0c88310b9d0fbf93895ad49))

## 0.191.0 (2025-12-02)

Full Changelog: [v0.190.0...v0.191.0](https://github.com/aiinbx/aiinbx-py/compare/v0.190.0...v0.191.0)

### Features

* **api:** api update ([8a4ae59](https://github.com/aiinbx/aiinbx-py/commit/8a4ae59d1fe9b792f7222dd3dc597f56c03eff05))

## 0.190.0 (2025-12-02)

Full Changelog: [v0.189.0...v0.190.0](https://github.com/aiinbx/aiinbx-py/compare/v0.189.0...v0.190.0)

### Features

* **api:** api update ([3015fdd](https://github.com/aiinbx/aiinbx-py/commit/3015fdd697ba4dbac3a29f0ae2a3f2b7e22be71f))

## 0.189.0 (2025-12-02)

Full Changelog: [v0.188.0...v0.189.0](https://github.com/aiinbx/aiinbx-py/compare/v0.188.0...v0.189.0)

### Features

* **api:** api update ([27f06f9](https://github.com/aiinbx/aiinbx-py/commit/27f06f9b80e7cacc942de7d8bd2ceccad15e7ce3))

## 0.188.0 (2025-12-02)

Full Changelog: [v0.187.0...v0.188.0](https://github.com/aiinbx/aiinbx-py/compare/v0.187.0...v0.188.0)

### Features

* **api:** api update ([996e7e2](https://github.com/aiinbx/aiinbx-py/commit/996e7e285fa3e0804e552863171edb9bc7f03451))

## 0.187.0 (2025-12-02)

Full Changelog: [v0.186.0...v0.187.0](https://github.com/aiinbx/aiinbx-py/compare/v0.186.0...v0.187.0)

### Features

* **api:** api update ([ac05446](https://github.com/aiinbx/aiinbx-py/commit/ac054460619096dbddeee9012e836586d80ecbd2))

## 0.186.0 (2025-12-02)

Full Changelog: [v0.185.0...v0.186.0](https://github.com/aiinbx/aiinbx-py/compare/v0.185.0...v0.186.0)

### Features

* **api:** api update ([ac618eb](https://github.com/aiinbx/aiinbx-py/commit/ac618eb1bcbf2fef0a8fa1a6f9a498e63c49576e))

## 0.185.0 (2025-12-02)

Full Changelog: [v0.184.0...v0.185.0](https://github.com/aiinbx/aiinbx-py/compare/v0.184.0...v0.185.0)

### Features

* **api:** api update ([bb68e95](https://github.com/aiinbx/aiinbx-py/commit/bb68e959afbad71b5f69fd2da57081251e800a01))

## 0.184.0 (2025-12-02)

Full Changelog: [v0.183.0...v0.184.0](https://github.com/aiinbx/aiinbx-py/compare/v0.183.0...v0.184.0)

### Features

* **api:** api update ([f88ab54](https://github.com/aiinbx/aiinbx-py/commit/f88ab54edcb48c1d71f23a74ff53a9985610a214))

## 0.183.0 (2025-12-02)

Full Changelog: [v0.182.0...v0.183.0](https://github.com/aiinbx/aiinbx-py/compare/v0.182.0...v0.183.0)

### Features

* **api:** api update ([4f24787](https://github.com/aiinbx/aiinbx-py/commit/4f24787762fb36ebacb97749246d0706ded1c5e1))

## 0.182.0 (2025-12-02)

Full Changelog: [v0.181.0...v0.182.0](https://github.com/aiinbx/aiinbx-py/compare/v0.181.0...v0.182.0)

### Features

* **api:** api update ([cb81668](https://github.com/aiinbx/aiinbx-py/commit/cb81668c48415f3f399caaf5488e2e3010f104ff))

## 0.181.0 (2025-12-02)

Full Changelog: [v0.180.0...v0.181.0](https://github.com/aiinbx/aiinbx-py/compare/v0.180.0...v0.181.0)

### Features

* **api:** api update ([0c210e7](https://github.com/aiinbx/aiinbx-py/commit/0c210e7c3b43832eb83162dbeb8379b8f89af019))

## 0.180.0 (2025-12-02)

Full Changelog: [v0.179.0...v0.180.0](https://github.com/aiinbx/aiinbx-py/compare/v0.179.0...v0.180.0)

### Features

* **api:** api update ([9e7f581](https://github.com/aiinbx/aiinbx-py/commit/9e7f581fd634200d6e6ed103226d40b0ed21fcfa))

## 0.179.0 (2025-12-02)

Full Changelog: [v0.178.0...v0.179.0](https://github.com/aiinbx/aiinbx-py/compare/v0.178.0...v0.179.0)

### Features

* **api:** api update ([775a20c](https://github.com/aiinbx/aiinbx-py/commit/775a20c77b3c2b24b6b8fc4199eb01aba8666978))

## 0.178.0 (2025-12-02)

Full Changelog: [v0.177.0...v0.178.0](https://github.com/aiinbx/aiinbx-py/compare/v0.177.0...v0.178.0)

### Features

* **api:** api update ([d209e68](https://github.com/aiinbx/aiinbx-py/commit/d209e68e77e96c1d6896bdf1de92b99d04c39c8a))

## 0.177.0 (2025-12-02)

Full Changelog: [v0.176.0...v0.177.0](https://github.com/aiinbx/aiinbx-py/compare/v0.176.0...v0.177.0)

### Features

* **api:** api update ([dd11f70](https://github.com/aiinbx/aiinbx-py/commit/dd11f702ae169af4dbf2dd3148fdbf87fc838e0a))

## 0.176.0 (2025-12-01)

Full Changelog: [v0.175.0...v0.176.0](https://github.com/aiinbx/aiinbx-py/compare/v0.175.0...v0.176.0)

### Features

* **api:** api update ([4fbca7c](https://github.com/aiinbx/aiinbx-py/commit/4fbca7c2858411cacddb42f2e3136d0b06fe106c))

## 0.175.0 (2025-12-01)

Full Changelog: [v0.174.0...v0.175.0](https://github.com/aiinbx/aiinbx-py/compare/v0.174.0...v0.175.0)

### Features

* **api:** api update ([5e5d3c7](https://github.com/aiinbx/aiinbx-py/commit/5e5d3c77d1f71027443c2d769f50556da58b1f30))

## 0.174.0 (2025-12-01)

Full Changelog: [v0.173.0...v0.174.0](https://github.com/aiinbx/aiinbx-py/compare/v0.173.0...v0.174.0)

### Features

* **api:** api update ([822c3fe](https://github.com/aiinbx/aiinbx-py/commit/822c3fec6baff43deb0679dd1cdf166a3613283b))

## 0.173.0 (2025-12-01)

Full Changelog: [v0.172.0...v0.173.0](https://github.com/aiinbx/aiinbx-py/compare/v0.172.0...v0.173.0)

### Features

* **api:** api update ([2954771](https://github.com/aiinbx/aiinbx-py/commit/295477183b274d242089d1bb435f9bfe9caa0991))

## 0.172.0 (2025-12-01)

Full Changelog: [v0.171.0...v0.172.0](https://github.com/aiinbx/aiinbx-py/compare/v0.171.0...v0.172.0)

### Features

* **api:** api update ([17adf93](https://github.com/aiinbx/aiinbx-py/commit/17adf934ccf3ff26d4f0a4ed5596ded3638c4e1e))

## 0.171.0 (2025-12-01)

Full Changelog: [v0.170.0...v0.171.0](https://github.com/aiinbx/aiinbx-py/compare/v0.170.0...v0.171.0)

### Features

* **api:** api update ([771d927](https://github.com/aiinbx/aiinbx-py/commit/771d927cc168d9b8b3b722b38a6286de06696083))

## 0.170.0 (2025-11-30)

Full Changelog: [v0.169.0...v0.170.0](https://github.com/aiinbx/aiinbx-py/compare/v0.169.0...v0.170.0)

### Features

* **api:** api update ([a0023fb](https://github.com/aiinbx/aiinbx-py/commit/a0023fb38b0866018ffc687b010067cad3be467d))

## 0.169.0 (2025-11-30)

Full Changelog: [v0.168.0...v0.169.0](https://github.com/aiinbx/aiinbx-py/compare/v0.168.0...v0.169.0)

### Features

* **api:** api update ([4ef431d](https://github.com/aiinbx/aiinbx-py/commit/4ef431dd712703804bdca6289909b5ec74c62b90))

## 0.168.0 (2025-11-30)

Full Changelog: [v0.167.0...v0.168.0](https://github.com/aiinbx/aiinbx-py/compare/v0.167.0...v0.168.0)

### Features

* **api:** api update ([9b15b20](https://github.com/aiinbx/aiinbx-py/commit/9b15b20684ca0d5015d8ce41ad9512f255a5a012))

## 0.167.0 (2025-11-30)

Full Changelog: [v0.166.0...v0.167.0](https://github.com/aiinbx/aiinbx-py/compare/v0.166.0...v0.167.0)

### Features

* **api:** api update ([9272c9f](https://github.com/aiinbx/aiinbx-py/commit/9272c9fc2025f16270513fbe2e478826e82fa696))

## 0.166.0 (2025-11-30)

Full Changelog: [v0.165.0...v0.166.0](https://github.com/aiinbx/aiinbx-py/compare/v0.165.0...v0.166.0)

### Features

* **api:** api update ([de78e1d](https://github.com/aiinbx/aiinbx-py/commit/de78e1d79753cf3d8ea1c8e807e75e369a560cd7))

## 0.165.0 (2025-11-30)

Full Changelog: [v0.164.0...v0.165.0](https://github.com/aiinbx/aiinbx-py/compare/v0.164.0...v0.165.0)

### Features

* **api:** api update ([ce72b92](https://github.com/aiinbx/aiinbx-py/commit/ce72b9275563ee54c26e9ab9dc202552c86b29e4))

## 0.164.0 (2025-11-30)

Full Changelog: [v0.163.0...v0.164.0](https://github.com/aiinbx/aiinbx-py/compare/v0.163.0...v0.164.0)

### Features

* **api:** api update ([593f518](https://github.com/aiinbx/aiinbx-py/commit/593f5183881b2a0c1d95a057f7d3c5ac1481bdc7))

## 0.163.0 (2025-11-30)

Full Changelog: [v0.162.0...v0.163.0](https://github.com/aiinbx/aiinbx-py/compare/v0.162.0...v0.163.0)

### Features

* **api:** api update ([24e7945](https://github.com/aiinbx/aiinbx-py/commit/24e7945ab4eb60db9fd7f7ea9c69bd82cafee4b4))

## 0.162.0 (2025-11-30)

Full Changelog: [v0.161.0...v0.162.0](https://github.com/aiinbx/aiinbx-py/compare/v0.161.0...v0.162.0)

### Features

* **api:** api update ([bdca52b](https://github.com/aiinbx/aiinbx-py/commit/bdca52bcfd2d3472982a38b7332cb638c014c049))

## 0.161.0 (2025-11-30)

Full Changelog: [v0.160.0...v0.161.0](https://github.com/aiinbx/aiinbx-py/compare/v0.160.0...v0.161.0)

### Features

* **api:** api update ([d961f43](https://github.com/aiinbx/aiinbx-py/commit/d961f4379246210f8123f96273b06095b2848283))

## 0.160.0 (2025-11-29)

Full Changelog: [v0.159.0...v0.160.0](https://github.com/aiinbx/aiinbx-py/compare/v0.159.0...v0.160.0)

### Features

* **api:** api update ([eba20d4](https://github.com/aiinbx/aiinbx-py/commit/eba20d47c10440407da0714eef16666432a7c7f2))

## 0.159.0 (2025-11-29)

Full Changelog: [v0.158.0...v0.159.0](https://github.com/aiinbx/aiinbx-py/compare/v0.158.0...v0.159.0)

### Features

* **api:** api update ([b015ac6](https://github.com/aiinbx/aiinbx-py/commit/b015ac60e66c30e0786c171d922d3270fa371d32))

## 0.158.0 (2025-11-29)

Full Changelog: [v0.157.0...v0.158.0](https://github.com/aiinbx/aiinbx-py/compare/v0.157.0...v0.158.0)

### Features

* **api:** api update ([e983b6b](https://github.com/aiinbx/aiinbx-py/commit/e983b6b5cb756ef67fadd3eb99cdb4b542d5ac40))

## 0.157.0 (2025-11-29)

Full Changelog: [v0.156.0...v0.157.0](https://github.com/aiinbx/aiinbx-py/compare/v0.156.0...v0.157.0)

### Features

* **api:** api update ([741c55f](https://github.com/aiinbx/aiinbx-py/commit/741c55fc0422784bc79f28cee0e2439b64cd5fb7))

## 0.156.0 (2025-11-29)

Full Changelog: [v0.155.0...v0.156.0](https://github.com/aiinbx/aiinbx-py/compare/v0.155.0...v0.156.0)

### Features

* **api:** api update ([987f8f7](https://github.com/aiinbx/aiinbx-py/commit/987f8f730b62f388318ed6fd549b648881774f88))

## 0.155.0 (2025-11-29)

Full Changelog: [v0.154.0...v0.155.0](https://github.com/aiinbx/aiinbx-py/compare/v0.154.0...v0.155.0)

### Features

* **api:** api update ([f78e77e](https://github.com/aiinbx/aiinbx-py/commit/f78e77e7ad3e623ee1a6f9fe6c543af2444668c0))

## 0.154.0 (2025-11-29)

Full Changelog: [v0.153.0...v0.154.0](https://github.com/aiinbx/aiinbx-py/compare/v0.153.0...v0.154.0)

### Features

* **api:** api update ([af86094](https://github.com/aiinbx/aiinbx-py/commit/af86094a7f0aa71b821785afd3caa0acd449f117))

## 0.153.0 (2025-11-29)

Full Changelog: [v0.152.0...v0.153.0](https://github.com/aiinbx/aiinbx-py/compare/v0.152.0...v0.153.0)

### Features

* **api:** api update ([4d1a33e](https://github.com/aiinbx/aiinbx-py/commit/4d1a33e45c652e115f5a5777bcfaeff3c0e6d658))

## 0.152.0 (2025-11-29)

Full Changelog: [v0.151.0...v0.152.0](https://github.com/aiinbx/aiinbx-py/compare/v0.151.0...v0.152.0)

### Features

* **api:** api update ([9577916](https://github.com/aiinbx/aiinbx-py/commit/9577916446e5db94dcc06955dd546ea975c49c15))

## 0.151.0 (2025-11-29)

Full Changelog: [v0.150.0...v0.151.0](https://github.com/aiinbx/aiinbx-py/compare/v0.150.0...v0.151.0)

### Features

* **api:** api update ([31663d5](https://github.com/aiinbx/aiinbx-py/commit/31663d51c45bf0c2f0300701533bfa83419ebacc))

## 0.150.0 (2025-11-29)

Full Changelog: [v0.149.0...v0.150.0](https://github.com/aiinbx/aiinbx-py/compare/v0.149.0...v0.150.0)

### Features

* **api:** api update ([d9b96eb](https://github.com/aiinbx/aiinbx-py/commit/d9b96eb6f810b6cba33d9907609ee21a235cdd35))

## 0.149.0 (2025-11-29)

Full Changelog: [v0.148.0...v0.149.0](https://github.com/aiinbx/aiinbx-py/compare/v0.148.0...v0.149.0)

### Features

* **api:** api update ([e1aeba9](https://github.com/aiinbx/aiinbx-py/commit/e1aeba98401119b0c35573ee31ad62152b607014))

## 0.148.0 (2025-11-29)

Full Changelog: [v0.147.0...v0.148.0](https://github.com/aiinbx/aiinbx-py/compare/v0.147.0...v0.148.0)

### Features

* **api:** api update ([691bbe8](https://github.com/aiinbx/aiinbx-py/commit/691bbe8226298e4014743aa3a03527cc83e703ff))

## 0.147.0 (2025-11-28)

Full Changelog: [v0.146.0...v0.147.0](https://github.com/aiinbx/aiinbx-py/compare/v0.146.0...v0.147.0)

### Features

* **api:** api update ([e90335e](https://github.com/aiinbx/aiinbx-py/commit/e90335e3cb5f6c6c689e94928dae43c5f0051f07))

## 0.146.0 (2025-11-28)

Full Changelog: [v0.145.0...v0.146.0](https://github.com/aiinbx/aiinbx-py/compare/v0.145.0...v0.146.0)

### Features

* **api:** api update ([3246438](https://github.com/aiinbx/aiinbx-py/commit/32464383a3768fee80a5ff22e8cf13e27c5091dd))

## 0.145.0 (2025-11-28)

Full Changelog: [v0.144.0...v0.145.0](https://github.com/aiinbx/aiinbx-py/compare/v0.144.0...v0.145.0)

### Features

* **api:** api update ([f284a7c](https://github.com/aiinbx/aiinbx-py/commit/f284a7c00575675dbb16913347ef605bbd683215))

## 0.144.0 (2025-11-28)

Full Changelog: [v0.143.0...v0.144.0](https://github.com/aiinbx/aiinbx-py/compare/v0.143.0...v0.144.0)

### Features

* **api:** api update ([5392797](https://github.com/aiinbx/aiinbx-py/commit/5392797686d44853d7106f1dae0294618860d3b2))

## 0.143.0 (2025-11-28)

Full Changelog: [v0.142.0...v0.143.0](https://github.com/aiinbx/aiinbx-py/compare/v0.142.0...v0.143.0)

### Features

* **api:** api update ([61f5e23](https://github.com/aiinbx/aiinbx-py/commit/61f5e23fb3e452eb60402445053a8b864dde6901))

## 0.142.0 (2025-11-28)

Full Changelog: [v0.141.0...v0.142.0](https://github.com/aiinbx/aiinbx-py/compare/v0.141.0...v0.142.0)

### Features

* **api:** api update ([ea05169](https://github.com/aiinbx/aiinbx-py/commit/ea051697f3c56692e408f7606bea5f31aa74e5d2))

## 0.141.0 (2025-11-28)

Full Changelog: [v0.140.0...v0.141.0](https://github.com/aiinbx/aiinbx-py/compare/v0.140.0...v0.141.0)

### Features

* **api:** api update ([aea101b](https://github.com/aiinbx/aiinbx-py/commit/aea101b4bf0bc48d53a44097fa4c2fe6b9298f5d))

## 0.140.0 (2025-11-28)

Full Changelog: [v0.139.0...v0.140.0](https://github.com/aiinbx/aiinbx-py/compare/v0.139.0...v0.140.0)

### Features

* **api:** api update ([5f14303](https://github.com/aiinbx/aiinbx-py/commit/5f14303298f63b6a8878e919501da29b8d63d7ce))

## 0.139.0 (2025-11-28)

Full Changelog: [v0.138.0...v0.139.0](https://github.com/aiinbx/aiinbx-py/compare/v0.138.0...v0.139.0)

### Features

* **api:** api update ([e56d509](https://github.com/aiinbx/aiinbx-py/commit/e56d509082595e1af5a474c5dc631d0798789257))

## 0.138.0 (2025-11-28)

Full Changelog: [v0.137.0...v0.138.0](https://github.com/aiinbx/aiinbx-py/compare/v0.137.0...v0.138.0)

### Features

* **api:** api update ([09c3046](https://github.com/aiinbx/aiinbx-py/commit/09c304687aff9b0c077e2fc6d4adf82fb372f15c))

## 0.137.0 (2025-11-28)

Full Changelog: [v0.136.1...v0.137.0](https://github.com/aiinbx/aiinbx-py/compare/v0.136.1...v0.137.0)

### Features

* **api:** api update ([9e3f137](https://github.com/aiinbx/aiinbx-py/commit/9e3f1371f8e85a0cc852ecf1f4fab5b90dc4fb86))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([58a443e](https://github.com/aiinbx/aiinbx-py/commit/58a443ebe51ac4353efdd467ca54711874274f90))

## 0.136.1 (2025-11-28)

Full Changelog: [v0.136.0...v0.136.1](https://github.com/aiinbx/aiinbx-py/compare/v0.136.0...v0.136.1)

### Bug Fixes

* ensure streams are always closed ([88c6253](https://github.com/aiinbx/aiinbx-py/commit/88c62534172f141a2e010f7f839d7f41c5d76421))

## 0.136.0 (2025-11-28)

Full Changelog: [v0.135.0...v0.136.0](https://github.com/aiinbx/aiinbx-py/compare/v0.135.0...v0.136.0)

### Features

* **api:** api update ([cc6c0e5](https://github.com/aiinbx/aiinbx-py/commit/cc6c0e5bf7fb1948cc25d5b005ad7ace696a3d6a))

## 0.135.0 (2025-11-28)

Full Changelog: [v0.134.0...v0.135.0](https://github.com/aiinbx/aiinbx-py/compare/v0.134.0...v0.135.0)

### Features

* **api:** api update ([c1c9d42](https://github.com/aiinbx/aiinbx-py/commit/c1c9d42e0a6cdc01f07887ad4421cda7b27d5b68))

## 0.134.0 (2025-11-28)

Full Changelog: [v0.133.0...v0.134.0](https://github.com/aiinbx/aiinbx-py/compare/v0.133.0...v0.134.0)

### Features

* **api:** api update ([cdcc0a1](https://github.com/aiinbx/aiinbx-py/commit/cdcc0a1d1fe270f881718204e53ca2bdbc46d2af))

## 0.133.0 (2025-11-27)

Full Changelog: [v0.132.0...v0.133.0](https://github.com/aiinbx/aiinbx-py/compare/v0.132.0...v0.133.0)

### Features

* **api:** api update ([8757ad9](https://github.com/aiinbx/aiinbx-py/commit/8757ad9c38aa02b44eb8f2e621d46284db003d41))

## 0.132.0 (2025-11-27)

Full Changelog: [v0.131.0...v0.132.0](https://github.com/aiinbx/aiinbx-py/compare/v0.131.0...v0.132.0)

### Features

* **api:** api update ([846674f](https://github.com/aiinbx/aiinbx-py/commit/846674f1b868319d45604f64646c4cf33e7167c0))

## 0.131.0 (2025-11-27)

Full Changelog: [v0.130.0...v0.131.0](https://github.com/aiinbx/aiinbx-py/compare/v0.130.0...v0.131.0)

### Features

* **api:** api update ([321051f](https://github.com/aiinbx/aiinbx-py/commit/321051f80554aef2b8b1eafc1e02ea3b816fba65))

## 0.130.0 (2025-11-27)

Full Changelog: [v0.129.0...v0.130.0](https://github.com/aiinbx/aiinbx-py/compare/v0.129.0...v0.130.0)

### Features

* **api:** api update ([43181c8](https://github.com/aiinbx/aiinbx-py/commit/43181c833258ac26b24e10408daa683d8e04b890))

## 0.129.0 (2025-11-27)

Full Changelog: [v0.128.0...v0.129.0](https://github.com/aiinbx/aiinbx-py/compare/v0.128.0...v0.129.0)

### Features

* **api:** api update ([8f6ecda](https://github.com/aiinbx/aiinbx-py/commit/8f6ecda13bf2429a19d2a55e54e69b5bea0900d1))

## 0.128.0 (2025-11-27)

Full Changelog: [v0.127.0...v0.128.0](https://github.com/aiinbx/aiinbx-py/compare/v0.127.0...v0.128.0)

### Features

* **api:** api update ([a20b075](https://github.com/aiinbx/aiinbx-py/commit/a20b07507df2445d16ddfc51444e74b21f8d7de6))

## 0.127.0 (2025-11-27)

Full Changelog: [v0.126.0...v0.127.0](https://github.com/aiinbx/aiinbx-py/compare/v0.126.0...v0.127.0)

### Features

* **api:** api update ([0b84926](https://github.com/aiinbx/aiinbx-py/commit/0b84926b5cf96395625bdc63000f46b9e8a8350e))

## 0.126.0 (2025-11-27)

Full Changelog: [v0.125.0...v0.126.0](https://github.com/aiinbx/aiinbx-py/compare/v0.125.0...v0.126.0)

### Features

* **api:** api update ([81a5def](https://github.com/aiinbx/aiinbx-py/commit/81a5def407f2c6754f03f7bf0ec0a5f63b10beb9))

## 0.125.0 (2025-11-27)

Full Changelog: [v0.124.0...v0.125.0](https://github.com/aiinbx/aiinbx-py/compare/v0.124.0...v0.125.0)

### Features

* **api:** api update ([193fff3](https://github.com/aiinbx/aiinbx-py/commit/193fff355124c4506dc2b183406b20da726eabbd))

## 0.124.0 (2025-11-27)

Full Changelog: [v0.123.0...v0.124.0](https://github.com/aiinbx/aiinbx-py/compare/v0.123.0...v0.124.0)

### Features

* **api:** api update ([e7736f1](https://github.com/aiinbx/aiinbx-py/commit/e7736f160122248339a3d5dd8ff391923bbb5a19))

## 0.123.0 (2025-11-27)

Full Changelog: [v0.122.0...v0.123.0](https://github.com/aiinbx/aiinbx-py/compare/v0.122.0...v0.123.0)

### Features

* **api:** api update ([1fccae6](https://github.com/aiinbx/aiinbx-py/commit/1fccae6162f505a74e0a3e5c02418a8ef95cd236))

## 0.122.0 (2025-11-26)

Full Changelog: [v0.121.0...v0.122.0](https://github.com/aiinbx/aiinbx-py/compare/v0.121.0...v0.122.0)

### Features

* **api:** api update ([30d6f68](https://github.com/aiinbx/aiinbx-py/commit/30d6f68cb3eb6b28ee4c3e5e0f0e34e6835c2259))

## 0.121.0 (2025-11-26)

Full Changelog: [v0.120.0...v0.121.0](https://github.com/aiinbx/aiinbx-py/compare/v0.120.0...v0.121.0)

### Features

* **api:** api update ([e004638](https://github.com/aiinbx/aiinbx-py/commit/e004638a8e6a91fe7c65bcd2259533902cceb515))

## 0.120.0 (2025-11-26)

Full Changelog: [v0.119.0...v0.120.0](https://github.com/aiinbx/aiinbx-py/compare/v0.119.0...v0.120.0)

### Features

* **api:** api update ([3d1c487](https://github.com/aiinbx/aiinbx-py/commit/3d1c4875fb7ec53eedf38c4d1815a4f49567a641))

## 0.119.0 (2025-11-26)

Full Changelog: [v0.118.0...v0.119.0](https://github.com/aiinbx/aiinbx-py/compare/v0.118.0...v0.119.0)

### Features

* **api:** api update ([5be4d48](https://github.com/aiinbx/aiinbx-py/commit/5be4d48d60bddd84137cbbad403e679eef6eade1))

## 0.118.0 (2025-11-26)

Full Changelog: [v0.117.0...v0.118.0](https://github.com/aiinbx/aiinbx-py/compare/v0.117.0...v0.118.0)

### Features

* **api:** api update ([6d769dd](https://github.com/aiinbx/aiinbx-py/commit/6d769dd6056b216be9a4e405f1c38fbb7fc3bd98))

## 0.117.0 (2025-11-26)

Full Changelog: [v0.116.0...v0.117.0](https://github.com/aiinbx/aiinbx-py/compare/v0.116.0...v0.117.0)

### Features

* **api:** api update ([4f55a97](https://github.com/aiinbx/aiinbx-py/commit/4f55a97efc6a614715039c6adbd64e6a5ef42aa8))

## 0.116.0 (2025-11-26)

Full Changelog: [v0.115.0...v0.116.0](https://github.com/aiinbx/aiinbx-py/compare/v0.115.0...v0.116.0)

### Features

* **api:** api update ([d810f79](https://github.com/aiinbx/aiinbx-py/commit/d810f79a9c7039c1976c9ef80e160626970f3078))

## 0.115.0 (2025-11-26)

Full Changelog: [v0.114.0...v0.115.0](https://github.com/aiinbx/aiinbx-py/compare/v0.114.0...v0.115.0)

### Features

* **api:** api update ([b0b5411](https://github.com/aiinbx/aiinbx-py/commit/b0b541149a6e29cd98395f9654fe5a57593ab09a))

## 0.114.0 (2025-11-26)

Full Changelog: [v0.113.0...v0.114.0](https://github.com/aiinbx/aiinbx-py/compare/v0.113.0...v0.114.0)

### Features

* **api:** api update ([bcc7e3c](https://github.com/aiinbx/aiinbx-py/commit/bcc7e3ca3d442fad1c0354983356ceb2ef83d05a))

## 0.113.0 (2025-11-26)

Full Changelog: [v0.112.0...v0.113.0](https://github.com/aiinbx/aiinbx-py/compare/v0.112.0...v0.113.0)

### Features

* **api:** api update ([f1cfc4c](https://github.com/aiinbx/aiinbx-py/commit/f1cfc4c131a165581b58bccf346353d0ee7aa73f))

## 0.112.0 (2025-11-26)

Full Changelog: [v0.111.0...v0.112.0](https://github.com/aiinbx/aiinbx-py/compare/v0.111.0...v0.112.0)

### Features

* **api:** api update ([0217e4f](https://github.com/aiinbx/aiinbx-py/commit/0217e4f6a37ff0f72b24f647e46e2126ca079e6b))

## 0.111.0 (2025-11-26)

Full Changelog: [v0.110.0...v0.111.0](https://github.com/aiinbx/aiinbx-py/compare/v0.110.0...v0.111.0)

### Features

* **api:** api update ([47d695c](https://github.com/aiinbx/aiinbx-py/commit/47d695c2780c119f0a3e754461d09edc9218c488))

## 0.110.0 (2025-11-25)

Full Changelog: [v0.109.0...v0.110.0](https://github.com/aiinbx/aiinbx-py/compare/v0.109.0...v0.110.0)

### Features

* **api:** api update ([904d6fc](https://github.com/aiinbx/aiinbx-py/commit/904d6fca59a6de80f9db2832ac1e92e326fc32c9))

## 0.109.0 (2025-11-25)

Full Changelog: [v0.108.0...v0.109.0](https://github.com/aiinbx/aiinbx-py/compare/v0.108.0...v0.109.0)

### Features

* **api:** api update ([9dfa658](https://github.com/aiinbx/aiinbx-py/commit/9dfa658c022e27a0862f3bce8d4e3b524d2497d9))

## 0.108.0 (2025-11-25)

Full Changelog: [v0.107.0...v0.108.0](https://github.com/aiinbx/aiinbx-py/compare/v0.107.0...v0.108.0)

### Features

* **api:** api update ([d3fd7c9](https://github.com/aiinbx/aiinbx-py/commit/d3fd7c9d952f18802eae02b6766181e5e5e42fe2))

## 0.107.0 (2025-11-25)

Full Changelog: [v0.106.0...v0.107.0](https://github.com/aiinbx/aiinbx-py/compare/v0.106.0...v0.107.0)

### Features

* **api:** api update ([9c59858](https://github.com/aiinbx/aiinbx-py/commit/9c59858f8e0d43584637920f9c6fd8e84b71199a))

## 0.106.0 (2025-11-25)

Full Changelog: [v0.105.0...v0.106.0](https://github.com/aiinbx/aiinbx-py/compare/v0.105.0...v0.106.0)

### Features

* **api:** api update ([8e56bc0](https://github.com/aiinbx/aiinbx-py/commit/8e56bc0e74dd0bb896c2ce09e65fc688511a39f2))

## 0.105.0 (2025-11-25)

Full Changelog: [v0.104.0...v0.105.0](https://github.com/aiinbx/aiinbx-py/compare/v0.104.0...v0.105.0)

### Features

* **api:** api update ([bd1404c](https://github.com/aiinbx/aiinbx-py/commit/bd1404c07eff87288b3f656c1b2dbd22b7a0b8df))

## 0.104.0 (2025-11-25)

Full Changelog: [v0.103.0...v0.104.0](https://github.com/aiinbx/aiinbx-py/compare/v0.103.0...v0.104.0)

### Features

* **api:** api update ([32c9c5c](https://github.com/aiinbx/aiinbx-py/commit/32c9c5cef6d392062ac1ecc0f048cce94397895f))

## 0.103.0 (2025-11-25)

Full Changelog: [v0.102.0...v0.103.0](https://github.com/aiinbx/aiinbx-py/compare/v0.102.0...v0.103.0)

### Features

* **api:** api update ([75297ac](https://github.com/aiinbx/aiinbx-py/commit/75297ace0f7ac44bec8e177b77692f4a40baf589))

## 0.102.0 (2025-11-25)

Full Changelog: [v0.101.0...v0.102.0](https://github.com/aiinbx/aiinbx-py/compare/v0.101.0...v0.102.0)

### Features

* **api:** api update ([628467e](https://github.com/aiinbx/aiinbx-py/commit/628467e4ff7ec410357dec20a7b82082d5c1804c))

## 0.101.0 (2025-11-25)

Full Changelog: [v0.100.0...v0.101.0](https://github.com/aiinbx/aiinbx-py/compare/v0.100.0...v0.101.0)

### Features

* **api:** api update ([a446d3e](https://github.com/aiinbx/aiinbx-py/commit/a446d3ea2acab4df5748e8bd67971d4d7b42045c))

## 0.100.0 (2025-11-25)

Full Changelog: [v0.99.0...v0.100.0](https://github.com/aiinbx/aiinbx-py/compare/v0.99.0...v0.100.0)

### Features

* **api:** api update ([c6bf192](https://github.com/aiinbx/aiinbx-py/commit/c6bf19267425b36e5b03333be4183ae93b626d34))

## 0.99.0 (2025-11-25)

Full Changelog: [v0.98.0...v0.99.0](https://github.com/aiinbx/aiinbx-py/compare/v0.98.0...v0.99.0)

### Features

* **api:** api update ([8e1a0d7](https://github.com/aiinbx/aiinbx-py/commit/8e1a0d7e991761b039049d7c115f5ac9e0e574dc))

## 0.98.0 (2025-11-25)

Full Changelog: [v0.97.0...v0.98.0](https://github.com/aiinbx/aiinbx-py/compare/v0.97.0...v0.98.0)

### Features

* **api:** api update ([bead2f2](https://github.com/aiinbx/aiinbx-py/commit/bead2f2f878227f6df01064c48d4e9f6881c8cb2))

## 0.97.0 (2025-11-24)

Full Changelog: [v0.96.0...v0.97.0](https://github.com/aiinbx/aiinbx-py/compare/v0.96.0...v0.97.0)

### Features

* **api:** api update ([57d31b8](https://github.com/aiinbx/aiinbx-py/commit/57d31b82d58e5664b867376a055be7e8f81c94c3))

## 0.96.0 (2025-11-24)

Full Changelog: [v0.95.0...v0.96.0](https://github.com/aiinbx/aiinbx-py/compare/v0.95.0...v0.96.0)

### Features

* **api:** api update ([e127d5f](https://github.com/aiinbx/aiinbx-py/commit/e127d5f9b1f2cd89e539540dc3f3a37bc5ea6fe5))

## 0.95.0 (2025-11-24)

Full Changelog: [v0.94.0...v0.95.0](https://github.com/aiinbx/aiinbx-py/compare/v0.94.0...v0.95.0)

### Features

* **api:** api update ([9a2361e](https://github.com/aiinbx/aiinbx-py/commit/9a2361ed0342c66ff96a3d3f43b0dae54e51ad61))

## 0.94.0 (2025-11-24)

Full Changelog: [v0.93.0...v0.94.0](https://github.com/aiinbx/aiinbx-py/compare/v0.93.0...v0.94.0)

### Features

* **api:** api update ([65d321c](https://github.com/aiinbx/aiinbx-py/commit/65d321ca0e96d03c657b459cd93c2198b0752a81))

## 0.93.0 (2025-11-24)

Full Changelog: [v0.92.0...v0.93.0](https://github.com/aiinbx/aiinbx-py/compare/v0.92.0...v0.93.0)

### Features

* **api:** api update ([285dc04](https://github.com/aiinbx/aiinbx-py/commit/285dc0421ae30c79ddfa4f79b66b58e23a3c3f53))

## 0.92.0 (2025-11-24)

Full Changelog: [v0.91.0...v0.92.0](https://github.com/aiinbx/aiinbx-py/compare/v0.91.0...v0.92.0)

### Features

* **api:** api update ([8a01ec4](https://github.com/aiinbx/aiinbx-py/commit/8a01ec46537fa5d1b22eece2f933df8651b060a6))

## 0.91.0 (2025-11-24)

Full Changelog: [v0.90.0...v0.91.0](https://github.com/aiinbx/aiinbx-py/compare/v0.90.0...v0.91.0)

### Features

* **api:** api update ([4e16918](https://github.com/aiinbx/aiinbx-py/commit/4e1691835040f44cd0a9aec32038c5a5f983648a))

## 0.90.0 (2025-11-24)

Full Changelog: [v0.89.0...v0.90.0](https://github.com/aiinbx/aiinbx-py/compare/v0.89.0...v0.90.0)

### Features

* **api:** api update ([9d6c65c](https://github.com/aiinbx/aiinbx-py/commit/9d6c65c5e0c0d28ecd2207dd3588b9f87905cef4))

## 0.89.0 (2025-11-23)

Full Changelog: [v0.88.0...v0.89.0](https://github.com/aiinbx/aiinbx-py/compare/v0.88.0...v0.89.0)

### Features

* **api:** api update ([0f2a29c](https://github.com/aiinbx/aiinbx-py/commit/0f2a29c468ef2523c24c6248919e0b064f1481cf))

## 0.88.0 (2025-11-23)

Full Changelog: [v0.87.0...v0.88.0](https://github.com/aiinbx/aiinbx-py/compare/v0.87.0...v0.88.0)

### Features

* **api:** api update ([7563af9](https://github.com/aiinbx/aiinbx-py/commit/7563af9cc1ca5f3a20cb1c8d6a4cc8930c4fcc58))

## 0.87.0 (2025-11-23)

Full Changelog: [v0.86.0...v0.87.0](https://github.com/aiinbx/aiinbx-py/compare/v0.86.0...v0.87.0)

### Features

* **api:** api update ([db583db](https://github.com/aiinbx/aiinbx-py/commit/db583db372d4c4089dfd2e4c8987edb5f2c15626))

## 0.86.0 (2025-11-23)

Full Changelog: [v0.85.0...v0.86.0](https://github.com/aiinbx/aiinbx-py/compare/v0.85.0...v0.86.0)

### Features

* **api:** api update ([78971fb](https://github.com/aiinbx/aiinbx-py/commit/78971fbff92489b6ff981a84d44ac1a89341242c))

## 0.85.0 (2025-11-23)

Full Changelog: [v0.84.0...v0.85.0](https://github.com/aiinbx/aiinbx-py/compare/v0.84.0...v0.85.0)

### Features

* **api:** api update ([c449694](https://github.com/aiinbx/aiinbx-py/commit/c449694fba8d6b3ee2363cd162bb84b2323ddbb1))

## 0.84.0 (2025-11-23)

Full Changelog: [v0.83.0...v0.84.0](https://github.com/aiinbx/aiinbx-py/compare/v0.83.0...v0.84.0)

### Features

* **api:** api update ([5e04bd8](https://github.com/aiinbx/aiinbx-py/commit/5e04bd8ef846531ea62b1a04b429a1cba86fc52d))

## 0.83.0 (2025-11-23)

Full Changelog: [v0.82.0...v0.83.0](https://github.com/aiinbx/aiinbx-py/compare/v0.82.0...v0.83.0)

### Features

* **api:** api update ([17120cb](https://github.com/aiinbx/aiinbx-py/commit/17120cb060710e880444ab8659c02848fe763f13))

## 0.82.0 (2025-11-23)

Full Changelog: [v0.81.0...v0.82.0](https://github.com/aiinbx/aiinbx-py/compare/v0.81.0...v0.82.0)

### Features

* **api:** api update ([28bc66e](https://github.com/aiinbx/aiinbx-py/commit/28bc66ef7f313e366ac2ceb05077ea567959dcdc))

## 0.81.0 (2025-11-23)

Full Changelog: [v0.80.0...v0.81.0](https://github.com/aiinbx/aiinbx-py/compare/v0.80.0...v0.81.0)

### Features

* **api:** api update ([3dda4a1](https://github.com/aiinbx/aiinbx-py/commit/3dda4a15491e7bafb3b5cc0ad475366d83a8adf7))

## 0.80.0 (2025-11-23)

Full Changelog: [v0.79.0...v0.80.0](https://github.com/aiinbx/aiinbx-py/compare/v0.79.0...v0.80.0)

### Features

* **api:** api update ([c16d233](https://github.com/aiinbx/aiinbx-py/commit/c16d233f10968aab444317f2b4f3d28bd24e53f0))

## 0.79.0 (2025-11-23)

Full Changelog: [v0.78.0...v0.79.0](https://github.com/aiinbx/aiinbx-py/compare/v0.78.0...v0.79.0)

### Features

* **api:** api update ([0a449d4](https://github.com/aiinbx/aiinbx-py/commit/0a449d403cdd5f8cf0d5af24c3464c6e14173d83))

## 0.78.0 (2025-11-23)

Full Changelog: [v0.77.0...v0.78.0](https://github.com/aiinbx/aiinbx-py/compare/v0.77.0...v0.78.0)

### Features

* **api:** api update ([1cb7886](https://github.com/aiinbx/aiinbx-py/commit/1cb7886e1ae830fc5e74a9977986e48fd0a6826f))

## 0.77.0 (2025-11-22)

Full Changelog: [v0.76.0...v0.77.0](https://github.com/aiinbx/aiinbx-py/compare/v0.76.0...v0.77.0)

### Features

* **api:** api update ([153ff5b](https://github.com/aiinbx/aiinbx-py/commit/153ff5b0c609a057a645f7613bfd5eec51f5e52c))

## 0.76.0 (2025-11-22)

Full Changelog: [v0.75.0...v0.76.0](https://github.com/aiinbx/aiinbx-py/compare/v0.75.0...v0.76.0)

### Features

* **api:** api update ([dd15724](https://github.com/aiinbx/aiinbx-py/commit/dd157242db4cc30e4df666fa7ef6e13de4db487c))

## 0.75.0 (2025-11-22)

Full Changelog: [v0.74.0...v0.75.0](https://github.com/aiinbx/aiinbx-py/compare/v0.74.0...v0.75.0)

### Features

* **api:** api update ([35da423](https://github.com/aiinbx/aiinbx-py/commit/35da42365bc4a5147a02a0b5f795b1c0f571b8c2))

## 0.74.0 (2025-11-22)

Full Changelog: [v0.73.0...v0.74.0](https://github.com/aiinbx/aiinbx-py/compare/v0.73.0...v0.74.0)

### Features

* **api:** api update ([5ce8eb7](https://github.com/aiinbx/aiinbx-py/commit/5ce8eb7899f6a5ef5f0c76aecda92791ab0d2ef3))

## 0.73.0 (2025-11-22)

Full Changelog: [v0.72.0...v0.73.0](https://github.com/aiinbx/aiinbx-py/compare/v0.72.0...v0.73.0)

### Features

* **api:** api update ([ba74e8a](https://github.com/aiinbx/aiinbx-py/commit/ba74e8ab2f44ecd7768594fc84ed3ef177295a08))

## 0.72.0 (2025-11-22)

Full Changelog: [v0.71.0...v0.72.0](https://github.com/aiinbx/aiinbx-py/compare/v0.71.0...v0.72.0)

### Features

* **api:** api update ([547645b](https://github.com/aiinbx/aiinbx-py/commit/547645b7531125c5b87aabe65391322465b5803e))

## 0.71.0 (2025-11-22)

Full Changelog: [v0.70.0...v0.71.0](https://github.com/aiinbx/aiinbx-py/compare/v0.70.0...v0.71.0)

### Features

* **api:** api update ([54ef3ae](https://github.com/aiinbx/aiinbx-py/commit/54ef3aed189ee1de665a24d84d92c2ccac57ae1c))

## 0.70.0 (2025-11-22)

Full Changelog: [v0.69.0...v0.70.0](https://github.com/aiinbx/aiinbx-py/compare/v0.69.0...v0.70.0)

### Features

* **api:** api update ([134491c](https://github.com/aiinbx/aiinbx-py/commit/134491c6a3f54a30f05fb2f6faa8abcc6ea011e9))

## 0.69.0 (2025-11-22)

Full Changelog: [v0.68.0...v0.69.0](https://github.com/aiinbx/aiinbx-py/compare/v0.68.0...v0.69.0)

### Features

* **api:** api update ([d9f30ae](https://github.com/aiinbx/aiinbx-py/commit/d9f30ae5fbe5ae57b006a71fda94996e72a1328e))

## 0.68.0 (2025-11-22)

Full Changelog: [v0.67.0...v0.68.0](https://github.com/aiinbx/aiinbx-py/compare/v0.67.0...v0.68.0)

### Features

* **api:** api update ([9c419ee](https://github.com/aiinbx/aiinbx-py/commit/9c419ee8e26ebc5bc6c7b0c373cf00a12bea75b0))

## 0.67.0 (2025-11-22)

Full Changelog: [v0.66.0...v0.67.0](https://github.com/aiinbx/aiinbx-py/compare/v0.66.0...v0.67.0)

### Features

* **api:** api update ([d4b338f](https://github.com/aiinbx/aiinbx-py/commit/d4b338f1a4be2250647aa71aad337dc37333ef6d))


### Chores

* add Python 3.14 classifier and testing ([62f401d](https://github.com/aiinbx/aiinbx-py/commit/62f401ddcd9c4cba9fce5cf4a5343577aead36e4))

## 0.66.0 (2025-11-22)

Full Changelog: [v0.65.0...v0.66.0](https://github.com/aiinbx/aiinbx-py/compare/v0.65.0...v0.66.0)

### Features

* **api:** api update ([7f98c7a](https://github.com/aiinbx/aiinbx-py/commit/7f98c7a6b6bd7608464f9759c663d3ecc507809d))

## 0.65.0 (2025-11-22)

Full Changelog: [v0.64.0...v0.65.0](https://github.com/aiinbx/aiinbx-py/compare/v0.64.0...v0.65.0)

### Features

* **api:** api update ([c21773b](https://github.com/aiinbx/aiinbx-py/commit/c21773b7849351704a4aa11a96b40d277bfdfe4c))

## 0.64.0 (2025-11-22)

Full Changelog: [v0.63.0...v0.64.0](https://github.com/aiinbx/aiinbx-py/compare/v0.63.0...v0.64.0)

### Features

* **api:** api update ([74b1868](https://github.com/aiinbx/aiinbx-py/commit/74b1868c1899beff00b4f95fc53404346673e81d))

## 0.63.0 (2025-11-21)

Full Changelog: [v0.62.0...v0.63.0](https://github.com/aiinbx/aiinbx-py/compare/v0.62.0...v0.63.0)

### Features

* **api:** api update ([2feb128](https://github.com/aiinbx/aiinbx-py/commit/2feb1289dd7a740f9a507740409be433568bb733))

## 0.62.0 (2025-11-21)

Full Changelog: [v0.61.0...v0.62.0](https://github.com/aiinbx/aiinbx-py/compare/v0.61.0...v0.62.0)

### Features

* **api:** api update ([1fd8f6a](https://github.com/aiinbx/aiinbx-py/commit/1fd8f6a5de7faf0b290c567060147f05286cacd4))

## 0.61.0 (2025-11-21)

Full Changelog: [v0.60.0...v0.61.0](https://github.com/aiinbx/aiinbx-py/compare/v0.60.0...v0.61.0)

### Features

* **api:** api update ([63aaef3](https://github.com/aiinbx/aiinbx-py/commit/63aaef3967cb9c21ccd4f852ebe7a9e6e69c67fd))

## 0.60.0 (2025-11-21)

Full Changelog: [v0.59.0...v0.60.0](https://github.com/aiinbx/aiinbx-py/compare/v0.59.0...v0.60.0)

### Features

* **api:** api update ([1785c25](https://github.com/aiinbx/aiinbx-py/commit/1785c25ccad58c14e1145a604e1583fd46d03258))

## 0.59.0 (2025-11-21)

Full Changelog: [v0.58.0...v0.59.0](https://github.com/aiinbx/aiinbx-py/compare/v0.58.0...v0.59.0)

### Features

* **api:** api update ([0c970a7](https://github.com/aiinbx/aiinbx-py/commit/0c970a7ddea8b38c4fa39229588d7d921b789861))

## 0.58.0 (2025-11-21)

Full Changelog: [v0.57.0...v0.58.0](https://github.com/aiinbx/aiinbx-py/compare/v0.57.0...v0.58.0)

### Features

* **api:** api update ([84b8a60](https://github.com/aiinbx/aiinbx-py/commit/84b8a60042eb48cc4c8478e6fda54bc0f3755ac0))

## 0.57.0 (2025-11-21)

Full Changelog: [v0.56.0...v0.57.0](https://github.com/aiinbx/aiinbx-py/compare/v0.56.0...v0.57.0)

### Features

* **api:** api update ([134f28d](https://github.com/aiinbx/aiinbx-py/commit/134f28dd327111d70bf14402129cf6aff1ccc736))

## 0.56.0 (2025-11-21)

Full Changelog: [v0.55.0...v0.56.0](https://github.com/aiinbx/aiinbx-py/compare/v0.55.0...v0.56.0)

### Features

* **api:** api update ([6367694](https://github.com/aiinbx/aiinbx-py/commit/6367694cdbaca9a5c220c50c8a5bda7f217b23e5))

## 0.55.0 (2025-11-21)

Full Changelog: [v0.54.0...v0.55.0](https://github.com/aiinbx/aiinbx-py/compare/v0.54.0...v0.55.0)

### Features

* **api:** api update ([b822faf](https://github.com/aiinbx/aiinbx-py/commit/b822faf1d9bc625bca46b684072c5d67f64107b1))

## 0.54.0 (2025-11-20)

Full Changelog: [v0.53.0...v0.54.0](https://github.com/aiinbx/aiinbx-py/compare/v0.53.0...v0.54.0)

### Features

* **api:** api update ([6b71e1f](https://github.com/aiinbx/aiinbx-py/commit/6b71e1f9af19842069b37c12e228ba44bc3d8f91))

## 0.53.0 (2025-11-20)

Full Changelog: [v0.52.0...v0.53.0](https://github.com/aiinbx/aiinbx-py/compare/v0.52.0...v0.53.0)

### Features

* **api:** api update ([85ebce1](https://github.com/aiinbx/aiinbx-py/commit/85ebce1d9837a14238cf636ec342513c168e1d91))

## 0.52.0 (2025-11-20)

Full Changelog: [v0.51.0...v0.52.0](https://github.com/aiinbx/aiinbx-py/compare/v0.51.0...v0.52.0)

### Features

* **api:** api update ([8a32278](https://github.com/aiinbx/aiinbx-py/commit/8a32278f6f1342538080eb97a3c924809e6b5361))

## 0.51.0 (2025-11-20)

Full Changelog: [v0.50.0...v0.51.0](https://github.com/aiinbx/aiinbx-py/compare/v0.50.0...v0.51.0)

### Features

* **api:** api update ([85caac4](https://github.com/aiinbx/aiinbx-py/commit/85caac45303006acc345fdb9dfef03c6a9867a2e))

## 0.50.0 (2025-11-20)

Full Changelog: [v0.49.0...v0.50.0](https://github.com/aiinbx/aiinbx-py/compare/v0.49.0...v0.50.0)

### Features

* **api:** api update ([7dff50e](https://github.com/aiinbx/aiinbx-py/commit/7dff50e7d8e817c42d0e75098c1b025d2bf889ba))

## 0.49.0 (2025-11-20)

Full Changelog: [v0.48.0...v0.49.0](https://github.com/aiinbx/aiinbx-py/compare/v0.48.0...v0.49.0)

### Features

* **api:** api update ([44d2e9f](https://github.com/aiinbx/aiinbx-py/commit/44d2e9fb016a3df5f167247ea6f4ee7b9d5e4541))

## 0.48.0 (2025-11-20)

Full Changelog: [v0.47.0...v0.48.0](https://github.com/aiinbx/aiinbx-py/compare/v0.47.0...v0.48.0)

### Features

* **api:** api update ([ef55fcf](https://github.com/aiinbx/aiinbx-py/commit/ef55fcf68f39d32ed844fb892af3062b5d98d46e))

## 0.47.0 (2025-11-20)

Full Changelog: [v0.46.0...v0.47.0](https://github.com/aiinbx/aiinbx-py/compare/v0.46.0...v0.47.0)

### Features

* **api:** api update ([212d2c5](https://github.com/aiinbx/aiinbx-py/commit/212d2c512049dfdd4933456d203ad78055dd0ad4))

## 0.46.0 (2025-11-20)

Full Changelog: [v0.45.0...v0.46.0](https://github.com/aiinbx/aiinbx-py/compare/v0.45.0...v0.46.0)

### Features

* **api:** api update ([38faf59](https://github.com/aiinbx/aiinbx-py/commit/38faf592aa991e75c18c6a6a04e97dbcdeb820e2))
* **api:** api update ([df0d0c2](https://github.com/aiinbx/aiinbx-py/commit/df0d0c27a95bd53f6298f83c9e90faff9d35a489))

## 0.45.0 (2025-11-19)

Full Changelog: [v0.44.0...v0.45.0](https://github.com/aiinbx/aiinbx-py/compare/v0.44.0...v0.45.0)

### Features

* **api:** api update ([c03b59c](https://github.com/aiinbx/aiinbx-py/commit/c03b59cd171e8889b5e0ba7bba2d78fecda4cfb4))

## 0.44.0 (2025-11-19)

Full Changelog: [v0.43.0...v0.44.0](https://github.com/aiinbx/aiinbx-py/compare/v0.43.0...v0.44.0)

### Features

* **api:** api update ([869b2e2](https://github.com/aiinbx/aiinbx-py/commit/869b2e24f735d6c9ea92ab2bfc9fe5b313c71999))

## 0.43.0 (2025-11-19)

Full Changelog: [v0.42.0...v0.43.0](https://github.com/aiinbx/aiinbx-py/compare/v0.42.0...v0.43.0)

### Features

* **api:** api update ([f353fd7](https://github.com/aiinbx/aiinbx-py/commit/f353fd79e4be75b49a1b4224560c697fa88b7971))

## 0.42.0 (2025-11-19)

Full Changelog: [v0.41.0...v0.42.0](https://github.com/aiinbx/aiinbx-py/compare/v0.41.0...v0.42.0)

### Features

* **api:** api update ([907a6ba](https://github.com/aiinbx/aiinbx-py/commit/907a6ba050c97925d06db258cfd4d38b4ea06521))

## 0.41.0 (2025-11-19)

Full Changelog: [v0.40.0...v0.41.0](https://github.com/aiinbx/aiinbx-py/compare/v0.40.0...v0.41.0)

### Features

* **api:** api update ([17c7ce2](https://github.com/aiinbx/aiinbx-py/commit/17c7ce235fa810896d4ea978f073cab30453c79d))

## 0.40.0 (2025-11-19)

Full Changelog: [v0.39.0...v0.40.0](https://github.com/aiinbx/aiinbx-py/compare/v0.39.0...v0.40.0)

### Features

* **api:** api update ([0b0896d](https://github.com/aiinbx/aiinbx-py/commit/0b0896da1bfa6aa8ebc9bf7d70678adde421b8c9))

## 0.39.0 (2025-11-18)

Full Changelog: [v0.38.0...v0.39.0](https://github.com/aiinbx/aiinbx-py/compare/v0.38.0...v0.39.0)

### Features

* **api:** api update ([c5d2004](https://github.com/aiinbx/aiinbx-py/commit/c5d20042088ab15972aec0ef6499678cc9ac0300))

## 0.38.0 (2025-11-18)

Full Changelog: [v0.37.0...v0.38.0](https://github.com/aiinbx/aiinbx-py/compare/v0.37.0...v0.38.0)

### Features

* **api:** api update ([bcf07a5](https://github.com/aiinbx/aiinbx-py/commit/bcf07a59f71d677ad127b418eaa8833b560bd61a))
* **api:** api update ([22f5a13](https://github.com/aiinbx/aiinbx-py/commit/22f5a134583e2e7c3a3e51b3419ea1afd5c8a3a1))
* **api:** api update ([2865d84](https://github.com/aiinbx/aiinbx-py/commit/2865d84b5c5283c7755287ee5fca64ba46ee6cdf))
* **api:** api update ([8084044](https://github.com/aiinbx/aiinbx-py/commit/80840444792bd38df7e8c5b23697ca30eb9cab32))
* **api:** api update ([6217cf4](https://github.com/aiinbx/aiinbx-py/commit/6217cf46a2cfade17ef9e71eb1a62976ebd931c9))
* **api:** api update ([4a8d8c4](https://github.com/aiinbx/aiinbx-py/commit/4a8d8c42e47b8dcd85cbc2b4d06de21c91bef921))
* **api:** api update ([6fde6bb](https://github.com/aiinbx/aiinbx-py/commit/6fde6bb2fe44c59108447cc8ac7a323b7d0c2629))
* **api:** api update ([fc5511e](https://github.com/aiinbx/aiinbx-py/commit/fc5511e033fc3b3bc2ff14df8b6beb00548f76b9))
* **api:** api update ([acfd5ed](https://github.com/aiinbx/aiinbx-py/commit/acfd5ed0eb83fa61f0d1dfc5582221627d807d18))
* **api:** api update ([217f9fe](https://github.com/aiinbx/aiinbx-py/commit/217f9fe35cc01e3632021154532b9e8c68ac34ea))
* **api:** api update ([ad10db4](https://github.com/aiinbx/aiinbx-py/commit/ad10db4bce1262d36b94612cc47ee6e8c66b2ba0))
* **api:** api update ([297679b](https://github.com/aiinbx/aiinbx-py/commit/297679b314e893af136eaac292cb01f7c64e76d1))
* **api:** api update ([b77ff86](https://github.com/aiinbx/aiinbx-py/commit/b77ff862599eba45522848d1976f2ad0f7171830))
* **api:** api update ([918bf99](https://github.com/aiinbx/aiinbx-py/commit/918bf99ea3d6df3ce819627e37cc02f61969721e))
* **api:** api update ([94d5491](https://github.com/aiinbx/aiinbx-py/commit/94d5491081b14940f026f26ede06609563053e2f))
* **api:** api update ([d0edd94](https://github.com/aiinbx/aiinbx-py/commit/d0edd9478aa785a39fa9269b83e41af5cea6d2a1))
* **api:** api update ([8401492](https://github.com/aiinbx/aiinbx-py/commit/84014923bc87d1caee8ad0e8f7b59f09ff276ef8))
* **api:** api update ([e220a15](https://github.com/aiinbx/aiinbx-py/commit/e220a156bab48b9d6695b07ee888c60fc4c57409))
* **api:** api update ([d8d2ac5](https://github.com/aiinbx/aiinbx-py/commit/d8d2ac5e07ccf3db6c9e81c9c0b78ae3e4d14e7f))
* **api:** api update ([0ce53af](https://github.com/aiinbx/aiinbx-py/commit/0ce53af25ec38907a900fe4853ff8b9bdf19cf00))
* **api:** api update ([bfd7765](https://github.com/aiinbx/aiinbx-py/commit/bfd77656d16db7142ba89c7533fc65a6714c96ab))
* **api:** api update ([9a989b4](https://github.com/aiinbx/aiinbx-py/commit/9a989b4a8eecd76012a38a967f8f21702781f703))
* **api:** api update ([9ebe5ce](https://github.com/aiinbx/aiinbx-py/commit/9ebe5ce18e2acb366245b22d201ed15b3e35d1aa))
* **api:** api update ([5f74d6b](https://github.com/aiinbx/aiinbx-py/commit/5f74d6bc627b23cb85e9c3beddbb3e3f5bf77f25))
* **api:** api update ([2f56833](https://github.com/aiinbx/aiinbx-py/commit/2f568330c6060d7c255be445847083518659eb6e))
* **api:** api update ([df57cb1](https://github.com/aiinbx/aiinbx-py/commit/df57cb153d7cb3f7f5badf98a190b20c7047d254))
* **api:** api update ([e3fa355](https://github.com/aiinbx/aiinbx-py/commit/e3fa35502f7b817fa74e1b6b3032c1d08a34d873))
* **api:** api update ([a5ca405](https://github.com/aiinbx/aiinbx-py/commit/a5ca405d9fedb2ac2b7f20713f8f8f7c87dfc85f))
* **api:** api update ([fe5a0cc](https://github.com/aiinbx/aiinbx-py/commit/fe5a0cc698a3b8b0dd1a3f993cbf450ed47778fe))
* **api:** api update ([4f77bfb](https://github.com/aiinbx/aiinbx-py/commit/4f77bfbecceea24c6b0209573aa6803b520fce2a))
* **api:** api update ([8e2c2d3](https://github.com/aiinbx/aiinbx-py/commit/8e2c2d38780c713d63ed975ec3366936d19e83fe))
* **api:** api update ([abab237](https://github.com/aiinbx/aiinbx-py/commit/abab237a881dad9a4b0ac14ac2987f963323d1ec))
* **api:** api update ([09bb63d](https://github.com/aiinbx/aiinbx-py/commit/09bb63d0796c0ec6f7c4f85054fa765d5d437f54))
* **api:** api update ([12de8ae](https://github.com/aiinbx/aiinbx-py/commit/12de8aef3efb1916af01cfc298a0880b7ac90781))
* **api:** api update ([835f86b](https://github.com/aiinbx/aiinbx-py/commit/835f86bd8a3eeefdb0c027e20a24bb705da527c1))
* **api:** manual updates ([0e6ad9c](https://github.com/aiinbx/aiinbx-py/commit/0e6ad9c05bc04d627495d33c26112fe8eea3b83e))
* **api:** manual updates ([a8e2907](https://github.com/aiinbx/aiinbx-py/commit/a8e29077f61c37e1565bae986960e671b4d8583d))
* **api:** manual updates ([3377308](https://github.com/aiinbx/aiinbx-py/commit/33773085b7658fb2be22c4c487ea33877e980c7c))
* **api:** manual updates ([9f338c0](https://github.com/aiinbx/aiinbx-py/commit/9f338c08cf76e9482a9529c761654cdd250483ea))
* improve future compat with pydantic v3 ([60479fd](https://github.com/aiinbx/aiinbx-py/commit/60479fd5aab856633c6eca0df3c1c5bfaddceb1d))
* **types:** replace List[str] with SequenceNotStr in params ([68f13b9](https://github.com/aiinbx/aiinbx-py/commit/68f13b951258795a96bfeb25b9017d404edf58b7))


### Bug Fixes

* avoid newer type syntax ([5be7f33](https://github.com/aiinbx/aiinbx-py/commit/5be7f3326de519f7be66a89cb7fea6428378b2af))
* **client:** close streams without requiring full consumption ([c9f31ef](https://github.com/aiinbx/aiinbx-py/commit/c9f31ef55fb6d3fb93be2213334f91a2d04dd258))
* compat with Python 3.14 ([7e15855](https://github.com/aiinbx/aiinbx-py/commit/7e158557c4b162a4a87c67b939cddf0d9d1a7d05))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([744437f](https://github.com/aiinbx/aiinbx-py/commit/744437f18a7aa06a7956aae618a7240e6926061f))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([68dfe98](https://github.com/aiinbx/aiinbx-py/commit/68dfe98c70f4338569bc9ec71c769cfb596b66df))
* configure new SDK language ([3cc34fc](https://github.com/aiinbx/aiinbx-py/commit/3cc34fcf8b0325986076726a774c419992b5aafa))
* do not install brew dependencies in ./scripts/bootstrap by default ([b790676](https://github.com/aiinbx/aiinbx-py/commit/b79067691b2dd53f05e0c1ec4e7d44329d5a2a7d))
* **internal/tests:** avoid race condition with implicit client cleanup ([8151b68](https://github.com/aiinbx/aiinbx-py/commit/8151b681a02be66458edc9692574dc6143f036f7))
* **internal:** add Sequence related utils ([4a2dd8c](https://github.com/aiinbx/aiinbx-py/commit/4a2dd8c5ca6c58ca5e4774eaad28167b0d797bf9))
* **internal:** change ci workflow machines ([0bdef89](https://github.com/aiinbx/aiinbx-py/commit/0bdef89c32b5776076a51f33e0bf2e3b420c76f2))
* **internal:** codegen related update ([6f79bad](https://github.com/aiinbx/aiinbx-py/commit/6f79bad626202ec0b4227e61a5ddc4c8b9acdf64))
* **internal:** detect missing future annotations with ruff ([c12e87e](https://github.com/aiinbx/aiinbx-py/commit/c12e87e4070f07c2b69625d727166ba55fcbbd62))
* **internal:** grammar fix (it's -&gt; its) ([ec0e54a](https://github.com/aiinbx/aiinbx-py/commit/ec0e54a72af0ce65d410a2e5775253cf9e570268))
* **internal:** move mypy configurations to `pyproject.toml` file ([485c0d9](https://github.com/aiinbx/aiinbx-py/commit/485c0d9f65d7fd8f59f9a2509c31cceaced1200f))
* **internal:** update pydantic dependency ([6a9413a](https://github.com/aiinbx/aiinbx-py/commit/6a9413a8cb94c48beed239109f876e705a3c92a1))
* **internal:** update pyright exclude list ([a2e7dba](https://github.com/aiinbx/aiinbx-py/commit/a2e7dba2d4e5daacb20e90498133b7f814938556))
* **tests:** simplify `get_platform` test ([ba0da0f](https://github.com/aiinbx/aiinbx-py/commit/ba0da0f48f2209bcb96d9d5f9f7d92dbbd9ed524))
* **types:** change optional parameter type from NotGiven to Omit ([220c508](https://github.com/aiinbx/aiinbx-py/commit/220c508548d348593f5ab50b919b68ff7a0321e2))
* update github action ([9f7c7f2](https://github.com/aiinbx/aiinbx-py/commit/9f7c7f2a77c7f129fcebcad3de76a0d0c027c511))
* update SDK settings ([9251ee7](https://github.com/aiinbx/aiinbx-py/commit/9251ee7b47185255692e59f672e6158f4af32541))

## 0.37.0 (2025-11-18)

Full Changelog: [v0.36.0...v0.37.0](https://github.com/aiinbx/aiinbx-py/compare/v0.36.0...v0.37.0)

### Features

* **api:** api update ([8d216db](https://github.com/aiinbx/aiinbx-py/commit/8d216db301003d76022e91c6d2f133e577616204))

## 0.36.0 (2025-11-18)

Full Changelog: [v0.35.0...v0.36.0](https://github.com/aiinbx/aiinbx-py/compare/v0.35.0...v0.36.0)

### Features

* **api:** api update ([8a8da17](https://github.com/aiinbx/aiinbx-py/commit/8a8da17951a064d0ed7f3d6df431f51993d577ea))

## 0.35.0 (2025-11-18)

Full Changelog: [v0.34.0...v0.35.0](https://github.com/aiinbx/aiinbx-py/compare/v0.34.0...v0.35.0)

### Features

* **api:** api update ([8a2a8df](https://github.com/aiinbx/aiinbx-py/commit/8a2a8dfd96493c2ccebb9094a51b7cbe547e5e4a))

## 0.34.0 (2025-11-18)

Full Changelog: [v0.33.0...v0.34.0](https://github.com/aiinbx/aiinbx-py/compare/v0.33.0...v0.34.0)

### Features

* **api:** api update ([fa2eefd](https://github.com/aiinbx/aiinbx-py/commit/fa2eefde5f4e0a5282419e38aa0350c959eaa4e1))

## 0.33.0 (2025-11-18)

Full Changelog: [v0.32.0...v0.33.0](https://github.com/aiinbx/aiinbx-py/compare/v0.32.0...v0.33.0)

### Features

* **api:** api update ([a9f4e64](https://github.com/aiinbx/aiinbx-py/commit/a9f4e64a44eef5f83c5524b7805a42c1ec0a11a4))
* **api:** api update ([6fde6bb](https://github.com/aiinbx/aiinbx-py/commit/6fde6bb2fe44c59108447cc8ac7a323b7d0c2629))
* **api:** api update ([fc5511e](https://github.com/aiinbx/aiinbx-py/commit/fc5511e033fc3b3bc2ff14df8b6beb00548f76b9))
* **api:** api update ([acfd5ed](https://github.com/aiinbx/aiinbx-py/commit/acfd5ed0eb83fa61f0d1dfc5582221627d807d18))
* **api:** api update ([217f9fe](https://github.com/aiinbx/aiinbx-py/commit/217f9fe35cc01e3632021154532b9e8c68ac34ea))
* **api:** api update ([ad10db4](https://github.com/aiinbx/aiinbx-py/commit/ad10db4bce1262d36b94612cc47ee6e8c66b2ba0))
* **api:** api update ([297679b](https://github.com/aiinbx/aiinbx-py/commit/297679b314e893af136eaac292cb01f7c64e76d1))
* **api:** api update ([b77ff86](https://github.com/aiinbx/aiinbx-py/commit/b77ff862599eba45522848d1976f2ad0f7171830))
* **api:** api update ([918bf99](https://github.com/aiinbx/aiinbx-py/commit/918bf99ea3d6df3ce819627e37cc02f61969721e))
* **api:** api update ([94d5491](https://github.com/aiinbx/aiinbx-py/commit/94d5491081b14940f026f26ede06609563053e2f))
* **api:** api update ([d0edd94](https://github.com/aiinbx/aiinbx-py/commit/d0edd9478aa785a39fa9269b83e41af5cea6d2a1))
* **api:** api update ([8401492](https://github.com/aiinbx/aiinbx-py/commit/84014923bc87d1caee8ad0e8f7b59f09ff276ef8))
* **api:** api update ([e220a15](https://github.com/aiinbx/aiinbx-py/commit/e220a156bab48b9d6695b07ee888c60fc4c57409))
* **api:** api update ([d8d2ac5](https://github.com/aiinbx/aiinbx-py/commit/d8d2ac5e07ccf3db6c9e81c9c0b78ae3e4d14e7f))
* **api:** api update ([0ce53af](https://github.com/aiinbx/aiinbx-py/commit/0ce53af25ec38907a900fe4853ff8b9bdf19cf00))
* **api:** api update ([bfd7765](https://github.com/aiinbx/aiinbx-py/commit/bfd77656d16db7142ba89c7533fc65a6714c96ab))
* **api:** api update ([9a989b4](https://github.com/aiinbx/aiinbx-py/commit/9a989b4a8eecd76012a38a967f8f21702781f703))
* **api:** api update ([9ebe5ce](https://github.com/aiinbx/aiinbx-py/commit/9ebe5ce18e2acb366245b22d201ed15b3e35d1aa))
* **api:** api update ([5f74d6b](https://github.com/aiinbx/aiinbx-py/commit/5f74d6bc627b23cb85e9c3beddbb3e3f5bf77f25))
* **api:** api update ([2f56833](https://github.com/aiinbx/aiinbx-py/commit/2f568330c6060d7c255be445847083518659eb6e))
* **api:** api update ([df57cb1](https://github.com/aiinbx/aiinbx-py/commit/df57cb153d7cb3f7f5badf98a190b20c7047d254))
* **api:** api update ([e3fa355](https://github.com/aiinbx/aiinbx-py/commit/e3fa35502f7b817fa74e1b6b3032c1d08a34d873))
* **api:** api update ([a5ca405](https://github.com/aiinbx/aiinbx-py/commit/a5ca405d9fedb2ac2b7f20713f8f8f7c87dfc85f))
* **api:** api update ([fe5a0cc](https://github.com/aiinbx/aiinbx-py/commit/fe5a0cc698a3b8b0dd1a3f993cbf450ed47778fe))
* **api:** api update ([4f77bfb](https://github.com/aiinbx/aiinbx-py/commit/4f77bfbecceea24c6b0209573aa6803b520fce2a))
* **api:** api update ([8e2c2d3](https://github.com/aiinbx/aiinbx-py/commit/8e2c2d38780c713d63ed975ec3366936d19e83fe))
* **api:** api update ([abab237](https://github.com/aiinbx/aiinbx-py/commit/abab237a881dad9a4b0ac14ac2987f963323d1ec))
* **api:** api update ([09bb63d](https://github.com/aiinbx/aiinbx-py/commit/09bb63d0796c0ec6f7c4f85054fa765d5d437f54))
* **api:** api update ([12de8ae](https://github.com/aiinbx/aiinbx-py/commit/12de8aef3efb1916af01cfc298a0880b7ac90781))
* **api:** api update ([835f86b](https://github.com/aiinbx/aiinbx-py/commit/835f86bd8a3eeefdb0c027e20a24bb705da527c1))
* **api:** manual updates ([0e6ad9c](https://github.com/aiinbx/aiinbx-py/commit/0e6ad9c05bc04d627495d33c26112fe8eea3b83e))
* **api:** manual updates ([a8e2907](https://github.com/aiinbx/aiinbx-py/commit/a8e29077f61c37e1565bae986960e671b4d8583d))
* **api:** manual updates ([3377308](https://github.com/aiinbx/aiinbx-py/commit/33773085b7658fb2be22c4c487ea33877e980c7c))
* **api:** manual updates ([9f338c0](https://github.com/aiinbx/aiinbx-py/commit/9f338c08cf76e9482a9529c761654cdd250483ea))
* improve future compat with pydantic v3 ([60479fd](https://github.com/aiinbx/aiinbx-py/commit/60479fd5aab856633c6eca0df3c1c5bfaddceb1d))
* **types:** replace List[str] with SequenceNotStr in params ([68f13b9](https://github.com/aiinbx/aiinbx-py/commit/68f13b951258795a96bfeb25b9017d404edf58b7))


### Bug Fixes

* avoid newer type syntax ([5be7f33](https://github.com/aiinbx/aiinbx-py/commit/5be7f3326de519f7be66a89cb7fea6428378b2af))
* **client:** close streams without requiring full consumption ([c9f31ef](https://github.com/aiinbx/aiinbx-py/commit/c9f31ef55fb6d3fb93be2213334f91a2d04dd258))
* compat with Python 3.14 ([7e15855](https://github.com/aiinbx/aiinbx-py/commit/7e158557c4b162a4a87c67b939cddf0d9d1a7d05))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([744437f](https://github.com/aiinbx/aiinbx-py/commit/744437f18a7aa06a7956aae618a7240e6926061f))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([68dfe98](https://github.com/aiinbx/aiinbx-py/commit/68dfe98c70f4338569bc9ec71c769cfb596b66df))
* configure new SDK language ([3cc34fc](https://github.com/aiinbx/aiinbx-py/commit/3cc34fcf8b0325986076726a774c419992b5aafa))
* do not install brew dependencies in ./scripts/bootstrap by default ([b790676](https://github.com/aiinbx/aiinbx-py/commit/b79067691b2dd53f05e0c1ec4e7d44329d5a2a7d))
* **internal/tests:** avoid race condition with implicit client cleanup ([8151b68](https://github.com/aiinbx/aiinbx-py/commit/8151b681a02be66458edc9692574dc6143f036f7))
* **internal:** add Sequence related utils ([4a2dd8c](https://github.com/aiinbx/aiinbx-py/commit/4a2dd8c5ca6c58ca5e4774eaad28167b0d797bf9))
* **internal:** change ci workflow machines ([0bdef89](https://github.com/aiinbx/aiinbx-py/commit/0bdef89c32b5776076a51f33e0bf2e3b420c76f2))
* **internal:** codegen related update ([6f79bad](https://github.com/aiinbx/aiinbx-py/commit/6f79bad626202ec0b4227e61a5ddc4c8b9acdf64))
* **internal:** detect missing future annotations with ruff ([c12e87e](https://github.com/aiinbx/aiinbx-py/commit/c12e87e4070f07c2b69625d727166ba55fcbbd62))
* **internal:** grammar fix (it's -&gt; its) ([ec0e54a](https://github.com/aiinbx/aiinbx-py/commit/ec0e54a72af0ce65d410a2e5775253cf9e570268))
* **internal:** move mypy configurations to `pyproject.toml` file ([485c0d9](https://github.com/aiinbx/aiinbx-py/commit/485c0d9f65d7fd8f59f9a2509c31cceaced1200f))
* **internal:** update pydantic dependency ([6a9413a](https://github.com/aiinbx/aiinbx-py/commit/6a9413a8cb94c48beed239109f876e705a3c92a1))
* **internal:** update pyright exclude list ([a2e7dba](https://github.com/aiinbx/aiinbx-py/commit/a2e7dba2d4e5daacb20e90498133b7f814938556))
* **tests:** simplify `get_platform` test ([ba0da0f](https://github.com/aiinbx/aiinbx-py/commit/ba0da0f48f2209bcb96d9d5f9f7d92dbbd9ed524))
* **types:** change optional parameter type from NotGiven to Omit ([220c508](https://github.com/aiinbx/aiinbx-py/commit/220c508548d348593f5ab50b919b68ff7a0321e2))
* update github action ([9f7c7f2](https://github.com/aiinbx/aiinbx-py/commit/9f7c7f2a77c7f129fcebcad3de76a0d0c027c511))
* update SDK settings ([9251ee7](https://github.com/aiinbx/aiinbx-py/commit/9251ee7b47185255692e59f672e6158f4af32541))

## 0.32.0 (2025-11-18)

Full Changelog: [v0.31.0...v0.32.0](https://github.com/aiinbx/aiinbx-py/compare/v0.31.0...v0.32.0)

### Features

* **api:** api update ([68e735d](https://github.com/aiinbx/aiinbx-py/commit/68e735dfbd46c4495b15ee0475a454be2b70d071))

## 0.31.0 (2025-11-18)

Full Changelog: [v0.30.0...v0.31.0](https://github.com/aiinbx/aiinbx-py/compare/v0.30.0...v0.31.0)

### Features

* **api:** api update ([1caf52d](https://github.com/aiinbx/aiinbx-py/commit/1caf52d0d38e0ed858cb909b343f0945f16d76f9))

## 0.30.0 (2025-11-17)

Full Changelog: [v0.29.0...v0.30.0](https://github.com/aiinbx/aiinbx-py/compare/v0.29.0...v0.30.0)

### Features

* **api:** api update ([26931da](https://github.com/aiinbx/aiinbx-py/commit/26931da268c8db09f51494c11cdb7c290b97f0f1))

## 0.29.0 (2025-11-17)

Full Changelog: [v0.28.0...v0.29.0](https://github.com/aiinbx/aiinbx-py/compare/v0.28.0...v0.29.0)

### Features

* **api:** api update ([8864d90](https://github.com/aiinbx/aiinbx-py/commit/8864d90564569d6409d969316fcaa23a3193cc0f))

## 0.28.0 (2025-11-17)

Full Changelog: [v0.27.0...v0.28.0](https://github.com/aiinbx/aiinbx-py/compare/v0.27.0...v0.28.0)

### Features

* **api:** api update ([4b9f66c](https://github.com/aiinbx/aiinbx-py/commit/4b9f66c616434332276e6442ea5d319807649b8f))

## 0.27.0 (2025-11-17)

Full Changelog: [v0.26.0...v0.27.0](https://github.com/aiinbx/aiinbx-py/compare/v0.26.0...v0.27.0)

### Features

* **api:** api update ([fad20c1](https://github.com/aiinbx/aiinbx-py/commit/fad20c11a6647f2d8fb44c1b871509217daffb9d))

## 0.26.0 (2025-11-17)

Full Changelog: [v0.25.0...v0.26.0](https://github.com/aiinbx/aiinbx-py/compare/v0.25.0...v0.26.0)

### Features

* **api:** api update ([131b2cf](https://github.com/aiinbx/aiinbx-py/commit/131b2cfb0a95229173edaff527922f0fc005d53a))

## 0.25.0 (2025-11-17)

Full Changelog: [v0.24.0...v0.25.0](https://github.com/aiinbx/aiinbx-py/compare/v0.24.0...v0.25.0)

### Features

* **api:** api update ([ca06373](https://github.com/aiinbx/aiinbx-py/commit/ca06373a0655a4263293b90f83fdcbb023537fbc))
* **api:** api update ([324884a](https://github.com/aiinbx/aiinbx-py/commit/324884a673831f317709aca4dfaa4dfee8bec01c))

## 0.24.0 (2025-11-17)

Full Changelog: [v0.23.0...v0.24.0](https://github.com/aiinbx/aiinbx-py/compare/v0.23.0...v0.24.0)

### Features

* **api:** api update ([d4cc500](https://github.com/aiinbx/aiinbx-py/commit/d4cc500501514ea58515e7a7c6b1eb9fce5d8a9c))

## 0.23.0 (2025-11-17)

Full Changelog: [v0.22.0...v0.23.0](https://github.com/aiinbx/aiinbx-py/compare/v0.22.0...v0.23.0)

### Features

* **api:** api update ([4bd1404](https://github.com/aiinbx/aiinbx-py/commit/4bd14043d5d312aea548de04165cd4a94b838321))

## 0.22.0 (2025-11-17)

Full Changelog: [v0.21.0...v0.22.0](https://github.com/aiinbx/aiinbx-py/compare/v0.21.0...v0.22.0)

### Features

* **api:** api update ([77853f3](https://github.com/aiinbx/aiinbx-py/commit/77853f3028819561553f4d00a200d9eacc5ef089))

## 0.21.0 (2025-11-17)

Full Changelog: [v0.20.0...v0.21.0](https://github.com/aiinbx/aiinbx-py/compare/v0.20.0...v0.21.0)

### Features

* **api:** api update ([6bbbe93](https://github.com/aiinbx/aiinbx-py/commit/6bbbe93fa42c2facf5c6b1d84ba32bf47658c300))

## 0.20.0 (2025-11-16)

Full Changelog: [v0.19.0...v0.20.0](https://github.com/aiinbx/aiinbx-py/compare/v0.19.0...v0.20.0)

### Features

* **api:** api update ([87c105a](https://github.com/aiinbx/aiinbx-py/commit/87c105a99df202f9a3dc388b0cfe078251998d5f))

## 0.19.0 (2025-11-16)

Full Changelog: [v0.18.0...v0.19.0](https://github.com/aiinbx/aiinbx-py/compare/v0.18.0...v0.19.0)

### Features

* **api:** api update ([07beb52](https://github.com/aiinbx/aiinbx-py/commit/07beb52d40745cbcf5193c85a7efbdc90ad1ef31))

## 0.18.0 (2025-11-16)

Full Changelog: [v0.17.0...v0.18.0](https://github.com/aiinbx/aiinbx-py/compare/v0.17.0...v0.18.0)

### Features

* **api:** api update ([24490c8](https://github.com/aiinbx/aiinbx-py/commit/24490c8805342f13b6ff919d27feaf0d7dfb71ed))

## 0.17.0 (2025-11-16)

Full Changelog: [v0.16.0...v0.17.0](https://github.com/aiinbx/aiinbx-py/compare/v0.16.0...v0.17.0)

### Features

* **api:** api update ([4db8f52](https://github.com/aiinbx/aiinbx-py/commit/4db8f52e507e287f71e36f2ce1816e7147d97d39))

## 0.16.0 (2025-11-16)

Full Changelog: [v0.15.0...v0.16.0](https://github.com/aiinbx/aiinbx-py/compare/v0.15.0...v0.16.0)

### Features

* **api:** api update ([b423628](https://github.com/aiinbx/aiinbx-py/commit/b423628767b266a14d0e9b385d6ed057dfae1f78))

## 0.15.0 (2025-11-16)

Full Changelog: [v0.14.0...v0.15.0](https://github.com/aiinbx/aiinbx-py/compare/v0.14.0...v0.15.0)

### Features

* **api:** api update ([e85c831](https://github.com/aiinbx/aiinbx-py/commit/e85c831870cdc8e101cd4c08ab665babda9fe089))

## 0.14.0 (2025-11-16)

Full Changelog: [v0.13.0...v0.14.0](https://github.com/aiinbx/aiinbx-py/compare/v0.13.0...v0.14.0)

### Features

* **api:** api update ([4f72d75](https://github.com/aiinbx/aiinbx-py/commit/4f72d758e209039a5293d53750b224c18ca8025a))

## 0.13.0 (2025-11-16)

Full Changelog: [v0.12.0...v0.13.0](https://github.com/aiinbx/aiinbx-py/compare/v0.12.0...v0.13.0)

### Features

* **api:** api update ([13b6d23](https://github.com/aiinbx/aiinbx-py/commit/13b6d23df33c278b1f17ab41a0df7495500bf553))

## 0.12.0 (2025-11-16)

Full Changelog: [v0.11.0...v0.12.0](https://github.com/aiinbx/aiinbx-py/compare/v0.11.0...v0.12.0)

### Features

* **api:** api update ([f2d9176](https://github.com/aiinbx/aiinbx-py/commit/f2d91769b6ab82a2a234f76b59f9b273d7850c8d))

## 0.11.0 (2025-11-15)

Full Changelog: [v0.10.0...v0.11.0](https://github.com/aiinbx/aiinbx-py/compare/v0.10.0...v0.11.0)

### Features

* **api:** api update ([1bf1047](https://github.com/aiinbx/aiinbx-py/commit/1bf1047914ccbdb79141933797ee2153f57928a2))

## 0.10.0 (2025-11-15)

Full Changelog: [v0.9.0...v0.10.0](https://github.com/aiinbx/aiinbx-py/compare/v0.9.0...v0.10.0)

### Features

* **api:** api update ([ef0d36f](https://github.com/aiinbx/aiinbx-py/commit/ef0d36f67a8254350e4d6d08e2ea340666df5286))

## 0.9.0 (2025-11-15)

Full Changelog: [v0.8.0...v0.9.0](https://github.com/aiinbx/aiinbx-py/compare/v0.8.0...v0.9.0)

### Features

* **api:** api update ([43ed250](https://github.com/aiinbx/aiinbx-py/commit/43ed250785d0b96f48c3a46b6db9b017f080aebc))

## 0.8.0 (2025-11-15)

Full Changelog: [v0.7.2...v0.8.0](https://github.com/aiinbx/aiinbx-py/compare/v0.7.2...v0.8.0)

### Features

* **api:** api update ([73ba8b5](https://github.com/aiinbx/aiinbx-py/commit/73ba8b5c88cf196e502f10cf975dd5c58620fd90))

## 0.7.2 (2025-11-12)

Full Changelog: [v0.7.1...v0.7.2](https://github.com/aiinbx/aiinbx-py/compare/v0.7.1...v0.7.2)

### Bug Fixes

* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([63fdaba](https://github.com/aiinbx/aiinbx-py/commit/63fdaba20d9bfe35d1d1358ef229d28c222b5ecf))

## 0.7.1 (2025-11-11)

Full Changelog: [v0.7.0...v0.7.1](https://github.com/aiinbx/aiinbx-py/compare/v0.7.0...v0.7.1)

### Bug Fixes

* compat with Python 3.14 ([17da3dd](https://github.com/aiinbx/aiinbx-py/commit/17da3dd00711f92f515ab05562b79eb784d0ce24))


### Chores

* **internal:** codegen related update ([2976852](https://github.com/aiinbx/aiinbx-py/commit/2976852cdedba8ffdaed6879fd51d87708419503))

## 0.7.0 (2025-11-04)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/aiinbx/aiinbx-py/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([0f82ed1](https://github.com/aiinbx/aiinbx-py/commit/0f82ed1bf1a6d34c2e63ecbc9cf0a5b43f53e89a))


### Chores

* **internal:** grammar fix (it's -&gt; its) ([4398c76](https://github.com/aiinbx/aiinbx-py/commit/4398c76c2f4f5cd115df6f40f9948dc9d439a9b6))

## 0.6.0 (2025-10-31)

Full Changelog: [v0.5.1...v0.6.0](https://github.com/aiinbx/aiinbx-py/compare/v0.5.1...v0.6.0)

### Features

* **api:** api update ([e0ee97a](https://github.com/aiinbx/aiinbx-py/commit/e0ee97a7568dc6839f1c011b5312ec34ce3d9f7d))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([4cf6938](https://github.com/aiinbx/aiinbx-py/commit/4cf6938564097419455a6219e0b217e7921a9ea2))

## 0.5.1 (2025-10-30)

Full Changelog: [v0.5.0...v0.5.1](https://github.com/aiinbx/aiinbx-py/compare/v0.5.0...v0.5.1)

### Bug Fixes

* **client:** close streams without requiring full consumption ([d824bbb](https://github.com/aiinbx/aiinbx-py/commit/d824bbbd517355748039bf7f5edfbee0e802a606))


### Chores

* bump `httpx-aiohttp` version to 0.1.9 ([8c932fb](https://github.com/aiinbx/aiinbx-py/commit/8c932fb49aa74fe9174deb5c7b4e71cccd41f119))

## 0.5.0 (2025-10-15)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/aiinbx/aiinbx-py/compare/v0.4.0...v0.5.0)

### Features

* **api:** manual updates ([ddacc81](https://github.com/aiinbx/aiinbx-py/commit/ddacc8158fd4079c1ee4b8ae04f89f22e2fcd46a))


### Chores

* **internal:** detect missing future annotations with ruff ([6f6a3da](https://github.com/aiinbx/aiinbx-py/commit/6f6a3da5978b34e1a2959b38715d4311474f1c5e))

## 0.4.0 (2025-10-05)

Full Changelog: [v0.3.0...v0.4.0](https://github.com/aiinbx/aiinbx-py/compare/v0.3.0...v0.4.0)

### Features

* **api:** manual updates ([601d5ea](https://github.com/aiinbx/aiinbx-py/commit/601d5eade9216549a200c26584a2cc18176835fd))
* improve future compat with pydantic v3 ([dcc1c80](https://github.com/aiinbx/aiinbx-py/commit/dcc1c804ec998e7948395f7c1ea3aac371a539fb))
* **types:** replace List[str] with SequenceNotStr in params ([a31a999](https://github.com/aiinbx/aiinbx-py/commit/a31a999a8dd553a067fdd4368d147f773418dc02))


### Chores

* do not install brew dependencies in ./scripts/bootstrap by default ([b4c08e3](https://github.com/aiinbx/aiinbx-py/commit/b4c08e37dfa25b784a2cd7d5e9778f3318c365b9))
* **internal:** add Sequence related utils ([879c21a](https://github.com/aiinbx/aiinbx-py/commit/879c21ac262c2c10c0e1bfa03d5d1c40470f889b))
* **internal:** move mypy configurations to `pyproject.toml` file ([3108a79](https://github.com/aiinbx/aiinbx-py/commit/3108a794e35f868d1e21a210abbda837eecc64d1))
* **internal:** update pydantic dependency ([6dcd694](https://github.com/aiinbx/aiinbx-py/commit/6dcd694e2ab6b8246892ebef85e95bff9b0338a9))
* **tests:** simplify `get_platform` test ([0f14d8c](https://github.com/aiinbx/aiinbx-py/commit/0f14d8cd43342f3fda7ccda30717c01d20679593))
* **types:** change optional parameter type from NotGiven to Omit ([1b12faa](https://github.com/aiinbx/aiinbx-py/commit/1b12faa48dbcc8fedf5dc8e4a410c58fcfac7853))

## 0.3.0 (2025-08-28)

Full Changelog: [v0.2.0...v0.3.0](https://github.com/aiinbx/aiinbx-py/compare/v0.2.0...v0.3.0)

### Features

* **api:** api update ([2de3cb7](https://github.com/aiinbx/aiinbx-py/commit/2de3cb73d4178e81925fd6d04b3683b81e7da30d))

## 0.2.0 (2025-08-28)

Full Changelog: [v0.1.1...v0.2.0](https://github.com/aiinbx/aiinbx-py/compare/v0.1.1...v0.2.0)

### Features

* **api:** manual updates ([f4e60fe](https://github.com/aiinbx/aiinbx-py/commit/f4e60fed47de83248dbcef3cd28590643c0b9bff))

## 0.1.1 (2025-08-27)

Full Changelog: [v0.1.0...v0.1.1](https://github.com/aiinbx/aiinbx-py/compare/v0.1.0...v0.1.1)

### Bug Fixes

* avoid newer type syntax ([85f2191](https://github.com/aiinbx/aiinbx-py/commit/85f21914439dbd7e3ef751a1010eaf023b33ef70))


### Chores

* **internal:** change ci workflow machines ([7e210c5](https://github.com/aiinbx/aiinbx-py/commit/7e210c590a8a7659cbbf3f087b869ca580bd9b1b))
* **internal:** update pyright exclude list ([a4d4c96](https://github.com/aiinbx/aiinbx-py/commit/a4d4c9626f42577c535516072216bc82c6b2d551))
* update github action ([d06abee](https://github.com/aiinbx/aiinbx-py/commit/d06abee5f995ce020da7ab44160eaab348c8c18a))

## 0.1.0 (2025-08-13)

Full Changelog: [v0.0.1...v0.1.0](https://github.com/aiinbx/aiinbx-py/compare/v0.0.1...v0.1.0)

### Features

* **api:** manual updates ([9f338c0](https://github.com/aiinbx/aiinbx-py/commit/9f338c08cf76e9482a9529c761654cdd250483ea))


### Chores

* configure new SDK language ([3cc34fc](https://github.com/aiinbx/aiinbx-py/commit/3cc34fcf8b0325986076726a774c419992b5aafa))
* update SDK settings ([9251ee7](https://github.com/aiinbx/aiinbx-py/commit/9251ee7b47185255692e59f672e6158f4af32541))
